set more off, perm
set mat 11000
clear all
scalar drop _all
cls

***************************************************************
*                      Load Final
***************************************************************

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

capture log close
log using "${drctory}/temp/reg_comp.log", text replace

use "${drctory}/input/execucomp/execucomp_final.dta", replace

gen ncbei = nc*bei2009_scaled
cap drop t_new
gen t_new = t/10

global xlist ceo_g gender_g l_at roa
	
***************************************************************
*           Regression Realized Compensation - Whether NC
***************************************************************

eststo clear
eststo: quietly reg l_tdc2 c.t_new##c.t_new##c.t_new##c.ncbei $xlist i.sic i.year i.state,vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_state = "$\surd$"
estadd local fe_ind = "$\surd$"
estadd local fe_firm = " "
	
xtset, clear 	
xtset gvkey
eststo: quietly xtreg l_tdc2 c.t_new##c.t_new##c.t_new##c.ncbei $xlist i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_state = " " 
estadd local fe_ind = " "
estadd local fe_firm = "$\surd$"

***************************************************************
*           Regression Realized Compensation - Whether NC
***************************************************************

eststo: quietly reg l_tdc1 c.t_new##c.t_new##c.t_new##c.ncbei $xlist i.sic i.year i.state,vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_state = "$\surd$"
estadd local fe_ind = "$\surd$"
estadd local fe_firm = " "

xtset, clear 	
xtset gvkey
eststo: quietly xtreg l_tdc1 c.t_new##c.t_new##c.t_new##c.ncbei $xlist i.year, fe vce(cluster state)
estadd local fe_ind = " "
estadd local fe_state = " " 
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"
		
***************************************************************
*** compile table	

esttab using "${drctory}/output/table/reg_comp_temp.tex", replace ///
se nofloat booktabs nocons b(%9.3f) star(* 0.1 ** 0.05 *** 0.01) ///
keep(ncbei ///
	t_new c.t_new#c.ncbei ///
	c.t_new#c.t_new c.t_new#c.t_new#c.ncbei  ///
	c.t_new#c.t_new#c.t_new c.t_new#c.t_new#c.t_new#c.ncbei) ///
order(ncbei ///
	t_new c.t_new#c.ncbei ///
	c.t_new#c.t_new c.t_new#c.t_new#c.ncbei  ///
	c.t_new#c.t_new#c.t_new c.t_new#c.t_new#c.t_new#c.ncbei) ///
gaps lines ///
varlabels(ncbei "(Noncompete \$ \times \$ Enforce)" ///
	      t_new "Tenure/10" ///
		  c.t_new#c.ncbei "Tenure/10 \$ \times \$ (Noncompete \$ \times \$ Enforce)" ///
		  c.t_new#c.t_new "(Tenure/10)$^{2}$" ///
		  c.t_new#c.t_new#c.ncbei "(Tenure/10)$^{2}$ \$ \times \$ (Noncompete \$ \times \$ Enforce)" ///
		  c.t_new#c.t_new#c.t_new "(Tenure/10)$^{3}$" ///
		  c.t_new#c.t_new#c.t_new#c.ncbei "(Tenure/10)$^{3}$ \$ \times \$ (Noncompete \$ \times \$ Enforce)") ///
stats(fe_year fe_state fe_ind fe_firm N r2_a, fmt(%9.3f %9.3f %9.3f %9.3f %12.0gc %9.2f) layout(@ @ @ @ @ @) ///
labels("Year FEs" "State FEs" "Industry FEs" "Firm FEs" "Observations" "Adjusted $ R^{2} $")) ///
nomtitles eqlabels(none) nonotes 

***************************************************************
*** adjust

file open infile using "${drctory}/output/table/reg_comp_temp.tex", read
file open outfile using "${drctory}/output/table/reg_comp.tex", write replace
file read infile line
local i=1
while r(eof)==0 {
	if inlist(`i',5){
		file write outfile "& \multicolumn{2}{c}{Realized} & \multicolumn{2}{c}{Awarded} \\" _n 
		file write outfile "\cmidrule(l){2-3} \cmidrule(l){4-5}" _n
		file write outfile "`line'" _n
	}
	else if inlist(`i',21){
		file write outfile "& \\" _n
	}
	else if inlist(`i',8,10,12,14,16,18){
		file write outfile "`line'" _n
		file write outfile "\addlinespace" _n
	}	
	else {
		file write outfile "`line'" _n
	}		
	file read infile line
	local i=`i'+1
}
file close infile
file close outfile
erase "${drctory}/output/table/reg_comp_temp.tex"

log close

