set more off, perm
set mat 11000
clear all
scalar drop _all
cls

***************************************************************
*                      Load Final
***************************************************************

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

capture log close
log using "${drctory}/temp/reg_comp_marginplot.log", text replace

use "${drctory}/input/execucomp/execucomp_final.dta", replace

gen ncbei = nc*bei2009_scaled

global xlist ceo_g gender_g l_at roa
			 
***************************************************************
*           Margins - Realized
***************************************************************	

reg l_tdc2 $xlist i.sic i.year i.state c.t##c.t##c.t##c.ncbei,vce(cluster state)

* save the estimated profile tdc2_tenure
margins, at(t=(1(1)11) ncbei=(0 1)) saving(tdc2_tenure, replace)		
marginsplot, ////
	plot1opts(color("0 0 153") lp(solid) lw(medthick)  msymbol(T)) ///
	plot2opts(color(gs2) lp(dash) lw(medthick)  msymbol(O)) ///	
	ci1opts(color("0 0 153") lw(vthin)) ///
	ci2opts(color(gs4) lw(vthin)) ///
	legend(order(3 "without a noncompete clause" 4 "with a noncompete clause") ///
				 col(1) ring(0) pos(5) symx(*.3) region(style(none)) size(vlarge)) ///
	title("", color(black) margin(0 0 5 2.55)) ///
	ytitle("Log realized compensation (mn)", margin(0 5 0 0) size(vlarge)) ///
	xtitle("Tenure, years", margin(0 0 0 5) size(vlarge)) ///
	ylabel(-.1(0.1).7,angle(0) grid glc("250 250 250") glw(vthin) labsize(large)) ///
	ymtick(-.1(0.1).7, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(1(1)11, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(1(1)11, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(3.3)
graph export "${drctory}/output/figure/tdc2_tenure.eps", replace

***************************************************************
*           Margins - Awarded
***************************************************************	

reg l_tdc1 $xlist i.sic i.year i.state c.t##c.t##c.t##c.ncbei,vce(cluster state)

margins, at(t=(1(1)11) ncbei=(0 1)) 
marginsplot, ///
	plot1opts(color("0 0 153") lp(solid) lw(medthick)  msymbol(t)) ///
	plot2opts(color(gs2) lp(dash) lw(medthick) msymbol(o)) ///	
	ci1opts(color("0 0 153") lw(vthin)) ///
	ci2opts(color(gs4) lw(vthin)) ///
	legend(order(3 "without a noncompete clause" 4 "with a noncompete clause") ///
				 col(1) ring(0) pos(5) symx(*.3) region(style(none)) size(vlarge)) ///
	title("", color(black) margin(0 0 5 2.55)) ///
	ytitle("Log awarded compensation (mn)", margin(0 5 0 0) size(vlarge)) ///
	xtitle("Tenure, years", margin(0 0 0 5) size(vlarge)) ///
	ylabel(-.1(0.1).7, grid glc("250 250 250") glw(vthin) labsize(large)) ///
	ymtick(-.1(0.1).7, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(1(1)11, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(1(1)11, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(3.3)
graph export "${drctory}/output/figure/tdc1_tenure.eps", replace

***************************************************************
*           Save tdc2_tenure as a csv file
***************************************************************	

use "tdc2_tenure", replace
export delimited using "${drctory}/output/data/tdc2_tenure", replace
erase tdc2_tenure.dta

log close
