set more off, perm
set emptycells keep, permanently
*set mat 11000
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

capture log close
log using "${drctory}/temp/reg_investment.log", text replace

***************************************************************
*                      DATA PREP
***************************************************************

use "${drctory}/input/compustat/firm_panel.dta", replace

***************************************************************
*                      Merge Contract Info
***************************************************************

merge m:1 gvkey year using "${drctory}/input/compustat/noncompete_firm_level.dta", keep(master match) 
drop _merge

***************************************************************
*                      Raw Data
***************************************************************

keep if year>=1992 & year<=2015
do "${drctory}/code/reg/sub_filter_firm2.do"

gen roa = ni/at
gen l_cash = log(cash)

***************************************************************
*                      Regressions
***************************************************************

eststo clear 

xtset gvkey
eststo: xtreg inv_int nc_mean q_tot_lag l_cash i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"

eststo: xtreg inv_int c.nc_mean#c.bei2009_scaled q_tot_lag l_cash i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"

eststo: xtreg inv_int c.nc_mean#c.bei_sic3_N q_tot_lag l_cash i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"

eststo: xtreg inv_phy nc_mean q_tot_lag l_cash i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"

eststo: xtreg inv_phy c.nc_mean#c.bei2009_scaled q_tot_lag l_cash i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"

eststo: xtreg inv_phy c.nc_mean#c.bei_sic3_N q_tot_lag l_cash i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$"

***************************************************************
*** compile table

esttab using "${drctory}/output/table/reg_investment_temp.tex", replace ///
se nofloat booktabs nocons b(%9.3f) star(* 0.1 ** 0.05 *** 0.01) ///
keep(nc_mean c.nc_mean#c.bei2009_scaled c.nc_mean#c.bei_sic3_N) ///
order(nc_mean c.nc_mean#c.bei2009_scaled c.nc_mean#c.bei_sic3_N) ///
gaps lines ///
varlabels(nc_mean "Noncompete" ///
		  c.nc_mean#c.bei2009_scaled "Noncompete \$ \times \$ Enforce (State)" ///
		  c.nc_mean#c.bei_sic3_N "Noncompete \$ \times \$ Enforce (Industry)") ///	
stats(fe_year fe_firm N , fmt(%9.3f %9.3f %12.0gc) layout(@ @ @) ///
labels("Year FEs" "Firm FEs" "Observations")) ///
nomtitles eqlabels(none) nonotes 

***************************************************************
*** adjust

file open infile using "${drctory}/output/table/reg_investment_temp.tex", read
file open outfile using "${drctory}/output/table/reg_investment.tex", write replace
file read infile line
local i=1
while r(eof)==0 {
	if inlist(`i',5){
		file write outfile "&\multicolumn{3}{c}{Intangible Capital} &\multicolumn{3}{c}{Physical Capital}\\" _n
		file write outfile "\cmidrule(l){2-4} \cmidrule(l){5-7}" _n
		file write outfile "`line'" _n
	}	
	else if inlist(`i',13){
		file write outfile "& \\" _n
	}
	else if inlist(`i',8,10,12){
		file write outfile "`line'" _n
		file write outfile "\addlinespace" _n
	}	
	else {
		file write outfile "`line'" _n
	}		
	file read infile line
	local i=`i'+1
}
file close infile
file close outfile

erase "${drctory}/output/table/reg_investment_temp.tex"


***************************************************************
*                      Fit Pareto Distribution
***************************************************************

** the shape parameter is slightly larger than the unfiltered data
paretofit at if at>0 
scalar zeta_at = e(ba)+1

forvalues yy = 1992/2015 { 
	quietly paretofit at if at>0 & year==`yy'
	scalar zeta_at_`yy' = e(ba)+1
}
scalar zeta_at_average = (zeta_at_1992+zeta_at_1993+zeta_at_1994+zeta_at_1995+zeta_at_1996+zeta_at_1997+zeta_at_1998+zeta_at_1999+zeta_at_2000+zeta_at_2001+zeta_at_2002+zeta_at_2003+zeta_at_2004+zeta_at_2005+zeta_at_2006+zeta_at_2007+zeta_at_2008+zeta_at_2009+zeta_at_2010+zeta_at_2011+zeta_at_2012+zeta_at_2013+zeta_at_2014+zeta_at_2015)/24

paretofit emp if emp>0 
scalar zeta_emp = e(ba)+1

forvalues yy = 1992/2015 { 
	quietly paretofit emp if emp>0 & year==`yy'
	scalar zeta_emp_`yy' = e(ba)+1
}
scalar zeta_emp_average = (zeta_emp_1992+zeta_emp_1993+zeta_emp_1994+zeta_emp_1995+zeta_emp_1996+zeta_emp_1997+zeta_emp_1998+zeta_emp_1999+zeta_emp_2000+zeta_emp_2001+zeta_emp_2002+zeta_emp_2003+zeta_emp_2004+zeta_emp_2005+zeta_emp_2006+zeta_emp_2007+zeta_emp_2008+zeta_emp_2009+zeta_emp_2010+zeta_emp_2011+zeta_emp_2012+zeta_emp_2013+zeta_emp_2014+zeta_emp_2015)/24

scalar list 

log close
			 
