set more off, perm
set mat 11000
clear all
scalar drop _all
cls

***************************************************************
*                      Load Final Sample
***************************************************************

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

capture log close
log using "${drctory}/temp/reg_mobility.log", text replace

use "${drctory}/input/execucomp/execucomp_final.dta", replace

global xlist ceo_g gender_g l_at roa
egen match_id = group(execid job_n)

tab nc, sum(sep)
tab nc, sum(j2j)

***************************************************************
*                      Separation + J2J
***************************************************************

eststo clear 

xtset gvkey
quietly eststo: xtreg sep nc $xlist i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$" 
estadd local fe_match = " " 

quietly eststo: xtreg sep c.nc#c.bei2009_scaled $xlist i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$" 
estadd local fe_match = " "  

xtset match_id
quietly eststo: xtreg sep c.nc#c.bei_sic3_N $xlist i.year, fe vce(cluster sic3)
estadd local fe_year = "$\surd$"
estadd local fe_firm = " " 
estadd local fe_match = "$\surd$" 

xtset gvkey
quietly eststo: xtreg j2j nc $xlist i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$" 
estadd local fe_match = " " 

quietly eststo: xtreg j2j c.nc#c.bei2009_scaled $xlist i.year, fe vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_firm = "$\surd$" 
estadd local fe_match = " " 

xtset match_id
quietly eststo: xtreg j2j c.nc#c.bei_sic3_N $xlist i.year, fe vce(cluster sic3)
estadd local fe_year = "$\surd$"
estadd local fe_firm = " " 
estadd local fe_match = "$\surd$" 

***************************************************************
*** compile table

esttab using "${drctory}/output/table/reg_mobility_temp.tex", replace ///
se nofloat booktabs nocons b(%9.3f) star(* 0.1 ** 0.05 *** 0.01) ///
keep(nc c.nc#c.bei2009_scaled c.nc#c.bei_sic3_N) ///
order(nc c.nc#c.bei2009_scaled c.nc#c.bei_sic3_N) ///
gaps lines ///
varlabels(nc "Noncompete" ///
		  c.nc#c.bei2009_scaled "Noncompete \$ \times \$ Enforce (State)" ///
		  c.nc#c.bei_sic3_N "Noncompete \$ \times \$ Enforce (Industry)") ///	
stats(fe_year fe_firm fe_match N, fmt(%9.3f %9.3f %9.3f %12.0gc) layout(@ @ @ @) ///
labels("Year FEs" "Firm FEs"  "Firm-Executive FEs" "Observations")) ///
nomtitles eqlabels(none) nonotes 

***************************************************************
*** adjust

file open infile using "${drctory}/output/table/reg_mobility_temp.tex", read
file open outfile using "${drctory}/output/table/reg_mobility.tex", write replace
file read infile line
local i=1
while r(eof)==0 {
	if inlist(`i',5){
		file write outfile "&\multicolumn{3}{c}{Separation (Y/N)} &\multicolumn{3}{c}{Job-to-Job Transition (Y/N)} \\" _n
		file write outfile "\cmidrule(l){2-4} \cmidrule(l){5-7}" _n
		file write outfile "`line'" _n
	}	
	else if inlist(`i',13){
		file write outfile "& \\" _n
	}
	else if inlist(`i',8,10,12){
		file write outfile "`line'" _n
		file write outfile "\addlinespace" _n
	}	
	else {
		file write outfile "`line'" _n
	}		
	file read infile line
	local i=`i'+1
}
file close infile
file close outfile

erase "${drctory}/output/table/reg_mobility_temp.tex"	

log close


