set more off, perm
set mat 11000
clear all
scalar drop _all
cls

***************************************************************
*                      Load Final
***************************************************************

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

capture log close
log using "${drctory}/temp/reg_use.log", text replace

use "${drctory}/input/execucomp/execucomp_final.dta", replace

** generate match level measure
sort execid job_n year
bysort execid job_n: egen ceo_g_ever = max(ceo_g)

sort execid job_n year0
bysort execid: gen nc_last = nc[_n-1] if job_n == job_n[_n-1] +1
bysort execid job_n: egen temp = max(nc_last)
bysort execid job_n: replace nc_last = temp
drop temp


global xlist age ceo_g_ever l_at
sum $xlist
			 
***************************************************************
*                     Regression: BEI
***************************************************************

eststo: reg nc bei2009_scaled $xlist i.sic i.year if t==1, vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_industry = "$\surd$"
estadd local fe_firm = " "
estadd local fe_executive = " "

***************************************************************
*                     Regression: Selection Effect?
***************************************************************

** run on subsample of executives with at least 2 jobs
** use sic2 (can't use narrower industry category, not enough observation)
xtset execid
eststo: xtreg nc bei2009_scaled $xlist i.year if t==1, fe vce(robust)
estadd local fe_year = "$\surd$"
estadd local fe_industry = " "
estadd local fe_firm = " "
estadd local fe_executive = "$\surd$"

eststo: reg nc bei2009_scaled nc_last $xlist i.year if t==1, vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_industry = " "
estadd local fe_firm = " "
estadd local fe_executive = " "

***************************************************************
*                     Regression: BEI-Industry Weigthed
***************************************************************

eststo: ivreg2 nc bei_sic3_N bei2009_scaled $xlist i.sic i.year if t==1, cluster(state sic3)
estadd local fe_year = "$\surd$"
estadd local fe_industry = "$\surd$"
estadd local fe_firm = " "
estadd local fe_executive = " "

xtset gvkey
eststo: xtreg nc bei_sic3_N $xlist i.year if t==1, fe vce(cluster sic3)
estadd local fe_year = "$\surd$"
estadd local fe_industry = " "
estadd local fe_firm = "$\surd$"
estadd local fe_executive = " "

***************************************************************
*                     Regression: Non-Compete Duration
***************************************************************

eststo: reg dur_max bei2009_scaled $xlist i.sic i.year if t==1, vce(cluster state)
estadd local fe_year = "$\surd$"
estadd local fe_industry = "$\surd$"
estadd local fe_firm = " "
estadd local fe_executive = " "

***************************************************************
*** compile table

esttab using "${drctory}/output/table/reg_use_temp.tex", replace ///
se nofloat booktabs nocons b(%9.3f) star(* 0.1 ** 0.05 *** 0.01) ///
keep(bei2009_scaled bei_sic3_N nc_last) ///
order(bei2009_scaled bei_sic3_N nc_last) ///
gaps lines ///
varlabels(bei2009_scaled "Enforce (State)" ///
		  bei_sic3_N "Enforce (Industry)" ///
		  nc_last "Noncompete (Previous Job)") ///
stats(fe_year fe_industry fe_firm fe_executive N, fmt(%9.3f %9.3f %9.3f %9.3f %12.0gc) layout(@ @ @ @ @) ///
labels("Year FEs" "Industry FEs" "Firm FEs" "Executive FEs" "Observations")) ///
nomtitles eqlabels(none) nonotes

***************************************************************
*** adjust

file open infile using "${drctory}/output/table/reg_use_temp.tex", read
file open outfile using "${drctory}/output/table/reg_use.tex", write replace
file read infile line
local i=1
while r(eof)==0 {
	if inlist(`i',5){
		file write outfile "&\multicolumn{5}{c}{Noncompete (Y/N)} &\multicolumn{1}{c}{Duration} \\" _n	
		file write outfile "\cmidrule(l){2-6} \cmidrule(l){7-7}" _n			
		file write outfile "&\multicolumn{1}{c}{Baseline} &\multicolumn{2}{c}{Job-Changers} &\multicolumn{2}{c}{Cross-State Enforce} & \\" _n			
		file write outfile "\cmidrule(l){2-2} \cmidrule(l){3-4} \cmidrule(l){5-6} \cmidrule(l){7-7}" _n	
		file write outfile "`line'" _n
	}	
	else if inlist(`i',13){
		file write outfile "& \\" _n
	}	
	else if inlist(`i',8,10,12){
		file write outfile "`line'" _n
		file write outfile "\addlinespace" _n
	}
	else {
		file write outfile "`line'" _n
	}		
	file read infile line
	local i=`i'+1
}
file close infile
file close outfile

erase "${drctory}/output/table/reg_use_temp.tex"

log close
			 
