
***************************************************************
*                      Filtering
***************************************************************


* exclude financial firms
drop if sic>=6000 & sic<=6999
* exclude firms in regulated industries
drop if sic>=4900 & sic<=4999
* exlcude firms categorized as public service, international affairs, or non-operating establishments
drop if sic>=9000

* exclude firms with acquisition activities: sales or asset growth>100%
gen ind = 0
replace ind = 1 if g_at1>1 | g_revt1>1
drop if ind == 1
drop ind

* exclude firms with missing or non-positive book value of assets or sales 
gen ind_temp = 0
replace ind_temp = 1 if mi(at) | mi(revt) | ppegt<=.5
quietly bysort gvkey: egen ind = max(ind_temp)
* drop if ind == 1
drop if ind_temp == 1
drop ind_temp ind

drop if inlist(compst,"AA","AB","AR","AS","AT")

/*
Description
AA - Data reflects a merger or acquisition
AB - Data reflects a major merger resulting in the formation of a new company.
AC - Data reflects an accounting change
AD - Missing quarter (period) has not been derived due to discontinued operations
AF - Combination AA and AN
AG - Combination AC and AN
AH - Combination AN and AZ
AN - Data reflects the adoption of new accounting principles and presentation methods pursuant to revised national regulations and guidelines
AQ - Combination AC & SQ - Reflects an accounting change and reflects that Semi-annual I/S and C/F data is allocated over missing quarters and B/S data is carried over to missing quarter
AR - Combination AA and AZ
AS - Combination AA and AC
AT - Combination AC and AZ
AU - Combination AD and DB
AZ - Data excludes discontinued operations (North America); data reflects disposals (outside North America)
CA - Includes six months of a merger or acquisition
CB - Includes nine months of a merger or acquisition
CC - Includes 12 months of a merger or acquisition
CE - Excludes six months of discontinued operations
CF - Excludes nine months of discontinued operations
CG - Excludes 12 months of discontinued operations
DB - Company has undergone a fiscal year change. Some or all data may not be available
DZ - Company has been in operation for less than one year. Some or all data may not be available
IP - Company has undergone an initial public offering
SQ - Semi-annual I/S and C/F data is allocated over missing quarters and B/S data is carried over to missing quarter
Unless otherwise noted, all material is © 1993 - 2019, The Wharton School, University of Pennsylvania. All rights reserved.
*/


