set more off, perm
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

capture log close
log using "${drctory}/temp/fig_use.log", text replace

use "${drctory}/input/aggregate_data/nc_state.dta", replace

* save a csv copy of the data for matlab plot:
export delimited using "${drctory}/input/aggregate_data/nc_state", replace

***************************************************************
*                     Fraction with Noncompete                *
***************************************************************

reg nc_mean bei2009_scaled
mat mytable = r(table)
mat list mytable
local b: display %5.2f mytable[1,1]
local p: display %5.2f mytable[4,1]
local r2: display %5.2f e(r2)

twoway ///
	(lfitci nc_mean bei2009_scaled, clcolor(black) clwidth(medthick) afcolor(gs15) alcolor(gs16)) /// 
	(scatter nc_mean bei2009_scaled [aw=num_match], msymbol(circle_hollow) color("0 0 153")) ///
	(scatter nc_mean bei2009_scaled, ms(i) mlabel(state) mlabsize(medium) mlabcolor(black) mlabposition(12)), ///
	legend(off) ///
	text(1 -0.08 "Slope:" ///
				 "{it:p-}value:" ///
				 "{it:R}{sup:2}:", ///
				 size(medlarge) color(black) place(se) just(left) box fcolor(none) linegap(1.5) margin(1 10 1 1)) ///		
	text(1 0.08 "`b'" ///
				"`p'" ///
				"`r2'", ///
				size(medlarge) color(black) place(se) just(left) fcolor(none) linegap(1.5) margin(1 1 1 1)) ///						
	ytitle("Proportion with a noncompete clause", margin(0 4 -9 0) size(vlarge)) ///
	xtitle("Enforcement index", margin(0 0 0 4) size(vlarge)) ///
	ylabel(0(0.2)1, angle(0) grid glc("250 250 250") glw(thin) labsize(large)) ///
	ymtick(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(3.3)
graph export "${drctory}/output/figure/nc_state.eps", replace

***************************************************************
*                     Noncompete Duration                     *
***************************************************************

reg dur_max_mean bei2009_scaled
mat mytable = r(table)
mat list mytable
local b: display %5.2f mytable[1,1]
local p: display %5.2f mytable[4,1]
local r2: display %5.2f e(r2)

twoway ///
	(lfitci dur_max_mean bei2009_scaled, clcolor(black) clwidth(medthick) afcolor(gs15) alcolor(gs16)) /// 
	(scatter dur_max_mean bei2009_scaled [w=num_dur], msymbol(circle_hollow) color("0 0 153")) ///
	(scatter dur_max_mean bei2009_scaled, ms(i) mlabsize(medium) mlabel(state) mlabcolor(black) mlabposition(12)), ///
	legend(off) ///
	text(3 -0.08 "Slope:" ///
				 "{it:p-}value:" ///
				 "{it:R}{sup:2}:", ///
				    size(medlarge) color(black) place(se) just(left) box fcolor(none) linegap(1.5) margin(1 10 1 1)) ///		
	text(3 0.08 "`b'" ///
				"`p'" ///
				"`r2'", ///
				size(medlarge) color(black) place(se) just(left) fcolor(none) linegap(1.5) margin(1 1 1 1)) ///			
	ytitle("Avearge duration, years", margin(0 4 0 0) size(vlarge)) ///
	xtitle("Enforcement index", margin(0 0 0 4) size(vlarge)) ///
	ylabel(0(.5)3,angle(0) grid glc("250 250 250") glw(thin) labsize(large)) ///
	ymtick(1(.5)3, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(0(.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(0(.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(3.3)
graph export "${drctory}/output/figure/dur_state.eps", replace

***************************************************************
*                     Index over Time
***************************************************************

use "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/build/output/bei.dta", replace

label define statel 01 "AL" 02 "AK" 04 "AZ" 05 "AR" 06 "CA" 08 "CO" 09 "CT" 10 "DE" 11 "DC" 12 "FL" 13 "GA" 15 "HI" 16 "ID" 17 "IL" ///
					18 "IN" 19 "IA" 20 "KS" 21 "KY" 22 "LA" 23 "ME" 24 "MD" 25 "MA" 26 "MI" 27 "MN" 28 "MS" 29 "MO" 30 "MT" 31 "NE" ///
					32 "NV" 33 "NH" 34 "NJ" 35 "NM" 36 "NY" 37 "NC" 38 "ND" 39 "OH" 40 "OK" 41 "OR" 42 "PA" 44 "RI" 45 "SC" 46 "SD" ///
					47 "TN" 48 "TX" 49 "UT" 50 "VT" 51 "VA" 53 "WA" 54 "WV" 55 "WI" 56 "WY" 
label values state statel

twoway ///
	(scatteri -4.4 -4.4 2 2, recast(line) lw(medthick) color(gs5)) ///	
	(scatter bei1991 bei2009, color("0 0 153")) ///
	(scatter bei1991 bei2009, ms(i) mlabsize(medium) mlabel(state) mlabcolor(black) mlabposition(12)), ///
	legend(off) ///
	ytitle("Raw enforcement index, 2009", margin(0 4 0 0) size(vlarge)) ///
	xtitle("Raw enforcement index, 1991", margin(0 0 0 4) size(vlarge)) ///
	ylabel(-4(1)2, angle(0) grid glc("250 250 250") glw(thin) labsize(large)) ///
	ymtick(-4(1)2, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(-4(1)2, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(-4(1)2, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(2.5)
graph export "${drctory}/output/figure/bei_1991_2009.eps", replace

***************************************************************
*                     Noncompete Over Time
***************************************************************

use "${drctory}/input/aggregate_data/nc_year.dta", replace
gen nc_avg = 0.64
twoway ///
	(line nc year, color("0 0 153") lw(medthick)) ///
	(line nc_avg year, lp(dash) lw(thin) color(black)), ///	
	text(0.65 2005 "average: 64%", size(large) color(black)  place(e)) ///	
	legend(off) ///
	ytitle("Proportion with a noncompete clause", margin(0 4 -9 0) size(vlarge)) ///
	xtitle("Year", margin(0 0 0 4) size(vlarge)) ///
	ylabel(0.56(0.02)0.68, grid glc("250 250 250") glw(thin) labsize(large)) ///
	ymtick(0.56(0.02)0.68, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(1995(5)2015, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(1995(5)2015, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(3.3)
graph export "${drctory}/output/figure/nc_year.eps", replace

***************************************************************
*                  Noncompete Over Time by State              *
***************************************************************

local en_dash = ustrunescape("\u2013")

use "${drctory}/input/aggregate_data/nc_state_year.dta", replace
twoway ///
	(scatter nc_p2 nc_p1 [aw=num_match], msymbol(circle_hollow) color("0 0 153")) ///
	(scatter nc_p2 nc_p1, ms(i) mlabsize(medium) mlabel(state) mlabcolor(black) mlabposition(12)) ///
	(line nc_p2 nc_p2, color(black) lwidth(medthick)), ///
	legend(off) ///	
	ytitle("Proportion with a noncompete" "clause, 2012-2015", margin(0 4 0 0) size(vlarge)) ///
	xtitle("Proportion with a noncompete clause, 1992-1995", margin(-6 0 0 4) size(vlarge)) ///
	ylabel(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	ymtick(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xlabel(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	xmtick(0(0.2)1, grid glc("250 250 250") glw(thin) labsize(large)) ///
	plotregion(color(white) lcolor(white) ilcolor(white)) ///
	graphregion(color(white) lcolor(white) ilcolor(white)) aspectratio(1) ///
	bgcolor(white)
graph display, ysize(2.5) xsize(3.5)
graph export "${drctory}/output/figure/nc_state_time.eps", replace

log close
