set more off, perm
set mat 11000
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/analysis"

use "${drctory}/input/execucomp/execucomp_final.dta", replace

capture log close
log using "${drctory}/temp/summary_statistics.log", text replace


***************************************************************
*                      Executive
***************************************************************

preserve
bysort execid job_n: keep if _n==_N

quietly sum nc
scalar stat_frac_1 = r(N)
scalar stat_frac_2 = 100
scalar stat_frac_3 = (1-r(mean))*100
scalar stat_frac_4 = r(mean)*100

quietly sum dur_max
scalar stat_dur_1 = r(N)
scalar stat_dur_4 = r(mean)

local varlist age_join T
foreach var of local varlist {
	quietly sum `var'
	scalar stat_`var'_1 = r(N)	
	scalar stat_`var'_2 = r(mean)	
	quietly sum `var' if nc == 0
	scalar stat_`var'_3 = r(mean)
	quietly sum `var' if nc == 1
	scalar stat_`var'_4 = r(mean)
	quietly ttest `var', by(nc) 
	scalar stat_`var'_5 = r(t)	
}
restore

cap drop temp_id
egen temp_id = group(execid job_n)

local varlist sep j2j j2j_within j2j_cross 	
foreach var of local varlist {

	quietly sum `var'
	scalar stat_`var'_1 = r(N)	
	scalar stat_`var'_2 = r(mean)*100
	quietly sum `var' if nc == 0
	scalar stat_`var'_3 = r(mean)*100
	quietly sum `var' if nc == 1
	scalar stat_`var'_4 = r(mean)*100
	quietly ttest `var', by(nc) 
	scalar stat_`var'_5 = r(t)	
}

matrix sum_stat=J(8,5,.)
matrix sum_stat[1, 1] = stat_frac_1
matrix sum_stat[1, 2] = stat_frac_2
matrix sum_stat[1, 3] = stat_frac_3
matrix sum_stat[1, 4] = stat_frac_4
matrix sum_stat[2, 1] = stat_dur_1
matrix sum_stat[2, 4] = stat_dur_4

local varlist age_join T sep j2j j2j_within j2j_cross
forvalues c=1(1)5 {
	local r=3
	foreach var of local varlist {		
		matrix sum_stat[`r', `c'] = stat_`var'_`c'
		local r=`r'+1
	}
}

matrix list sum_stat
frmttable using  "${drctory}/output/table/summary_statistics_temp.tex", ///
tex fragment nocenter plain hlines(0) statmat(sum_stat) ///
sdec( 0,0,0,0,0 \ 0,1,1,1,1 \ 0,1,1,1,2 \ 0,1,1,1,2 \ 0,2,2,2,2 \ 0,2,2,2,2 \ 0,2,2,2,2 \ 0,2,2,2,2) ///
sfmt( "fc" \ "fc" \ "fc" \ "fc" \ "fc" \ "fc" \ "fc" \ "fc") replace /// 
rtitles("Fraction (\%)" \ ///
		"Duration (year)" \ ///
		"Age joined" \ ///
		"Tenure" \ ///
		"Separation rate (\%)" \ /// 			
		"Job-to-job transition rate (\%)" \ ///
		"-- within industry" \ ///
		"-- between industry")	
		
***************************************************************
*                      Firm
***************************************************************

preserve 
do "${drctory}/code/reg/sub_filter_firm2.do"

local varlist at emp revt inv_phy inv_int l_tobinq cash roa
foreach var of local varlist {
	quietly sum `var'
	scalar stat_`var'_1 = r(N)	
	scalar stat_`var'_2 = r(mean)		
	quietly sum `var' if nc == 0
	scalar stat_`var'_3 = r(mean)
	quietly sum `var' if nc == 1
	scalar stat_`var'_4 = r(mean)
	quietly ttest `var', by(nc)
	scalar stat_`var'_5 = r(t)
}

matrix sum_stat=J(8,5,.)
local varlist at emp revt inv_phy inv_int l_tobinq cash roa
forvalues c=1(1)5 {
	local r=1
	foreach var of local varlist {
		matrix sum_stat[`r', `c'] = stat_`var'_`c'
		local r=`r'+1	
	}
}
matrix list sum_stat
frmttable using "${drctory}/output/table/summary_statistics_temp.tex", ///
tex fragment nocenter hlines(0) statmat(sum_stat) ///
sdec(0,0,0,0,2 \ 0,0,0,0,2 \ 0,0,0,0,2 \ 0,3,3,3,2 \ 0,3,3,3,2 \ 0,2,2,2,2 \ 0,2,2,2,2 \ 0,3,3,3,2) ///
sfmt( "fc" \ "fc" \ "fc" \ "fc" \ "fc" \ "fc" \ "fc" \ "fc") append /// 
rtitles("Asset (mn)"  \ ///
		"Emploment (thousands)" \ ///
		"Sales (mn)"  \ ///		
		"Phyiscal investment" \ ///
		"Intangible investment" \ ///
		"Tobin's Q" \ ///
		"Cash flow" \ ///
		"ROA")
restore
		
***************************************************************
*                      Compensation
***************************************************************

local varlist tdc1 tdc2 current deferred

foreach var of local varlist {
	quietly sum `var'
	scalar stat_`var'_1 = r(N)	
	scalar stat_`var'_2 = r(mean)	
	quietly sum `var' if nc == 0
	scalar stat_`var'_3 = r(mean)
	quietly sum `var' if nc == 1
	scalar stat_`var'_4 = r(mean)
	quietly ttest `var',by(nc)
	scalar stat_`var'_5 = r(t)	
}

matrix sum_stat=J(4,5,.)
forvalues c=1(1)5 {
	local r=1
	foreach var of local varlist {
		matrix sum_stat[`r', `c'] = stat_`var'_`c'
		local r=`r'+1	
	}
}
matrix list sum_stat
frmttable using  "${drctory}/output/table/summary_statistics_temp.tex", ///
tex fragment nocenter hlines(0) statmat(sum_stat) ///
sdec( 0,2,2,2,2) ///
sfmt( "fc" ) append /// 
rtitles("Awarded compensation (mn)" \ ///
		"Realized compensation (mn)" \ ///
		"-- cash" \ ///
		"-- deferred equity")
		

***************************************************************
*                      Adjust
***************************************************************

file open infile using "${drctory}/output/table/summary_statistics_temp.tex", read
file open outfile using "${drctory}/output/table/summary_statistics.tex", write replace
file read infile line
local i=1
while r(eof)==0 {
	if inlist(`i', 1){
		file write outfile "\begin{tabular}{>{\quad}lccccc}" _n
		file write outfile "\toprule" _n		
		file write outfile " & \multirow{2}{*}{N. Obs.} & \multirow{2}{*}{All}  & \multicolumn{2}{c}{Noncompete} & \multicolumn{1}{c}{t-stat.} \\" _n  
		file write outfile "\cmidrule(l){4-5}" _n
		file write outfile "& & & No & Yes & (diff.) \\" _n	
		file write outfile "\midrule" _n
	}
	else if inlist(`i', 3) {
		file write outfile "`line'" _n
		file write outfile "& & & & &\\" _n	
		file write outfile "\rowgroup{\itshape Executive Characteristics} \\" _n	
	}	
	else if inlist(`i', 9) {
		file write outfile "`line'" _n
		file write outfile "& & & & & \\" _n	
		file write outfile "\rowgroup{\itshape Firm Characteristics} \\" _n	
	}	
	else if inlist(`i', 17) {
		file write outfile "`line'" _n
		file write outfile "& & & & & \\" _n	
		file write outfile "\rowgroup{\itshape Compensation} \\" _n	
	}	
	else if inlist(`i', 22) {
		file write outfile "\bottomrule" _n	
		file write outfile "\end{tabular}"
	}
	else {
		file write outfile "`line'" _n
	}		
	file read infile line
	local i=`i'+1
}
file close infile
file close outfile

erase "${drctory}/output/table/summary_statistics_temp.tex"		
	
log close 
