set more off, perm
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/build"

capture log close
log using "${drctory}/temp/clean_compustat_4exec.log", text replace

***************************************************************
*                      Load                                   *
***************************************************************

insheet using "${drctory}/input/compustat/compustat_annual.csv"

***************************************************************
*                      Redefine Time                          *
***************************************************************

rename fyear year
rename fyr month

gen temp_year = year 
replace temp_year = . if mi(prcc_f)
sort gvkey year
by gvkey: egen ipo_year = min(temp_year)
drop temp_year

***************************************************************
*                   Keep Relevant Variables                   *
***************************************************************

** Key Variable Definition

* Identifying Information
// gvkey:     
// cik:
// cusip: 
// conm:    company name
// datadate:

// fic:    	ISO Country Code - Incorporation. Alternative, loc: ISO Country Code - Headquarters
// state:
// gsector: first level in the hierarchy of the Global Industry Classification Standard (GICS)
// ggroup:  the second level in the hierarchy of the Global Industry Classification Standard (GICS)
// gind:    the third level in the hierarchy of the Global Industry Classification Standard (GICS)
// gsubind: the fourth level in the hierarchy of the Global Industry Classification Standard (GICS)
// 
// naics:   a single production-oriented or supply-based conceptual framework and provides comparability in statistics about business activity acros North America
// sic:    	6000-6999 financials; 4900-4999 utilities

* Balance Sheet Items
// at:     	Assets - Total
// act:    	Current Assets - Total
// aqa:     Acquisition/Merger After-tax
// aqc:     Acquisitions
// che:    	Cash and Short-Term Investments 
// ceq: 	Common/Ordinary Equity - Total
// ceql:	Common Equity - Liquidation Value
// ceqt: 	Common Equity - Tangible
// dlc:    	Debt in Current Liabilities - Total
// dltt:   	Long-Term Debt - Total
// dpact:	Depreciation, Depletion and Amortization (Accumulated)
// intan:	Intangible Assets - Total
// ppegt:  	Property, Plant and Equipment - Total (Gross)
// ppent:  	Property, Plant and Equipment - Total (Net)
// wcap: 	Working Capital (Balance Sheet)
// invt:    Inventories - Total
// invrm:   Inventories Raw Materials
// prcc_f:  Price Close - Annual - Fiscal
// csho:    Common Shares Outstanding
// ceq:     Common/Ordinary Equity - Total
// txdb:    Deferred Taxes (Balance Sheet)

* Income Statement Items
// cogs: 	Cost of Goods Sold
// dfxa: 	Depreciation of Tangible Fixed Assets
// dp:     	Depreciation and Amortization
// gp:		Gross Profit (Loss)
// oibdp: 	Operating Income Before Depreciation
// ib:      Income Before Extraordinary Items
// pi:      Pretax Income
// pifo:   	Pretax Income Foreign
// ni:      Net Income
// revt:   	Revenue
// sale:	Sales/Turnover (Net)
// 			Note: revt and sale are broadly identical. revt has issues with double entry. sale has more missing values. suggest we use revt
// xrd:    	Research and Development Expense
// xsga:   	Selling, General and Administrative Expense
// xstf:    Staff Expense (Income Account)
// xstfo:   Staff Expense - Other
// xstfws:	Staff Expense - Wages and Salaries

* Cash Flow Items
// capx:   	Capital Expenditures
// capxv: 	Capital Expenditures Property, Plant and Equipment (Schedule V)
// depc:	Depreciation and Depletion (Cash Flow)
// dpc:		Depreciation and Amortization (Cash Flow)
// sppe:    Sale of Property

* Miscellaneous Items
// emp: 	Employees, in thousands

* Filtering Criteria
// US firms with nonmissing & positive book value of total assets and sales revenue, excluding financials and utilities, from 1970 and onwards

* Flags
* stalt: indicates whether the company is in bankruptcy or undergoing a leveraged buyout.
* dlrsn: indicates the reason a company become inactive on the database. Inactive issues remain on the database but are no longer updated.
* dldte: the effective date (month and year) of the acquisition, merger, liquidation, or other reason for deletion
* compst: two-character code that describes conditions under which data in one period may not be comparable to data in another period
* acqmeth: identifies the method a company uses to account for acquisitions
* idbflag: the source of data for the company.
* stko: the stock ownership of each company.
* upd: identifies the updated status of data for the period

** Age (define an entrant as a firm that reports a fiscal year-end value of the stock price for the first time (item PRCC F))

rename cusip cusip9

keep gvkey cik cusip9 conm datadate year ipo_year ///
	 fic state naics sic ///
	 stalt dlrsn dldte compst acqmeth idbflag stko upd ///	 
	 act at dlc dltt intan ppegt ppent invt invrm prcc_f ceq txdb ///
	 sale revt cogs gp oibdp pi ni capx xrd xsga xstfws sppe dp ib ///
	 csho emp
	 
order gvkey cik cusip9 conm datadate year ipo_year ///
	 fic state naics sic ///
	 stalt dlrsn dldte compst acqmeth idbflag stko upd ///	 
	 act at dlc dltt intan ppegt ppent invt invrm prcc_f ceq txdb ///
	 sale revt cogs gp oibdp pi ni capx xrd xsga xstfws sppe dp ib ///
	 csho em

***************************************************************
*            Drop duplicate gvkey year observation            *
***************************************************************

tab upd

gsort gvkey year -upd
quietly by gvkey: egen yearT_co = max(year)
quietly by gvkey year: gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup

tab upd

***************************************************************
*                      Geographic Location                    *
***************************************************************

**  don't drop non-US companies yet, merge all firm-level data onto execucomp 
** (past employment could be abroad)

***************************************************************
*                   Merge with Compustat Intangible           *
***************************************************************

tostring datadate, replace
gen edate_master = date(datadate, "YMD")

merge 1:1 gvkey year using "${drctory}/output/compustat/compustat_intangible.dta", keep(master match)

* check merge results
sort gvkey year
by gvkey year: egen x1=max(_merge==1)
by gvkey year: egen x2=max(_merge==2)
gen x=x1+x2
tab x
drop x1 x2 x

drop _merge

* check the reporting dates: Compustat Annual v.s. Compustat Intangible
gen temp = edate_master==edate
tab temp
drop temp

***************************************************************
*                      Deflate Nomial Variables               *
***************************************************************

merge m:1 year using "${drctory}/output/cpi.dta", keep(master match) keepusing(cpi)
drop _merge

local vars act at dlc dltt intan ppegt ppent invt invrm prcc_f ceq txdb ///
		   sale revt cogs gp oibdp pi ni capx xrd xsga xstfws sppe dp ib ///	
		   k_int_know k_int_org k_int_offbs k_int
		   
foreach var of varlist `vars' {
	replace `var' = `var'/cpi
}

drop cpi
sum

***************************************************************
*                   Relabel State                             *
***************************************************************

do "${drctory}/code/1_clean_compustat/1sub_state_label.do"

***************************************************************
*                    Create Firm Measure 					  *
***************************************************************

do "${drctory}/code/1_clean_compustat/1sub_firm_measure.do"

***************************************************************
*           Merge with Bishara enforcement index              *
***************************************************************

merge m:1 state using "${drctory}/output/bei.dta", keep(master match)
drop _merge

***************************************************************
*                      Save                                   *
***************************************************************

save "${drctory}/output/compustat/compustat_4exec.dta", replace

log close 
