set more off, perm
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/build"

capture log close
log using "${drctory}/temp/2_clean_boardex_company.log", text replace

***************************************************************
*                      Load                                   *
***************************************************************

insheet using "${drctory}/input/boardex/company_profile.csv"

** keep public and private firms
** private firms also have cik information etc to be matched to gvkey
** this allows to measure employment transitions more accurately as firms go public or private
keep if inlist(orgtype, "Quoted","Private") & hocountryname == "United States"
tab orgtype

** 1. cik --> gvkey
** 2. ticker --> gvkey
** 3. ticker --> again (DUE TO CHANGE IN TICKERS)
** potentially could also use isin

keep boardname orgtype cikcode boardid ticker isin
duplicates drop
rename cikcode cik 
codebook cik

***************************************************************
*                      First Merge: by cik
***************************************************************

merge m:1 cik using "${drctory}/output/link/gvkey_cik_link.dta", keep(match master)
tab orgtype _merge
drop _merge

** some issue with cik == . merging to some good gvkey 
replace gvkey = . if cik == .

***************************************************************
*                      Second Merge: by tic
***************************************************************

gen tic=ticker if mi(gvkey)
rename gvkey gvkey1

merge m:1 tic using "${drctory}/output/link/gvkey_tic_link.dta", keep(match master)
tab orgtype _merge
drop _merge

cap drop temp
gen temp = 1 if !mi(gvkey) & !mi(gvkey1)
sum temp
drop temp

replace gvkey = gvkey1 if mi(gvkey)
drop gvkey1 tic

***************************************************************
*                      Third Merge: by ticker
***************************************************************

gen tic=ticker if mi(gvkey)
rename gvkey gvkey1

merge m:1 tic using "${drctory}/output/link/more_links.dta", keep(match master)
tab orgtype _merge
drop _merge

cap drop temp
gen temp = 1 if !mi(gvkey) & !mi(gvkey1)
sum temp
drop temp

replace gvkey = gvkey1 if mi(gvkey)
drop gvkey1 tic

***************************************************************
*                      Some Further modify
***************************************************************

** could be that gvkey was merged later using ticker, for some cik merges private company gvkey missing
cap drop temp
bysort cik: egen temp = mode(gvkey), maxmode
replace gvkey = temp if mi(gvkey) & !mi(cik)
drop temp

cap drop temp
bysort boardid: egen temp = mode(gvkey), maxmode
replace gvkey = temp
drop temp

***************************************************************
*                      Save Separation: with or without gvkey
***************************************************************

keep boardname boardid gvkey orgtype
duplicates drop

preserve
keep if !mi(gvkey)
count
export delimited using "${drctory}/output/boardex/company_profile1.csv", replace
restore

preserve
keep if mi(gvkey) & orgtype=="Private"
count
export delimited using "${drctory}/output/boardex/company_profile2.csv", replace
restore

***************************************************************
*                    USE 2.1 to match names in python
* 	                 USE 2.2 
*                    USE 2.3 to clean matched names
***************************************************************

***************************************************************
*                     Merge the matched names in python
***************************************************************

merge m:1 boardid using "${drctory}/output/boardex/matched_bdex_company_filter.dta"
** gvkey_type == 1 meaning the gvkey information is indirect
gen gvkey_type = 1 if _merge==3
replace gvkey = gvkey_matched if _merge==3
replace boardid_matched = boardid if _merge==1
drop _merge

drop boardname_matched gvkey_matched 

rename boardid companyid
rename boardid_matched companyid_matched

***************************************************************
*                      Save                                   *
***************************************************************

save "${drctory}/output/boardex/company_profile.dta", replace

log close 


