set more off, perm
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/build"

capture log close
log using "${drctory}/temp/4_create_boardex_employment_history.log", text replace

use "${drctory}/output/boardex/individual_employment.dta", replace

keep if inlist(orgtype, "Partnership", "Private", "Quoted")

***************************************************************
*                      Merge Individual Profile
***************************************************************

merge m:1 directorid using "${drctory}/output/boardex/individual_profile.dta", keep(master match)
drop _merge 

***************************************************************
*                      Merge with Names Matched to Execucomp
***************************************************************

merge m:1 directorid using "${drctory}/output/boardex/matched_name_filter.dta"
keep if _merge == 3
drop _merge

keep directorid directorname execid gvkey companyid companyid_matched companyname orgtype gvkey_type dob dod nationality ned brdposition rolename datestartrole dateendrole
order directorid directorname execid gvkey companyid companyid_matched companyname orgtype gvkey_type dob dod nationality ned brdposition rolename datestartrole dateendrole
duplicates drop

cap drop temp
bysort execid: egen temp = mode(dob), maxmode
replace dob = temp
drop temp

cap drop temp
bysort execid: egen temp = mode(dod), maxmode
replace dod = temp
drop temp

cap drop temp
bysort execid: egen temp = mode(nationality), maxmode
replace nationality = temp
drop temp

***************************************************************
*                      Filter by rolename
***************************************************************

drop if ned=="Yes"
drop if brdposition=="Outisde" & ned=="No"
drop ned

local roles `" "Emeritus" "Honor" "Board" "Investor" "'

foreach role of local roles {
	drop if strpos(rolename, "`role'")>0
}

***************************************************************
*                      Filter by Employment Dates
***************************************************************

* drop missing dates
drop if datestartrole == "N" 
drop if dateendrole == "N"

* change to stata date display
gen start_ddate=daily(datestartrole, "YMD")
gen end_ddate=daily(dateendrole, "YMD")

* drop negative duration (tiny fraction)
sort execid start_ddate end_ddate
gen duration = end_ddate-start_ddate
drop if duration<=0

* sort by execid company match starting time
* need to check that: sorting by "companyid_matched" is fine
bysort execid companyid_matched: egen start_min = min(start_ddate)
sort execid start_min companyid_matched start_ddate end_ddate

** check gap between change of roles or companies
by execid: gen gap = start_ddate[_n]-end_ddate[_n-1]
* check whether gaps are reasonable!
cap drop temp
gen temp = 0 if !mi(gap) & gap==0
replace temp=1 if !mi(gap) & gap>90
replace temp=-1 if !mi(gap) & gap<0
drop temp

***************************************************************
*             Define Became CEO and Left as CEO 
***************************************************************

* check CEO title variations - this part is tricky! which ones to count as CEO role
cap drop temp_rolename temp
gen temp_rolename = rolename if strpos(rolename, "CEO")>0  & ///
					   strpos(rolename, "Regional CEO")==0 & ///
					   strpos(rolename, "Division CEO")==0 & ///
					   strpos(rolename, "Regional Co-CEO")==0 & ///
					   strpos(rolename, "Regional Deputy CEO")==0 & ///
					   strpos(rolename, "Division Co-CEO")==0 & ///
					   strpos(rolename, "Division Acting CEO")==0 & ///
					   strpos(rolename, "Division Group CEO")==0 & ///
					   strpos(rolename, "Division Interim CEO")==0							   
tab temp_rolename
gen temp = 1 if !mi(temp_rolename)
sort execid companyid_matched start_ddate
* define as starting time if it is the first role that contains "CEO"
by execid companyid_matched: gen becameceo_bdex = datestartrole if (temp==1 & temp[_n-1]==0) | (temp==1 & _n==1)
* define as leaving time if it is the last role that contains "CEO"
by execid companyid_matched: gen leftofc_bdex = dateendrole if (temp==1 & temp[_n+1]==0) | (temp==1 & _n==_N & dateendrole!="C")
drop temp_rolename temp

cap drop temp
by execid companyid_matched: egen temp = mode(becameceo_bdex), maxmode
replace becameceo_bdex = temp
drop temp

cap drop temp
by execid companyid_matched: egen temp = mode(leftofc_bdex), maxmode
replace leftofc_bdex = temp
drop temp

***************************************************************
*                      Turn into Panel
***************************************************************

* define start year end year adjusting for time of the year
gen start_year = substr(datestartrole,1,4)
gen start_month = substr(datestartrole,5,2)
gen end_year = substr(dateendrole,1,4)
gen end_month = substr(dateendrole,5,2)
destring start_year end_year start_month end_month, force replace
replace start_year = start_year+1 if start_month == 12
replace end_year = end_year-1 if end_month == 1

* if next role starts in the same year, adjust
cap drop temp
by execid: gen temp = 1 if start_year[_n+1]==end_year[_n]
replace end_year = end_year-1 if temp==1 & end_month<6
drop temp
by execid: gen temp = 1 if start_year[_n]==end_year[_n-1]
replace start_year = start_year+1 if temp==1 & start_month>=6
drop temp

drop if end_year<start_year

* if dateendrole= C, then set end_year=2017
replace end_year=2017 if dateendrole=="C"

* each exec-manager-role as an observation
gen obs_id = _n
expand 2
bysort execid obs_id: gen year=start_year if _n==1
bysort execid obs_id: replace year=end_year if _n==2
* drop duplicates when start_year==end_year
duplicates drop 
** fill in gaps between years
tsset obs_id year
tsfill

** fill in missing info
sort obs_id year
by obs_id: carryforward execid directorid directorname gvkey companyid companyid_matched companyname orgtype gvkey_type dob dod nationality ///
						brdposition rolename datestartrole dateendrole start_ddate end_ddate duration gap start_year end_year start_min, replace
sort execid start_ddate companyid end_ddate 

***************************************************************
*                      Save Data
***************************************************************

keep execid directorid directorname gvkey companyid companyid_matched companyname orgtype gvkey_type dob dod nationality ///
	 rolename datestartrole dateendrole becameceo_bdex leftofc_bdex start_ddate end_ddate duration gap start_year end_year year
save "${drctory}/output/boardex/boardex_employment4execucomp.dta", replace

log close

