set more off, perm
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical/build"

capture log close
log using "${drctory}/temp/1_clean_execucomp.log", text replace


***************************************************************
*                      Load									  *
***************************************************************

insheet using "${drctory}/input/execucomp/execucomp_annual.csv"

***************************************************************
* Save a list of executive names to merge with the ones in boardex
* this step needs to be run before boardex 3.1_match_name.py
***************************************************************

/*
preserve
keep execid exec_fullname gvkey coname co_per_rol
duplicates drop 
count
sort gvkey execid
export delimited using "${drctory}/output/execucomp/name_list.csv", replace
restore
*/

***************************************************************
*                      A few simple operations
***************************************************************

** check the compensation rank of executives within a firm (execrankann)
order gvkey year execrankann tdc1 tdc2
sort gvkey year execrankann
tab year execrankann

gen base = salary + bonus

gsort gvkey year -base
by gvkey year: gen execrankann1 = _n
gen check = execrankann1-execrankann
tab check
drop check

** fill in gaps in years
tsset co_per_rol year 
tsfill 
               
sort co_per_rol year
* carryforward executive information at match-level
by co_per_rol: carryforward execid exec_fullname page gender ///
							gvkey coname state ///
							pceo pcfo ///
							joined_co leftco leftofc reason rejoin releft becameceo, replace

*** Initial Data Inspection
** check compensation formula
gen tdc1_old = salary + bonus + rstkgrnt + option_awards_blk_value + ltip + othann + allothtot 
gen tdc2_old = salary + bonus + rstkgrnt + opt_exer_val + ltip + othann + allothtot
gen tdc1_new = salary + bonus + stock_awards_fv + option_awards_fv + noneq_incent + defer_rpt_as_comp_tot + othcomp
gen tdc2_new = salary + bonus + stock_awards_fv + opt_exer_val + noneq_incent + defer_rpt_as_comp_tot + othcomp
gen total_alt1_new = salary + bonus + stock_awards_fv+ option_awards_fv + noneq_incent + pension_chg + othcomp
gen total_alt2_new = salary + bonus + shrs_vest_val+ opt_exer_val + noneq_incent + pension_chg + othcomp
gen diff_tdc1_old = tdc1_old - tdc1
gen diff_tdc2_old = tdc2_old - tdc2
gen diff_tdc1_new = tdc1_new - tdc1
gen diff_tdc2_new = tdc2_new - tdc2
gen diff_total_alt1_new = total_alt1_new - total_alt1
gen diff_total_alt2_new = total_alt2_new - total_alt2
sum diff_tdc1_old diff_tdc2_old diff_tdc1_new diff_tdc2_new diff_total_alt1_new diff_total_alt2_new

** check old_datafmt_flag - this should be 0 post 2006;
tab year, sum(old_datafmt_flag)

* page/age has discrepancies..
gen age_gap = (page-2015)-(age-year)
bysort execid: egen age_gap_max = min(abs(age_gap))
tab age_gap 
tab age_gap_max

gen age_2015 = age-year+2015
bysort execid: egen age_2015_sd = sd(age_2015)
bysort execid: egen page_sd = sd(page)
sum age_2015_sd page_sd

bysort execid: egen age_2015_maxmode = mode(age_2015), maxmode
replace age_2015 = age_2015_maxmode if age_2015_sd==0
replace age_2015 = age_2015_maxmode if age_2015_sd>0 & age_gap_max==0
replace age_2015 = page if mi(age_2015_maxmode)
drop age_gap age_gap_max age_2015_sd page_sd age_2015_maxmode

* this show that age/page is redundant information now
sum age page age_2015
gen check_age = 1 if !mi(age) & mi(age_2015)
gen check_page = 1 if !mi(page) & mi(age_2015)
drop page age check_age check_page


***************************************************************
*            Keep Variables
***************************************************************

rename state state_ceo

* there are some intersting infomation in the comment variable, but difficult to incorporate, so drop the variable
keep execid exec_fullname age_2015 gender /// 
	 gvkey coname co_per_rol year state_ceo ///
     execdir interlock reprice execrankann execrankann1 titleann ceoann cfoann pceo pcfo ///
     joined_co leftco leftofc reason rejoin releft becameceo ///
     salary bonus ltip term_pymt allothpd allothtot othann othcomp pension_chg  ///
	 rstkgrnt stock_awards stock_awards_fv stock_unvest_val shrs_vest_val /// 
	 opt_exer_val opt_unex_exer_est_val opt_unex_unexer_est_val option_awards_blk_value option_awards_fv option_awards_rpt_value /// 			 
	 defer_balance_tot defer_contrib_co_tot defer_contrib_exec_tot defer_earnings_tot defer_rpt_as_comp_tot defer_withdr_tot ///
	 eip_unearn_val noneq_incent ///		
	 total_curr tdc1 tdc2 total_alt1 total_alt2 total_sec
	 
order execid exec_fullname age_2015 gender /// 
	 gvkey coname co_per_rol year state_ceo ///
     execdir interlock reprice execrankann execrankann1 titleann ceoann cfoann pceo pcfo ///
     joined_co leftco leftofc reason rejoin releft becameceo ///
     salary bonus ltip term_pymt allothpd allothtot othann othcomp pension_chg  ///
	 rstkgrnt stock_awards stock_awards_fv stock_unvest_val shrs_vest_val /// 
	 opt_exer_val opt_unex_exer_est_val opt_unex_unexer_est_val option_awards_blk_value option_awards_fv option_awards_rpt_value /// 			 
	 defer_balance_tot defer_contrib_co_tot defer_contrib_exec_tot defer_earnings_tot defer_rpt_as_comp_tot defer_withdr_tot ///
	 eip_unearn_val noneq_incent ///		
	 total_curr tdc1 tdc2 total_alt1 total_alt2 total_sec
	 

***************************************************************
*            Deflate nominal variables
***************************************************************

merge m:1 year using "${drctory}/output/cpi.dta", keep(master match) keepusing(cpi)
drop _merge

* Execucomp variables: convert thousands into millions (2010$)
local vars  /// 
     salary bonus ltip term_pymt allothpd allothtot othann othcomp pension_chg  ///
	 rstkgrnt stock_awards stock_awards_fv stock_unvest_val shrs_vest_val /// 
	 opt_exer_val opt_unex_exer_est_val opt_unex_unexer_est_val option_awards_blk_value option_awards_fv option_awards_rpt_value /// 			 
	 defer_balance_tot defer_contrib_co_tot defer_contrib_exec_tot defer_earnings_tot defer_rpt_as_comp_tot defer_withdr_tot ///
	 eip_unearn_val noneq_incent ///		
	 total_curr tdc1 tdc2 total_alt1 total_alt2 total_sec
		   
foreach var of varlist `vars' {
	replace `var' = `var'/cpi/1000
}

drop cpi

***************************************************************
*                      Merge with BoardEx
***************************************************************

merge 1:m execid gvkey year using "${drctory}/output/boardex/boardex_employment4execucomp.dta"
gen datasource = 1 if _merge==1
replace datasource = 2 if _merge==2
replace datasource = 3 if _merge==3
label define datasource_label 1 "execucomp" 2 "boardex" 3 "both"
label values datasource datasource_label
drop _merge 

* the merge of 1:m creates some duplicates co_per_rol year observations: (2,053 observations deleted), doesn't seem to matter much
preserve
drop if datasource==2
keep co_per_rol year
duplicates drop
restore

***************************************************************
*                      Fill in blanks after merging
***************************************************************

cap drop temp
bysort execid: egen temp = mode(age_2015), maxmode
replace age_2015 = temp
drop temp 

cap drop temp
bysort execid: egen temp = mode(dob), maxmode
replace dob = temp
drop temp 

cap drop temp
bysort execid: egen temp = mode(dod), maxmode
replace dod = temp
drop temp 

cap drop temp
bysort execid: egen temp = mode(exec_fullname), maxmode
replace exec_fullname = temp
drop temp 

cap drop temp
bysort execid: egen temp = mode(gender), maxmode
replace gender = temp
drop temp 

cap drop temp
bysort gvkey: egen temp = mode(coname), maxmode
replace coname = temp
drop temp 

cap drop temp
bysort execid: egen temp = mode(nationality), maxmode
replace nationality = temp
drop temp 

***************************************************************
*              drop some unreasonable merge 
***************************************************************

*** 
gen age = age_2015-2015+year
replace age = year-dob if mi(age)
bysort execid: egen age_min = min(age)
tab age_min datasource
gen age_gap = 2015-age_2015-dob
bysort execid: egen age_gap_max = max(abs(age_gap))
tab age_gap_max datasource

** age_min<=15 implies that the execid is not a good match between Boardex and Compustat, drop the merged information
drop if age_min<=20 & datasource==2
drop if age_gap_max>=3 & datasource==2
** undo the match
local varlist directorid companyid companyid_matched gvkey_type dob dod start_ddate end_ddate duration gap  start_year end_year
foreach var of local varlist {
	replace  `var' = . if age_min<=20 & datasource==3
	replace  `var' = . if age_gap_max>=3 & datasource==3	
}
local varlist directorname companyname orgtype nationality rolename datestartrole dateendrole becameceo_bdex leftofc_bdex
foreach var of local varlist {
	replace  `var' = " " if age_min<=20 & datasource==3
	replace  `var' = " " if age_gap_max>=3 & datasource==3
}
drop age_min age_gap age_gap_max


/*
***************************************************************
*                      Create A List to Improve Company Name Match (substeps)
***************************************************************

* some movement to another companyid/company are not real job changes.
* below are attempts to fix it!
* skipping this step leads to only negligible changes to the results.

preserve 
keep execid gvkey coname companyname companyid 
duplicates drop
export delimited using "${drctory}/output/execucomp/list_improve_companyid.csv", replace
restore

***************************************************************
*                      Use 1.1 to imrpove companyid -> gvkey match
*                      Use 1.2 to clean the matches
***************************************************************
*/


***************************************************************
*                     Merge improved companyid -> gvkey match
***************************************************************

merge m:1 execid companyid using "${drctory}/output/execucomp/list_improved_companyid_filter.dta", keep(master match) keepusing(gvkey_final companyid_final)
replace gvkey_type = 1 if mi(gvkey) & !mi(gvkey_final)
replace gvkey = gvkey_final if mi(gvkey) & !mi(gvkey_final)
replace companyid_matched = companyid_final if !mi(companyid_final)
replace companyid_matched = companyid if mi(companyid_matched) & !mi(companyid)
drop _merge

order companyid* gvkey companyname

* combine information on company name
cap drop temp
gen temp = 1 if mi(coname) & !mi(companyname)
sum temp
replace coname = companyname if temp==1
drop temp 


***************************************************************
*                  Define Employment/Match
***************************************************************

* sort by execid company match starting time
cap drop start_min*
bysort execid gvkey: egen start_min = min(year) if !mi(gvkey)
bysort execid companyid_matched: egen start_min_alt = min(year)
replace start_min = start_min_alt if mi(start_min)
sort execid start_min gvkey companyid_matched year 
cap drop temp
gen temp = 0 
by execid: replace temp = 1 if (gvkey!=gvkey[_n-1]) & (mi(companyid_matched) | mi(companyid_matched[_n-1]))
by execid: replace temp = 1 if (companyid_matched!=companyid_matched[_n-1]) & (mi(gvkey) | mi(gvkey[_n-1]))
by execid: replace temp = 1 if (gvkey!=gvkey[_n-1]) & (companyid_matched!=companyid_matched[_n-1])
* job number
by execid: gen job_n = sum(temp)
* number of jobs
by execid: egen job_N = max(job_n)
drop temp start_min*

***************************************************************
*                    drop some redundant ones                 *
***************************************************************

cap drop temp*
bysort execid job_n year: gen temp=_N
bysort execid job_n year: gen temp1=_n
tab temp
tab temp1
bysort execid job_n year: egen tempmax=max(datasource)
bysort execid job_n year: egen tempmin=min(datasource)
tab tempmax tempmin
gen tempind=0
gsort execid job_n year -datasource
* if there are source from both, keep the first one
bysort execid job_n year datasource: replace tempind=1 if tempmax==3 & datasource==3 & _n==1
* if only from boardex, keep the first one
bysort execid job_n year datasource: replace tempind=2 if tempmax==2 & tempmin==2 & _n==1
* if  
bysort execid job_n year datasource: replace tempind=3 if tempmax<=2 & tempmin==1 & datasource==1 & _n==1
tab datasource tempind
drop if tempind==0
drop temp*
count

cap drop temp
bysort execid job_n: egen temp = mode(co_per_rol), maxmode
replace co_per_rol = temp
drop temp 

***************************************************************
*            Merge with Compustat Firm Level 
***************************************************************																																																														
merge m:1 gvkey year using "${drctory}/output/compustat/compustat_4exec.dta", keep(master match)
drop _merge

*** Fill in blanks after merging
cap drop temp
bysort gvkey: egen temp = mode(cik), maxmode
replace cik = temp
drop temp 


*** Check whether state_ceo == ceo
cap drop temp
gen temp = 1 if state_ceo!=ceo
sum temp
drop temp state_ceo

***************************************************************
*            Merge with Compustat Industry Measure
***************************************************************	 

merge m:1 gvkey year using "${drctory}/output/compustat/compustat_industry_measure.dta", keep(master match)
drop _merge


***************************************************************
*            Order Variables
***************************************************************	 

** variables to check further: ipo_year yearT_co

keep execid exec_fullname directorid directorname year ///
  	 gvkey gvkey_type gvkey_final orgtype companyid companyid_matched companyid_final coname companyname co_per_rol ///
	 ///
	 job_n job_N titleann rolename ceoann cfoann ///	 
	 joined_co leftco rejoin releft becameceo leftofc reason /// 
	 datestartrole dateendrole start_ddate end_ddate duration becameceo_bdex leftofc_bdex ///
     execdir interlock reprice execrankann execrankann1 ///
	 ///
	 age gender dob dod nationality ///
	 datasource ipo_year yearT_co ///	 
     salary bonus ltip term_pymt allothpd allothtot othann othcomp pension_chg  ///
	 rstkgrnt stock_awards stock_awards_fv stock_unvest_val shrs_vest_val /// 
	 opt_exer_val opt_unex_exer_est_val opt_unex_unexer_est_val option_awards_blk_value option_awards_fv option_awards_rpt_value /// 			 
	 defer_balance_tot defer_contrib_co_tot defer_contrib_exec_tot defer_earnings_tot defer_rpt_as_comp_tot defer_withdr_tot ///
	 eip_unearn_val noneq_incent ///		
	 total_curr tdc1 tdc2 total_alt1 total_alt2 total_sec ///
	 ///
	 fic state naics naics4 sic2 sic3 sic compst ///
	 act at dlc dltt intan ppegt ppent invt invrm prcc_f ceq txdb ///
	 sale revt cogs gp oibdp pi ni capx xrd xsga xstfws sppe dp ib ///
	 csho emp ///
	 ppegt_lag tobinq tobinq_lag q_tot q_tot_lag mb mb_lag inv inv_phy inv_int inv_tot xrd_rate cash /// 
	 g_revt  g_revt1  g_at g_at1 g_emp g_emp1 ///
	 ///
	 bei*
	 
order execid exec_fullname directorid directorname year ///
  	 gvkey gvkey_type gvkey_final orgtype companyid companyid_matched companyid_final coname companyname co_per_rol ///
	 ///
	 job_n job_N titleann rolename ceoann cfoann ///	 
	 joined_co leftco rejoin releft becameceo leftofc reason /// 
	 datestartrole dateendrole start_ddate end_ddate duration becameceo_bdex leftofc_bdex ///
     execdir interlock reprice execrankann execrankann1 ///
	 ///
	 age gender dob dod nationality ///
	 datasource ipo_year yearT_co ///	 
     salary bonus ltip term_pymt allothpd allothtot othann othcomp pension_chg  ///
	 rstkgrnt stock_awards stock_awards_fv stock_unvest_val shrs_vest_val /// 
	 opt_exer_val opt_unex_exer_est_val opt_unex_unexer_est_val option_awards_blk_value option_awards_fv option_awards_rpt_value /// 			 
	 defer_balance_tot defer_contrib_co_tot defer_contrib_exec_tot defer_earnings_tot defer_rpt_as_comp_tot defer_withdr_tot ///
	 eip_unearn_val noneq_incent ///		
	 total_curr tdc1 tdc2 total_alt1 total_alt2 total_sec ///
	 ///
	 fic state naics naics4 sic2 sic3 sic compst ///
	 act at dlc dltt intan ppegt ppent invt invrm prcc_f ceq txdb ///
	 sale revt cogs gp oibdp pi ni capx xrd xsga xstfws sppe dp ib ///
	 csho emp ///
	 ppegt_lag tobinq tobinq_lag q_tot q_tot_lag mb mb_lag inv inv_phy inv_int inv_tot xrd_rate cash /// 
	 g_revt  g_revt1  g_at g_at1 g_emp g_emp1 ///
	 ///
	 bei_*
	 
***************************************************************
*                      Merge Contract
***************************************************************

merge m:1 execid gvkey using "${drctory}/output/execucomp/noncompete_match_level.dta", ///
		  keep(master match) ///
		  keepusing(nc dur_max dur_min)

drop _merge

***************************************************************
*                     Save Match Level Final Data
***************************************************************

save "${drctory}/output/execucomp/execucomp_all.dta", replace

log close 
