set more off, perm
clear all
scalar drop _all
cls

global drctory = "/Users/liyan/Dropbox/Noncompete/replication_package/empirical"

capture log close
log using "${drctory}/build/temp/2_define_variables.log", text replace

***************************************************************
*                      DATA PREP                              *
***************************************************************

*** Load
use "${drctory}/build/output/execucomp/execucomp_all.dta", replace
format exec_fullname coname companyname title rolename %12s
count 

***************************************************************
*              Check whether role==executive                  *
***************************************************************

cap drop ind_exec
gen ind_exec = 0 if datasource==2
replace ind_exec = 1 if strpos(rolename, "CEO")>0
replace ind_exec = 1 if strpos(rolename, "Chairman")>0
replace ind_exec = 1 if strpos(rolename, "President")>0
replace ind_exec = 1 if strpos(rolename, "Chief")>0
replace ind_exec = 1 if strpos(rolename, "COO")>0
replace ind_exec = 1 if strpos(rolename, "CFO")>0
replace ind_exec = 1 if strpos(rolename, "CIO")>0
replace ind_exec = 1 if strpos(rolename, "Chair")>0
replace ind_exec = 1 if strpos(rolename, "Executive")>0
replace ind_exec = 1 if strpos(rolename, "MD")>0
replace ind_exec = 1 if strpos(rolename, "ED")>0
replace ind_exec = 1 if strpos(rolename, "Director")>0
replace ind_exec = 1 if strpos(rolename, "Head")>0
replace ind_exec = 1 if strpos(rolename, "Manager")>0
replace ind_exec = 1 if strpos(rolename, "Officer")>0
replace ind_exec = 1 if strpos(rolename, "Partner")>0
replace ind_exec = 1 if strpos(rolename, "Founder")>0
replace ind_exec = 1 if strpos(rolename, "Owner")>0
replace ind_exec = 1 if strpos(rolename, "Treasurer")>0
replace ind_exec = 1 if strpos(rolename, "Controller")>0
replace ind_exec = 1 if strpos(rolename, "Secretary")>0
replace ind_exec = 1 if strpos(rolename, "Counsel")>0
replace ind_exec = 1 if strpos(rolename, "Principal")>0
replace ind_exec = 1 if strpos(rolename, "Vice President")>0
replace ind_exec = 1 if strpos(rolename, "VP")>0

tab rolename if ind_exec==0
cap drop temp
bysort execid job_n year: egen temp = max(ind_exec)
bysort execid job_n year: replace ind_exec = temp
drop temp

* whether founder
cap drop temp
gen temp = 0
replace temp = 1 if strpos(rolename, "Owner")>0 | strpos(rolename, "Founder")>0
bysort co_per_rol: egen ind_founder = max(temp)
drop temp

***************************************************************
*      Keep Executives without overlaping employment          *
***************************************************************

*** create a new variable for whether the only employment!
sort execid job_n year
cap drop temp
bysort execid: gen temp = year-year[_n-1] if job_n-job_n[_n-1]==1
bysort execid job_n: egen gap = max(temp)
drop temp
bysort execid: egen gap_min = min(gap)

* define overlap if gap over 370 days
gen overlap = 0
replace overlap = 1 if gap_min<=-2 

***************************************************************
*            Save Firm Level Noncompete Data                  *
***************************************************************

preserve
collapse (mean) nc, by(gvkey year)
rename nc nc_mean
save "${drctory}/analysis/input/compustat/noncompete_firm_level.dta", replace
restore

***************************************************************
*                Define Variables                             *
***************************************************************

*** Tenure
do "${drctory}/build/code/3_clean_execucomp/2sub_define_tenure.do"

*** Groups
do "${drctory}/build/code/3_clean_execucomp/2sub_grouping.do"

*** Ratios
do "${drctory}/build/code/3_clean_execucomp/2sub_ratios.do"

***************************************************************
*                  Generate aggregate data
***************************************************************

do "${drctory}/build/code/3_clean_execucomp/2sub_gen_aggregate_data.do"

***************************************************************
*                      Filtering
***************************************************************

do "${drctory}/build/code/3_clean_execucomp/2sub_filter_firm.do"
do "${drctory}/build/code/3_clean_execucomp/2sub_filter_manager.do"

keep if year>=1992 & year<=2015
keep if !mi(nc)
keep if !mi(state)

***************************************************************
*                      Organize                               *
***************************************************************

order execid directorid datasource job_N job_n execrankann t t_alt t_ceo T ind_exec execdir ceo_g title rolename year coname companyname sep j2j tdc1 gvkey nc exec_fullname directorname
gsort execid job_n year
gsort -T execid job_n year

** check the compensation rank of executives within a firm (execrankann)
order gvkey year execrankann tdc1 tdc2
sort gvkey year execrankann

***************************************************************
*                      Save                                   *
***************************************************************

save "${drctory}/analysis/input/execucomp/execucomp_final.dta", replace

log close 
