
***************************************************************
*                      Some cleaning up
***************************************************************

** tabulating data to fill in blanks
sort execid job_n
by execid job_n: egen temp = mode(joined_co), maxmode
replace joined_co = temp
drop temp
by execid job_n: egen temp = mode(rejoin), maxmode
replace rejoin = temp
drop temp
by execid job_n: egen temp = mode(becameceo), maxmode
replace becameceo = temp
drop temp
by execid job_n: egen temp = mode(becameceo_bdex), maxmode
replace becameceo_bdex = temp
drop temp
by execid job_n: egen temp = mode(leftco), maxmode
replace leftco = temp
drop temp
by execid job_n: egen temp = mode(releft), maxmode
replace releft = temp
drop temp
by execid job_n: egen temp = mode(leftofc), maxmode
replace leftofc = temp
drop temp
by execid job_n: egen temp = mode(leftofc_bdex), maxmode
replace leftofc_bdex = temp
drop temp

***************************************************************
*                      Check by 4 categories of employment data
***************************************************************

** check available information on joining and leaving time
cap drop temp*
gen temp1 = 0
replace temp1 = 1 if (!mi(joined_co) & mi(leftco)) | (mi(joined_co) & !mi(leftco))
replace temp1 = 2 if !mi(joined_co) & !mi(leftco)
tab temp1 datasource
gen temp2 = 0
replace temp2 = 1 if (!mi(rejoin) & mi(releft)) | (mi(rejoin) & !mi(releft))
replace temp2 = 2 if !mi(rejoin) & !mi(releft)
tab temp2 datasource
gen temp3 = 0
replace temp3 = 1 if (!mi(becameceo) & mi(leftofc)) | (mi(becameceo) & !mi(leftofc))
replace temp3 = 2 if !mi(becameceo) & !mi(leftofc)
tab temp3 datasource
gen temp4 = 0
replace temp4 = 1 if (!mi(becameceo_bdex) & mi(leftofc_bdex)) | (mi(becameceo_bdex) & !mi(leftofc_bdex))
replace temp4 = 2 if !mi(becameceo_bdex) & !mi(leftofc_bdex)
tab temp4 datasource
drop temp*

** check whether leaving time is after joining time
tostring joined_co rejoin becameceo leftco releft leftofc, replace
gen join_ddate=daily(joined_co, "YMD")
gen rejoin_ddate=daily(rejoin, "YMD")
gen ceo_ddate=daily(becameceo, "YMD")
gen ceo_bdex_ddate=daily(becameceo_bdex, "YMD")
gen left_ddate=daily(leftco, "YMD")
gen releft_ddate=daily(releft, "YMD")
gen leftofc_ddate=daily(leftofc, "YMD")
gen leftofc_bdex_ddate=daily(leftofc_bdex, "YMD")

cap drop temp_T*
gen temp_T1 = left_ddate-join_ddate
gen temp_T2 = releft_ddate-rejoin_ddate
gen temp_T3 = leftofc_ddate-ceo_ddate
gen temp_T4 = leftofc_bdex_ddate-ceo_bdex_ddate
sum temp_T*
tab nc, sum(temp_T1)
tab nc, sum(temp_T2)
tab nc, sum(temp_T3)
tab nc, sum(temp_T4)
tab dur_max, sum(temp_T1)
tab dur_max, sum(temp_T2)
tab dur_max, sum(temp_T3)
tab dur_max, sum(temp_T4)
gen temp_T1_year=temp_T1/365
gen temp_T2_year=temp_T2/365
gen temp_T3_year=temp_T3/365
gen temp_T4_year=temp_T4/365


drop temp_T*

cap drop temp*
gen temp1 = (ceo_ddate-ceo_bdex_ddate)/365
gen temp2 = (leftofc_ddate-leftofc_bdex_ddate)/365
sum temp*
drop temp*

** observation 1: there are 9 jobs that has leftofc_ddate < ceo_ddate
** observation 2: the information on ceo tenure are consistent in boardex and execucomp: 
**  			  becameceo_bdex, becameceo are similar, and leftofc, leftofc_bdex are similar

***************************************************************
*                 Preparation for Defining Tenure 
***************************************************************

** Need to properly combine the 4 categories of information 

** join year
gen join_year = substr(joined_co,1,4)
gen rejoin_year = substr(rejoin,1,4)
gen startrole_year = substr(datestartrole,1,4)
gen becameceo_year = substr(becameceo,1,4)
gen becameceo_bdex_year = substr(becameceo_bdex,1,4)

destring join_year rejoin_year startrole_year becameceo_year becameceo_bdex_year, replace

replace join_year = join_year+1 if inlist(substr(joined_co,5,2),"07","08","09","10","11","12")
replace rejoin_year = rejoin_year+1 if inlist(substr(rejoin,5,2),"07","08","09","10","11","12")
replace startrole_year = startrole_year+1 if inlist(substr(datestartrole,5,2),"07","08","09","10","11","12") 
replace becameceo_year = becameceo_year+1 if inlist(substr(becameceo,5,2),"07","08","09","10","11","12")
replace becameceo_bdex_year = becameceo_bdex_year+1 if inlist(substr(becameceo_bdex,5,2),"07","08","09","10","11","12")

replace join_year = . if join_year>2016
replace rejoin_year = . if rejoin_year>2016
replace becameceo_year = . if becameceo_year>2016
* this replacement not sure: since brdex data is downloaded in 2017
replace becameceo_bdex_year = . if becameceo_bdex_year>2018
sum join_year rejoin_year startrole_year becameceo_year becameceo_bdex_year

** left year
gen left_year = substr(leftco,1,4)
gen releft_year = substr(releft,1,4)
gen endrole_year = substr(dateendrole,1,4)
gen leftofc_year = substr(leftofc,1,4)
gen leftofc_bdex_year = substr(leftofc_bdex,1,4)

destring left_year releft_year leftofc_year, replace
destring leftofc_bdex_year endrole_year, ignore( "C") replace

replace left_year = left_year-1 if inlist(substr(leftco,5,2),"01","02","03","04","05","06")
replace releft_year = releft_year-1 if inlist(substr(releft,5,2),"01","02","03","04","05","06") 
replace endrole_year = endrole_year-1 if inlist(substr(dateendrole,5,2),"01","02","03","04","05","06")
replace leftofc_year = leftofc_year-1 if inlist(substr(leftofc,5,2),"01","02","03","04","05","06")
replace leftofc_bdex_year = leftofc_bdex_year-1 if inlist(substr(leftofc_bdex,5,2),"01","02","03","04","05","06")

replace left_year = . if left_year>=2016
replace releft_year = . if releft_year>=2016
replace leftofc_year = . if leftofc_year>=2016
* this replacement not sure: since brdex data is downloaded in 2017
replace leftofc_bdex_year = . if leftofc_bdex_year>=2018
sum left_year releft_year leftofc_year leftofc_bdex_year

* years tabulated
sort execid job_n year
bysort execid job_n: egen year0_match = min(year)

cap drop temp
bysort execid job_n: egen year0_bdex = min(year) if ind_exec==1
bysort execid job_n: egen temp = max(year0_bdex)
bysort execid job_n: replace year0_bdex = temp
drop temp

cap drop temp
bysort execid job_n: egen year0_exec = min(year) if datasource!=2 

bysort execid job_n: egen temp = max(year0_exec)
bysort execid job_n: replace year0_exec = temp
drop temp

bysort execid job_n: egen yearT_match = max(year)
bysort execid job_n: gen gap_year = year-year[_n-1]
bysort execid job_n: egen gap_year_max = max(gap_year)
bysort execid: egen yearT_execid = max(year)

*** define two kinds of tenure variables below

***************************************************************
*                 Tenure: Definition based on 
* 						becameceo leftofc
* 					becameceo_bdex leftofc_bdex
***************************************************************

gen year0_ceo = becameceo_bdex_year 
replace year0_ceo = becameceo_year if mi(year0_ceo) | becameceo_year<becameceo_bdex_year
by execid job_n, sort: egen check = sd(year0_ceo)
sum check
drop check

gen yearT_ceo = leftofc_year
replace yearT_ceo = leftofc_bdex_year if mi(yearT_ceo)
by execid job_n, sort: egen check = sd(yearT_ceo)
sum check
drop check

replace year0_ceo = . if year0_ceo>yearT_ceo
replace yearT_ceo = . if year0_ceo>yearT_ceo

* year t as ceo
gen t_ceo = year-year0_ceo+1 if year>=year0_ceo & year<=yearT_ceo
* year T no longer ceo
gen T_ceo = yearT_ceo-year0_ceo+1 if year>=year0_ceo

***************************************************************
*                 Tenure: Definition based on join_co leftco
***************************************************************

sum year0_exec year0_bdex join_year year0_ceo

* define: year 0 of employment
gen year0 = join_year
* try not including information of join year in execucomp
replace year0 = rejoin_year if mi(year0)
replace year0 = year0_exec if year0_exec<year0
replace year0 = year0_bdex if year0_bdex<year0
quietly bysort execid job_n: egen temp = min(year0)
replace year0 = temp 
gen year0_role = startrole_year

gen year0_alt = year0_exec if year0_exec>=1993
replace year0_alt = year0_bdex if mi(year0_alt)

cap drop check
by execid job_n, sort: egen check = sd(year0)
sum check
drop check

* define: year T of employment
gen yearT = yearT_match
replace yearT = left_year if left_year>yearT_match & !mi(left_year)
cap drop check
by execid job_n, sort: egen check = sd(left_year)
sum check
drop check

* year t employed
gen t = year-year0+1 if year>=year0
gen t_alt = year-year0_alt+1 if year>=year0_alt
gen t_role = year-year0_role+1 if year>=year0_role
* year T left
gen T = yearT-year0+1

***************************************************************
*                      Age when joining 
* 						or becaming CEO
***************************************************************

gen age_join = age-year+year0
by execid job_n, sort: egen check = sd(age_join)
sum check
drop check

gen age_becameceo = age-year+year0_ceo
by execid job_n, sort: egen check = sd(age_becameceo)
sum check
drop check

***************************************************************
*                      Firm Age
***************************************************************

cap drop temp*
by gvkey, sort: egen temp1 = min(year)
quietly bysort gvkey: egen temp2 = mode(ipo_year), maxmode
replace ipo_year = temp2
gen firm_age = year-min(temp1,ipo_year)+1
gen firm_age_join = year0-min(temp1,ipo_year)+1
by execid job_n, sort: egen check = sd(firm_age_join)
sum check
drop temp*

***************************************************************
*                      J2J Transitions
***************************************************************

sort execid job_n year

gen j2j = 0
by execid: replace j2j = 1 if job_n[_n+1]==job_n[_n]+1 & (t==T & year[_n+1]>=year[_n])
* need to check robustness later: indsutry classification naics4 
gen j2j_within = 0
by execid: replace j2j_within = 1 if job_n[_n+1]==job_n[_n]+1 & (t==T & year[_n+1]>=year[_n])& sic2[_n+1]==sic2[_n]
gen j2j_cross = 0
by execid: replace j2j_cross = 1 if job_n[_n+1]==job_n[_n]+1 & (t==T & year[_n+1]>=year[_n])& sic2[_n+1]!=sic2[_n]
sum j2j*

* Average duration of unvested: compare with the one from the optional duration paper
gen vest = shrs_vest_val+opt_exer_val+opt_unex_exer_est_val
gen unvest = stock_unvest_val+opt_unex_unexer_est_val

* previous job contract type
by execid: gen nc_temp = nc[_n-1] if j2j[_n-1]==1
by execid: gen tdc1_temp = tdc1[_n-1] if j2j[_n-1]==1
by execid: gen tdc2_temp = tdc2[_n-1] if j2j[_n-1]==1
by execid: gen unvest_temp = unvest[_n-1] if j2j[_n-1]==1
by execid: gen at_temp = at[_n-1] if j2j[_n-1]==1

by co_per_rol, sort: egen nc_lag = max(nc)
by co_per_rol, sort: egen tdc1_lag = max(tdc1_temp)
by co_per_rol, sort: egen tdc2_lag = max(tdc2_temp)
by co_per_rol, sort: egen unvest_lag = max(unvest_temp)
by co_per_rol, sort: egen at_lag = max(at_temp)

***************************************************************
*                      Match Separation
***************************************************************

sort execid job_n year
gen sep = 0
by execid job_n: replace sep = 1 if t==T & (year<2017)
gen sep_ceo = 0
by execid job_n: replace sep_ceo = 1 if t_ceo==T_ceo & (year<2017)

sum sep*


