
%% Initialize the setting

clear;
close all;
clc;
format compact
format short

options_fsolve  =  optimset('fsolve');
options_fsolve  =  optimset(options_fsolve , 'TolFun'      , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'TolX'        , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'Display'     , 'off');
options_fsolve  =  optimset(options_fsolve , 'MaxFunEvals' , 1000);
options_fsolve  =  optimset(options_fsolve , 'MaxIter' , 1000);

%% Specification 

% set to 1 if kappa follows log-normal distribution 
%        2 if kappa follows a binary distribution
%        3 if kappa = 0
kappa_case = 1;

% whether to impose a simple duration cap
case_duration_cap = 0;
dur_cap = Inf;

% whether to weaken enforcement
case_weaken_p = 0;

% whether solve wage: 1 yes. 0 no.
case_solve_wage = 0;

% whether plot solution graphs
case_plot = 0;

%% Folder path

% base folder
dir = fileparts(fileparts(cd));
% figure folder
if kappa_case==1
    dir_fig = fullfile(dir,'output/figures/baseline');
elseif kappa_case==2 || kappa_case==3
    dir_fig = fullfile(dir,'output/figures/selection');
end
if ~exist(dir_fig,'dir')
    mkdir(dir_fig)
end

% data
run(fullfile(dir,'code/parameters','data_moment.m'));

%% Parameters

run(fullfile(dir,'code/parameters','parameters_baseline.m'));      
error = 5e-3;

if case_weaken_p==1 && kappa_case==1
    % use a finer grid for p for the counterfactual exercise weekenining enforcement p
    run(fullfile(dir,'code/grids','grid_finetune_p.m'));    
else 
    run(fullfile(dir,'code/grids','grid.m'));
end

%% Prepare to store results

% equilibrium objects
% standard contract
theta_bar_c_vec = zeros(N_p,1);
j_c_vec  = zeros(N_p,1);
mu_c_vec = zeros(N_p,1);
cmu_c_vec = zeros(N_p,1);
j2j_c_vec = zeros(N_p,1);
sep_c_vec = zeros(N_p,1);
Z_c_vec   = zeros(N_p,1);
Y_c_vec   = zeros(N_p,1);
s_c_vec   = zeros(N_p,1);

% noncompete contract
j_n_vec = zeros(N_p,N_kappa);
mu_n_vec = zeros(N_p,N_kappa);
i_n_vec = zeros(N_p,N_kappa);

Emu_n_vec = zeros(N_p,1);
Ecmu_n_vec = zeros(N_p,1);
theta_bar_n_vec = zeros(N_p,1);
j2j_n_vec = zeros(N_p,1);
sep_n_vec = zeros(N_p,1);

Z_n_vec = zeros(N_p,N_kappa);
Y_n_vec = zeros(N_p,N_kappa);

% aggregation
kappa_bar_vec = zeros(N_p,1);
i_kappa_bar_vec = zeros(N_p,1);
frac_n_vec = zeros(N_p,1);
frac_n_approx_vec = zeros(N_p,1);
pie_vec = zeros(N_p,1);
kappa_mean_vec = zeros(N_p,1);

j2j_vec = zeros(N_p,1);
sep_vec = zeros(N_p,1);
cmu_vec = zeros(N_p,1);

dlogmu_vec = zeros(N_p,1);
dlogcmu_vec = zeros(N_p,1);
gz_prox_c_vec = cell(N_p,1);
gz_prox_n_vec = cell(N_p,1);

Z_vec = zeros(N_p,1); 
Y_vec = zeros(N_p,1);

% social values
s_n_vec  = zeros(N_p,N_kappa);
S_1_vec  = zeros(N_p,1);
S_ss_vec = zeros(N_p,1);
Delta_vec = zeros(N_p,N_kappa);

% equilibrium objects: wage
% standard contract
x_c_vec   = cell(N_p,1);
xl_c_vec  = zeros(N_p,1);
xu_c_vec  = zeros(N_p,1);
x0_c_vec  = zeros(N_p,1);
u_c_vec   = cell(N_p,1);
du_c_vec  = cell(N_p,1);
ddu_c_vec = cell(N_p,1);
theta_l_c_vec = cell(N_p,1);
Istar_c_vec = cell(N_p,1);
check_HJB_c_vec = cell(N_p,1);

% noncompete contract
x_n_vec   = cell(N_p,1);
xl_n_vec  = zeros(N_p,N_kappa);
xu_n_vec  = zeros(N_p,N_kappa);
x0_n_vec  = zeros(N_p,N_kappa);
u_n_vec   = cell(N_p,1);
du_n_vec  = cell(N_p,1);
ddu_n_vec = cell(N_p,1);
theta_l_n_vec = cell(N_p,1);
theta_l_u_vec = cell(N_p,1);
Istar_n_vec = cell(N_p,1);
check_HJB_n_vec = cell(N_p,1);

% store simulated wage-tenure profile
gx_c_vec = cell(N_p,1);
Gx_c_vec = cell(N_p,1);
dxdt_c_vec = cell(N_p,1);
gxstat_c_vec = cell(N_p,1);
xmean_c_vec = cell(N_p,1);
wmean_c_vec = cell(N_p,1);
gwmean_c_vec = cell(N_p,1);

gx_n_vec = cell(N_p,1);
Gx_n_vec = cell(N_p,1);
dxdt_n_vec = cell(N_p,1);
gxstat_n_vec = cell(N_p,1);
xmean_n_vec = cell(N_p,1);
wmean_n_vec = cell(N_p,1);
gwmean_n_vec= cell(N_p,1);

% social optimum: time zero welfare
theta_bar_n_star_t0_vec  = zeros(N_p,N_kappa);
pie_star_t0_vec  = zeros(N_p,N_kappa);
mu_n_star_t0_vec = zeros(N_p,N_kappa);
s_n_star_t0_vec = zeros(N_p,N_kappa);
j_n_star_t0_vec = zeros(N_p,N_kappa);
Delta_star_t0_vec = zeros(N_p,N_kappa);
kappa_bar_star_t0_vec = zeros(N_p,1);
frac_n_star_t0_vec = zeros(N_p,1);
frac_n_star_t0_approx_vec = zeros(N_p,1);

Z_n_star_t0_vec = zeros(N_p,N_kappa);
Z_star_t0_vec = zeros(N_p,1); 
Y_n_star_t0_vec = zeros(N_p,N_kappa);

S_star_t0_vec = zeros(N_p,1); 
dS_t0_vec = zeros(N_p,1); 
dS_reallocate_t0_vec = zeros(N_p,1); 
dS_invest_t0_vec = zeros(N_p,1); 
dS_select_t0_vec = zeros(N_p,1); 

S_ss_star_t0_vec = zeros(N_p,1);
Y_star_t0_vec = zeros(N_p,1); 
dY_t0_vec = zeros(N_p,1);
dY_reallocate_t0_vec = zeros(N_p,1);
dY_invest_t0_vec = zeros(N_p,1);
dY_select_t0_vec = zeros(N_p,1);

% duration cap only
kappa_bar_cap_vec = zeros(N_p,1);
frac_n_cap_vec = zeros(N_p,1);
frac_n_cap_approx_vec = zeros(N_p,1);

S_cap_vec = zeros(N_p,1);
dS_cap_vec = zeros(N_p,1);
dS_reallocate_cap_vec = zeros(N_p,1);
dS_invest_cap_vec = zeros(N_p,1);
dS_select_cap_vec = zeros(N_p,1);

S_ss_cap_vec = zeros(N_p,1);
Y_cap_vec = zeros(N_p,1);
dY_cap_vec = zeros(N_p,1);
dY_reallocate_cap_vec = zeros(N_p,1);
dY_invest_cap_vec = zeros(N_p,1);
dY_select_cap_vec = zeros(N_p,1);

% social optimum: steady state welfare
theta_bar_n_star_ss_vec  = zeros(N_p,N_kappa);
pie_star_ss_vec  = zeros(N_p,N_kappa);
mu_n_star_ss_vec = zeros(N_p,N_kappa);
s_n_star_ss_vec = zeros(N_p,N_kappa);
j_n_star_ss_vec = zeros(N_p,N_kappa);
Delta_star_ss_vec = zeros(N_p,N_kappa);
kappa_bar_star_ss_vec = zeros(N_p,1);
frac_n_star_ss_vec = zeros(N_p,1);
frac_n_star_ss_approx_vec = zeros(N_p,1);

Z_n_star_ss_vec = zeros(N_p,N_kappa);
Z_star_ss_vec = zeros(N_p,1); 
Y_n_star_ss_vec = zeros(N_p,N_kappa);
Y_star_ss_vec = zeros(N_p,1); 
S_ss_star_ss_vec = zeros(N_p,1);

dY_ss_vec = zeros(N_p,1);
dY_reallocate_ss_vec = zeros(N_p,1);
dY_invest_ss_vec = zeros(N_p,1);
dY_select_ss_vec = zeros(N_p,1);

%% First best

eq_mu_fb = @(mu) cp(mu)*(r-mu-lambda*ES(1))-(1-c(mu));
mu_fb    = fsolve(eq_mu_fb,1/2*sigma^2,options_fsolve);
j_fb     = (1-c(mu_fb))/(r-mu_fb);
cmu_fb   = c(mu_fb);
% Productivity
Z_fb     = delta/(delta-mu_fb-lambda*ES(1));
% Consumption
Y_fb     = delta*(1-c(mu_fb))/(delta-mu_fb-lambda*ES(1));
% Welfare
s_fb     = (1-c(mu_fb))/(r-mu_fb-lambda*ES(1));
S_1_fb   = (rho+delta)/rho*s_fb;
S_ss_fb  = s_fb*Z_fb+delta/(rho+delta)*S_1_fb;

%% Iterate over enforcement regimes

for i_p = 1:N_p
    
    p   = p_vec(i_p);
    disp(['P Iteration = ' num2str(i_p) ...
          ', p = ' num2str(p)])

    %% Solve equilibrium

    run(fullfile(dir,'code/solve','solve_equilibrium.m'));

    %% Store results    
    
    theta_bar_c_vec(i_p) = theta_bar_c;
    j_c_vec(i_p)   = j_c;
    mu_c_vec(i_p)  = mu_c;
    cmu_c_vec(i_p) = cmu_c;
    j2j_c_vec(i_p) = j2j_c;
    sep_c_vec(i_p) = sep_c;
    Z_c_vec(i_p)   = Z_c;
    Y_c_vec(i_p)   = Y_c;
    s_c_vec(i_p)   = s_c;    

    j_n_vec(i_p,:) = j_n;
    mu_n_vec(i_p,:) = mu_n;
    i_n_vec(i_p,:) = i_n;

    theta_bar_n_vec(i_p) = theta_bar_n;
    pie_vec(i_p) = pie;
    kappa_bar_vec(i_p) = kappa_bar;    
    i_kappa_bar_vec(i_p) = i_kappa_bar;
    frac_n_vec(i_p) = frac_n;
    frac_n_approx_vec(i_p) = frac_n_approx;
           
    j2j_n_vec(i_p) = j2j_n;    
    sep_n_vec(i_p) = sep_n;    
    j2j_vec(i_p) = j2j;
    sep_vec(i_p) = sep;
    Emu_n_vec(i_p) = Emu_n;            
    Ecmu_n_vec(i_p) = Ecmu_n;        
    cmu_vec(i_p) = cmu;

    Z_n_vec(i_p,:) = Z_n;    
    Z_vec(i_p) = Z;        
    Y_n_vec(i_p,:) = Y_n;
    Y_vec(i_p) = Y;
    
    kappa_mean_vec(i_p) = kappa_mean;        
    dlogmu_vec(i_p) = dlogmu;     
    dlogcmu_vec(i_p) = dlogcmu;     
    
    s_n_vec(i_p,:) = s_n;
    S_1_vec(i_p) = S_1;
    S_ss_vec(i_p) = S_ss;
    Delta_vec(i_p,:) = Delta;
        
    gz_prox_c_vec{i_p} = gz_prox_c;
    gz_prox_n_vec{i_p} = gz_prox_n;
            
    %% Solve social optimum: time zero welfare 

    run(fullfile(dir,'code/solve','solve_social_optimum_t0.m'));
    
    %% Store results    
       
    theta_bar_n_star_t0_vec(i_p,:) = theta_bar_n_star_t0;
    pie_star_t0_vec(i_p,:) = pie_star_t0;
    mu_n_star_t0_vec(i_p,:) = mu_n_star_t0;
    s_n_star_t0_vec(i_p,:) = s_n_star_t0;
    j_n_star_t0_vec(i_p,:) = j_n_star_t0;
    Delta_star_t0_vec(i_p,:) = Delta_star_t0;   
 
    kappa_bar_star_t0_vec(i_p) = kappa_bar_star_t0;
    frac_n_star_t0_vec(i_p) = frac_n_star_t0;
    frac_n_star_t0_approx_vec(i_p) = frac_n_star_t0_approx;
    
    Z_n_star_t0_vec(i_p,:) = Z_n_star_t0;    
    Z_star_t0_vec(i_p) = Z_star_t0;    
    Y_n_star_t0_vec(i_p,:) = Y_n_star_t0;
    
    S_star_t0_vec(i_p) = S_star_t0;
    dS_t0_vec(i_p) = dS_t0;
    dS_reallocate_t0_vec(i_p) = dS_reallocate_t0;
    dS_invest_t0_vec(i_p) = dS_invest_t0;
    dS_select_t0_vec(i_p) = dS_select_t0;
    
    S_ss_star_t0_vec(i_p) = S_ss_star_t0;
    Y_star_t0_vec(i_p) = Y_star_t0;
    dY_t0_vec(i_p) = dY_t0;
    dY_reallocate_t0_vec(i_p) = dY_reallocate_t0;
    dY_invest_t0_vec(i_p) = dY_invest_t0;        
    dY_select_t0_vec(i_p) = dY_select_t0;    
    
    %% Duration cap ponly 
    
    run(fullfile(dir,'code/solve','solve_cap.m'));
        
    kappa_bar_cap_vec(i_p) = kappa_bar_cap;
    frac_n_cap_vec(i_p) = frac_n_cap;
    frac_n_cap_approx_vec(i_p) = frac_n_cap_approx;
    
    S_cap_vec(i_p) = S_cap;
    dS_cap_vec(i_p) = dS_cap;
    dS_reallocate_cap_vec(i_p) = dS_reallocate_cap;
    dS_invest_cap_vec(i_p) = dS_invest_cap;
    dS_select_cap_vec(i_p) = dS_select_cap;
    
    S_ss_cap_vec(i_p) = S_ss_cap;
    Y_cap_vec(i_p) = Y_cap;   
    dY_cap_vec(i_p) = dY_cap;
    dY_reallocate_cap_vec(i_p) = dY_reallocate_cap;
    dY_invest_cap_vec(i_p) = dY_invest_cap;        
    dY_select_cap_vec(i_p) = dY_select_cap;   
    
    %% Steady-state welfare 

    run(fullfile(dir,'code/solve','solve_social_optimum_ss.m'));
    
    %% Store results    
       
    theta_bar_n_star_ss_vec(i_p,:) = theta_bar_n_star_ss;
    pie_star_ss_vec(i_p,:) = pie_star_ss;
    mu_n_star_ss_vec(i_p,:) = mu_n_star_ss;
    s_n_star_ss_vec(i_p,:) = s_n_star_ss;
    j_n_star_ss_vec(i_p,:) = j_n_star_ss;
    Delta_star_ss_vec(i_p,:) = Delta_star_ss;   
 
    kappa_bar_star_ss_vec(i_p) = kappa_bar_star_ss;
    frac_n_star_ss_vec(i_p) = frac_n_star_ss;
    frac_n_star_ss_approx_vec(i_p) = frac_n_star_ss_approx;
   
    Z_n_star_ss_vec(i_p,:) = Z_n_star_ss;    
    Z_star_ss_vec(i_p) = Z_star_ss;
    Y_n_star_ss_vec(i_p,:) = Y_n_star_ss;
    Y_star_ss_vec(i_p) = Y_star_ss;
    S_ss_star_ss_vec(i_p) = S_ss_star_ss;
   
    dY_ss_vec(i_p) = dY_ss;
    dY_reallocate_ss_vec(i_p) = dY_reallocate_ss;
    dY_invest_ss_vec(i_p) = dY_invest_ss;        
    dY_select_ss_vec(i_p) = dY_select_ss;
    
    %% Weaken enforcement

    if case_weaken_p==1
        run(fullfile(dir,'code/solve','solve_weaken_enforcement.m'));
    end
    
    if case_solve_wage==1 && i_p==N_p
    
        %% Solve wage
        
        run(fullfile(dir,'code/solve','solve_wage.m'));
    
        %% Store results: Wage

        u_c_vec{i_p} = u_c;
        du_c_vec{i_p} = du_c;    
        ddu_c_vec{i_p} = ddu_c;       
        theta_l_c_vec{i_p} = theta_l_c;
        x_c_vec{i_p} = x_c;
        xl_c_vec(i_p) = xl_c;
        xu_c_vec(i_p) = xu_c;  
        x0_c_vec(i_p) = x0_c;      
        Istar_c_vec{i_p} = Istar_c;    
        check_HJB_c_vec{i_p} = check_HJB_c;

        u_n_vec{i_p} = u_n;
        du_n_vec{i_p} = du_n;    
        ddu_n_vec{i_p} = ddu_n;       
        theta_l_n_vec{i_p} = theta_l_n;
        theta_l_u_vec{i_p} = theta_l_u;
        x_n_vec{i_p} = x_n;
        xl_n_vec(i_p,:) = xl_n;
        xu_n_vec(i_p,:) = xu_n;  
        x0_n_vec(i_p,:) = x0_n;      
        Istar_n_vec{i_p} = Istar_n;    
        check_HJB_n_vec{i_p} = check_HJB_n;
        
        %% Wage tenure - KFE
        
        run(fullfile(dir,'code/solve','solve_wage_tenure.m'));
        
        %% Store results: wage tenure

        gx_c_vec{i_p} = gx_c;
        Gx_c_vec{i_p} = Gx_c;
        dxdt_c_vec{i_p} = dxdt_c;       
        gxstat_c_vec{i_p} = gxstat_c;
        xmean_c_vec{i_p} = xmean_c;
        wmean_c_vec{i_p} = wmean_c;
        gwmean_c_vec{i_p} = gwmean_c;

        gx_n_vec{i_p} = gx_n;
        Gx_n_vec{i_p} = Gx_n;
        dxdt_n_vec{i_p} = dxdt_n;       
        gxstat_n_vec{i_p} = gxstat_n;
        xmean_n_vec{i_p} = xmean_n;
        wmean_n_vec{i_p} = wmean_n;
        gwmean_n_vec{i_p} = gwmean_n;     
      
        if case_plot==1
            run(fullfile(dir,'code/plot_display','plot_solution_wage.m'));
            run(fullfile(dir,'code/plot_display','plot_solution_wage_tenure.m'));      
        end

    end
    
    %% Display results
    run(fullfile(dir,'code/plot_display','display_result.m'));

end

if kappa_case==1
    if case_plot==1
    % plot figures, varying p
    run(fullfile(dir,'code/plot_display','plot_variation_p.m'));
    end

    %% Save Data 
    % save variation in frac_n for the log-normal case  
    save(fullfile(dir,'output/data','variation_p_model.mat'),'p_vec','frac_n_vec')
end

