
%% Initialize the setting

clear;
close all;
clc;
format compact
format short

options_fsolve  =  optimset('fsolve');
options_fsolve  =  optimset(options_fsolve , 'TolFun'      , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'TolX'        , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'Display'     , 'off');
options_fsolve  =  optimset(options_fsolve , 'MaxFunEvals' , 1000);
options_fsolve  =  optimset(options_fsolve , 'MaxIter' , 1000);

plotfontsize  = 18;
labelfontsize = 18;
linecolor = 1/255*[0 0 153];

%% Specification

% set to 1 if kappa follows log-normal distribution 
%        2 if kappa follows a binary distribution
%        3 if kappa = 0
kappa_case = 1;

%% Folder path 

% base folder
dir = fileparts(fileparts(cd));
% figure folder
if kappa_case==1
    dir_fig = fullfile(dir,'output/figures/baseline');
elseif kappa_case==2 || kappa_case==3
    dir_fig = fullfile(dir,'output/figures/selection');
end
if ~exist(dir_fig,'dir')
    mkdir(dir_fig)
end

% data
run(fullfile(dir,'code/parameters','data_moment.m'));    

%% Parameters

run(fullfile(dir,'code/parameters','parameters_baseline.m'));   
run(fullfile(dir,'code/grids','grid_finetune_kappa.m'));
error = 5e-3;

% duration cap grid
case_duration_cap = 1;
N_dur = 201;    
dur_cap_vec = linspace(0,dur_data,N_dur)';

%% Prepare to store results

kappa_bar_cap_vec = zeros(N_p,N_dur);
frac_n_cap_vec = zeros(N_p,N_dur);
frac_n_cap_approx_vec = zeros(N_p,N_dur);

s_n_kappa0_cap_vec = zeros(N_p,N_dur);

S_cap_vec = zeros(N_p,N_dur);
dS_cap_vec = zeros(N_p,N_dur);
dS_reallocate_cap_vec = zeros(N_p,N_dur);
dS_invest_cap_vec = zeros(N_p,N_dur);
dS_select_cap_vec = zeros(N_p,N_dur);
dS_intensive_cap_vec = zeros(N_p,N_dur);

S_ss_cap_vec = zeros(N_p,N_dur);
Y_cap_vec = zeros(N_p,N_dur);
dY_cap_vec = zeros(N_p,N_dur);
dY_reallocate_cap_vec = zeros(N_p,N_dur);
dY_invest_cap_vec = zeros(N_p,N_dur);    
dY_select_cap_vec = zeros(N_p,N_dur);

%% Welfare analysis

% run only for full enforcement
for i_p=N_p %1:N_p
    
    Y_vec = zeros(N_dur,1);
    frac_n_vec = zeros(N_dur,1);
    s_n_vec = zeros(N_dur,N_kappa);
    Z_n_vec = zeros(N_dur,N_kappa);
    S_1_vec = zeros(N_dur,1);
    S_ss_vec = zeros(N_dur,1);

    p = p_vec(i_p);
    
    dur_cap = Inf;
    run(fullfile(dir,'code/solve','solve_equilibrium.m'));
    
    for i_dur=1:N_dur
        
        %% solve equilibrium subject to the cap
        dur_cap = dur_cap_vec(i_dur);
        run(fullfile(dir,'code/solve','solve_social_optimum_t0.m'));   
        run(fullfile(dir,'code/solve','solve_cap.m'));
        
        %% store results 
        s_n_kappa0_cap_vec(i_p,i_dur) = s_n_star_t0(1);
        
        kappa_bar_cap_vec(i_p,i_dur) = kappa_bar_cap;
        frac_n_cap_vec(i_p,i_dur) = frac_n_cap;
        frac_n_cap_approx_vec(i_p,i_dur) = frac_n_cap_approx;

        S_cap_vec(i_p,i_dur) = S_cap;
        dS_cap_vec(i_p,i_dur) = dS_cap;
        dS_reallocate_cap_vec(i_p,i_dur) = dS_reallocate_cap;
        dS_invest_cap_vec(i_p,i_dur) = dS_invest_cap;
        dS_select_cap_vec(i_p,i_dur) = dS_select_cap;
        dS_intensive_cap_vec(i_p,i_dur) = dS_reallocate_cap+dS_invest_cap;
        
        S_ss_cap_vec(i_p,i_dur) = S_ss_cap;
        Y_cap_vec(i_p,i_dur) = Y_cap;
        dY_cap_vec(i_p,i_dur) = dY_cap;
        dY_reallocate_cap_vec(i_p,i_dur) = dY_reallocate_cap;
        dY_invest_cap_vec(i_p,i_dur) = dY_invest_cap;        
        dY_select_cap_vec(i_p,i_dur) = dY_select_cap;   

    end

    [dS_cap_max, tempI] = max(dS_cap_vec(i_p,:));
    dur_cap_max = dur_cap_vec(tempI);
    fprintf('Time-0 welfare:\n')        
    fprintf('Overall\n')
    fprintf('   Gain = %.3g%%\n',dS_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_cap_max*12)    

    [dS_intensive_cap_max, tempI] = max(dS_intensive_cap_vec(i_p,:));
    dur_intensive_cap_max = dur_cap_vec(tempI);
    fprintf('Intensive margin\n')
    fprintf('   Gain = %.3g\n',dS_intensive_cap_max)
    fprintf('   Duration cap = %.3g years\n',dur_intensive_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_intensive_cap_max*12)

    [~, tempI] = max(s_n_kappa0_cap_vec(i_p,:));
    fprintf('   type kappa=0\n')
    fprintf('   Duration cap = %.3g years\n',dur_cap_vec(tempI))
    fprintf('   Duration cap = %.3g months \n',dur_cap_vec(tempI)*12)

end

%% Plot: duration cap and welfare 

y_max = ceil(max(dS_cap_vec(:))*100*2)/2;    

figure('pos',[100 100 450 360])
plot(dur_cap_vec*12,dS_intensive_cap_vec(11,:)*100,'-k','LineWidth',2)
hold on 
plot(dur_cap_vec*12,dS_select_cap_vec(11,:)*100,'--','Color',[0.6 0 0],'LineWidth',2)
plot(dur_cap_vec*12,dS_cap_vec(11,:)*100,':','Color',linecolor,'LineWidth',2)
plot(dur_intensive_cap_max*12,dS_intensive_cap_max*100,'Marker','o','MarkerSize',9,'MarkerEdgeColor','k','MarkerFaceColor','k')
plot(dur_cap_vec(end)*12,dS_cap_vec(11,end)*100,'Marker','s','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
if kappa_case==1
    plot(dur_cap_max*12,dS_cap_max*100,'Marker','d','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
    text(dur_cap_vec(1)*12,dS_cap_vec(11,1)*100,'Ban','HorizontalAlignment','left','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize,'interpreter','latex')
end
text(dur_cap_vec(end)*12,dS_cap_vec(11,end)*100,'Private Optimum','HorizontalAlignment','right','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize,'interpreter','latex')
hold off
pbaspect([1.5 1 1])
legend("Intensive Margin","Selection Margin",'Total','Box','off','Location','Northeast','FontSize',labelfontsize,'interpreter','latex')
xlabel('Noncompete duration, months','FontName','Arial','FontSize',labelfontsize);
ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 dur_data*12])
ylim([0 y_max])
xticks([0 2 4 6 8 10 12 14 16 18])
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')
    
if kappa_case==1
    filename = fullfile(dir_fig,'welfare_cap_baseline.eps');
elseif kappa_case==2
    filename = fullfile(dir_fig,'welfare_cap_kappa_binary.eps');
elseif kappa_case==3
    filename = fullfile(dir_fig,'welfare_cap_kappa_nocost.eps');
end
print(filename, '-depsc')    

%% Save data

if kappa_case==1
    save(fullfile(dir,'output/data','welfare_cap_baseline.mat'))
end