
%% Parameters

rho      = 0.05;          
sigma    = .24;

beta     = 0.5;  % bargaining power for setting initial wage
betal    = 0;    % worker minimum share
betau    = 1;    % worker maximum share

% calibrate parameters to match data moments
guess_x = [0.06;0.1;6];
fun_x = @(x) [1/(rho+x(1))*log(x(3)/(x(3)-1))-dur_data
             x(1)+x(2)-sep_c_data
             x(1)+x(2)*((x(3)-1)/x(3))^x(3)-sep_n_data];
sol_x = fsolve(@(x) fun_x(x),guess_x,options_fsolve);
delta    = sol_x(1);           % exogenous exit rate
lambda0  = sol_x(2);
alpha    = sol_x(3);
r        = rho+delta;

% double pareto centered at theta_c
% to the left: 1<=theta<theta_c; shape: alpha
% to the right: theta>=theta_c; shape: alpha_alt
theta_c = alpha/(alpha-1);

eq_alpha_alt = @(alpha_alt) ((1-theta_c^alpha_alt)/(-alpha_alt))/(1/alpha);
alpha_alt = fsolve(@(alpha_alt) eq_alpha_alt(alpha_alt)-dsep_alt_data/(sep_n_data-delta),-5,options_fsolve);

a = 1/(1/alpha+(1-theta_c^alpha_alt)/(-alpha_alt));
f       = @(theta) a*(theta_c^alpha*theta.^(-(alpha+1)).*(theta>=theta_c)...
                  +theta_c^alpha_alt*theta.^(-(alpha_alt+1)).*(theta<theta_c));
F       = @(theta) a*(((1-theta_c^alpha*theta.^(-alpha))/alpha+(1-theta_c^alpha_alt)/(-alpha_alt)).*(theta>=theta_c)...
                   +(theta_c^alpha_alt*(theta.^(-alpha_alt)-1)/(-alpha_alt)).*(theta<theta_c));
eq_theta  = @(theta_bar) 1+(1-F(theta_bar))./f(theta_bar)-theta_bar;
theta_bar = fsolve(@(theta_bar) eq_theta(theta_bar),theta_c,options_fsolve);
lambda = (sep_n_data-delta)/(1-F(theta_bar));
% check the formula
if alpha/(alpha-1)>=theta_c && abs(theta_bar-alpha/(alpha-1))>error
    fprintf('  Poaching threshold error = %.5g\n',theta_bar-theta_c)    
end
if abs(lambda*(F(theta_bar)-F(1))-dsep_alt_data)>error
    fprintf('  Mobility distortion error = %.5g\n',lambda*(F(theta_bar)-F(1))-dsep_alt_data)    
end

%% Entrant match quality distribution

% expected surplus at the poaching threshold
ES      = @(theta) a*(theta_c^alpha*theta.^(1-alpha)/(alpha-1).*(theta>=theta_c)...
                   +(theta_c/(alpha-1)+(theta_c-theta_c^alpha_alt*theta.^(1-alpha_alt))/(1-alpha_alt)).*(theta<theta_c))...
                   -(1-F(theta));
% expected rent value at the poaching threshold
ER      = @(theta) (theta-1).*(1-F(theta));
% expected entrant value at the poaching threshold
EE      = @(theta) ES(theta)-ER(theta);

%% Innovation cost function

epsilon = 6.8;
% calibrate phi
eq_phi  = @(x) [x(2)*(x(1)-1/2*sigma^2)^(1/epsilon)*(r-x(1))-(1-x(2)/(1+1/epsilon)*(x(1)-1/2*sigma^2)^(1+1/epsilon));...
                x(2)/(1+1/epsilon)*(x(1)-1/2*sigma^2)^(1+1/epsilon)-cmu_c_data];
temp    = fsolve(eq_phi, [(1/2*sigma^2*2+r)/3 cmu_c_data*(1+1/epsilon)/((1/2*sigma^2*2+r)/3-1/2*sigma^2)^(1+1/epsilon)], options_fsolve);
phi     = temp(2);

c       = @(mu) phi/(1+1/epsilon)*(mu-1/2*sigma^2).^(1+1/epsilon);
cp      = @(mu) phi*(mu-1/2*sigma^2).^(1/epsilon);
cpp     = @(mu) phi*(1/epsilon)*(mu-1/2*sigma^2).^(1/epsilon-1);
cp_inv  = @(mb) (mb/phi).^epsilon+1/2*sigma^2;

%% Standard contract

% Bilateral joint maximization  
theta_bar_c = 1;
eq_mu_c = @(mu) cp(mu).*(r-mu)-(1-c(mu));
mu_c    = fzero(eq_mu_c, [1/2*sigma^2 r], options_fsolve);
j_c     = (1-c(mu_c))/(r-mu_c);

%% Noncompete contract 

% Bilateral joint maximization
% private-optimal noncompete, poaching threshold 
theta_bar_guess = theta_bar;
theta_bar_n = fsolve(@(theta_bar) 1+((1-F(theta_bar))/f(theta_bar))-theta_bar, theta_bar_guess, options_fsolve);

% Marginal type 
kappa_bar_p1 = j_c*lambda*1*(theta_bar_n-1)*(1-F(theta_bar_n));
kappa_bar_p0p9 = j_c*lambda*0.9*(theta_bar_n-1)*(1-F(theta_bar_n));

%% Enforcement cost

eq_kappa = @(x) [1/2*(1+erf((log(kappa_bar_p1)-x(1))/(sqrt(2)*x(2))))-frac_n_p1;...
                1/2*(1+erf((log(kappa_bar_p1)-x(1))/(sqrt(2)*x(2))))-1/2*(1+erf((log(kappa_bar_p0p9)-x(1))/(sqrt(2)*x(2))))-dfrac_n_p1];
temp_guess = [.01;1];
temp     = fsolve(eq_kappa, temp_guess, options_fsolve);
mu_kappa = temp(1);
sigma_kappa = temp(2);
% lognormal distribution
pd       = makedist('Lognormal','mu',mu_kappa,'sigma',sigma_kappa);