
%% Parameters

rho      = 0.05;
sigma    = 0.24; 

beta     = 0.5;  % bargaining power for setting initial wage
betal    = 0;    % worker minimum share
betau    = 1;    % worker maximum share

% calibrate parameters to match data moments
guess_x  = [0.06;0.1;6];
fun_x    = @(x) [1/(rho+x(1))*log(x(3)/(x(3)-1))-dur_data
                 x(1)+x(2)-sep_c_data
                 x(1)+x(2)*((x(3)-1)/x(3))^x(3)-sep_n_data];
sol_x    = fsolve(@(x) fun_x(x),guess_x,options_fsolve);
delta    = sol_x(1);
lambda0  = sol_x(2);
alpha    = sol_x(3);
r        = rho+delta;

%% Entrant match quality distribution

theta_min = 0.768;
lambda  = lambda0/theta_min^alpha;
f       = @(theta) alpha*theta_min^alpha./theta.^(alpha+1);
F       = @(theta) 1-(theta_min./theta).^alpha;
E       = @(theta) alpha/(alpha-1)*theta_min^alpha*theta.^(1-alpha)./(1-F(theta));
% expected surplus at the poaching threshold
ES      = @(theta) (alpha/(alpha-1)*theta-1).*(1-F(theta));
% expected entrant value at the poaching threshold
EE      = @(theta) 1/(alpha-1)*theta.*(1-F(theta));
% expected rent value at the poaching threshold
ER      = @(theta) (theta-1).*(1-F(theta));

%% Innovation cost function

if i_case==1
    epsilon=6.8;
elseif i_case==2
    epsilon = 8.8;
end
% calibrate phi
eq_phi  = @(x) [x(2)*(x(1)-1/2*sigma^2)^(1/epsilon)*(r-x(1)-lambda*ER(1))-(1-x(2)/(1+1/epsilon)*(x(1)-1/2*sigma^2)^(1+1/epsilon));...
                x(2)/(1+1/epsilon)*(x(1)-1/2*sigma^2)^(1+1/epsilon)-cmu_c_data];
temp    = fsolve(eq_phi, [(1/2*sigma^2+r)/2 cmu_c_data*(1+1/epsilon)/((1/2*sigma^2+r)/2-1/2*sigma^2)^(1+1/epsilon)], options_fsolve);
phi     = temp(2);           

c       = @(mu) phi/(1+1/epsilon)*(mu-1/2*sigma^2).^(1+1/epsilon);
cp      = @(mu) phi*(mu-1/2*sigma^2).^(1/epsilon);
cpp     = @(mu) phi*(1/epsilon)*(mu-1/2*sigma^2).^(1/epsilon-1);
cp_inv  = @(mb) (mb/phi).^epsilon+1/2*sigma^2;

%% Standard contract

% Bilateral joint maximization  
theta_bar_c = 1;
eq_mu_c = @(mu) cp(mu)*(r-mu-lambda*ER(1))-(1-c(mu));
mu_c    = fzero(eq_mu_c, [1/2*sigma^2 r-lambda*ER(1)], options_fsolve);
j_c     = (1-c(mu_c))/(r-mu_c-lambda*ER(1));

%% Noncompete contract 

% Bilateral joint maximization
% private-optimal noncompete, poaching threshold 
theta_bar_guess = 1;
theta_bar_n = fsolve(@(theta_bar) 1+(1-F(theta_bar))/f(theta_bar)-theta_bar, theta_bar_guess, options_fsolve);

% Marginal type 
kappa_bar_p1 = j_c*lambda*1*(theta_bar_n-1)*(1-F(theta_bar_n));
kappa_bar_p0p9 = j_c*lambda*0.9*(theta_bar_n-1)*(1-F(theta_bar_n));

%% Enforcement cost

eq_kappa = @(x) [1/2*(1+erf((log(kappa_bar_p1)-x(1))/(sqrt(2)*x(2))))-frac_n_p1;...
                1/2*(1+erf((log(kappa_bar_p1)-x(1))/(sqrt(2)*x(2))))-1/2*(1+erf((log(kappa_bar_p0p9)-x(1))/(sqrt(2)*x(2))))-dfrac_n_p1];
temp_guess = [.01;1];
temp     = fsolve(eq_kappa, temp_guess, options_fsolve);
mu_kappa = temp(1);
sigma_kappa = temp(2);
% lognormal distribution
pd       = makedist('Lognormal','mu',mu_kappa,'sigma',sigma_kappa);

%% Matching function

if i_case == 1
    a   = 0;
    lambda_bar = lambda;
    K   = 0;
    b   = 2;
elseif i_case==2
    a   = 1;
    lambda_bar = lambda; 
    K   = 0.0381;
    b   = 2;
end

qv      = @(v) lambda_bar*v^(a-1);
pv      = @(v) lambda_bar*v^a;
pv_inv  = @(pv) (pv/lambda_bar)^(1/max(a,0.01));

