titlefontsize = 12;
labelfontsize = 12;
plotfontsize  = 12;
linewidth = 2;
linewidth_bg = 1;
markersize =1;

%% Plot Solutions

min_x_temp = exp(min([x_c_vec{i_p,1};cell2mat(x_n_vec{i_p})]));
max_x_temp = exp(max([x_c_vec{i_p,1};cell2mat(x_n_vec{i_p})]));
i_kappa_bar = i_kappa_bar_vec(i_p);

%% Stationary distribution 

figure 
set(gca,'FontSize',plotfontsize)
plot(exp(x_c_vec{i_p}),gxstat_c_vec{i_p},'b-','LineWidth',linewidth)
hold on
plot(exp(x_n_vec{i_p}{1}),gxstat_n_vec{i_p}{1},'r-.','LineWidth',linewidth)
plot(exp(x_n_vec{i_p}{i_kappa_bar}),gxstat_n_vec{i_p}{i_kappa_bar},'k-.','LineWidth',linewidth)
plot(exp(xl_c_vec(i_p))*ones(1,2),[0 1],'b:','LineWidth',linewidth_bg)
plot(exp(xu_c_vec(i_p))*ones(1,2),[0 1],'b:','LineWidth',linewidth_bg)
plot(exp(x0_c_vec(i_p))*ones(1,2),[0 1],'b:','LineWidth',linewidth_bg)
plot(exp(xl_n_vec(i_p,1))*ones(1,2),[0 1],'r:','LineWidth',linewidth_bg)
plot(exp(xu_n_vec(i_p,1))*ones(1,2),[0 1],'r:','LineWidth',linewidth_bg)
plot(exp(x0_n_vec(i_p,1))*ones(1,2),[0 1],'r:','LineWidth',linewidth_bg)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Product Ratio, $\exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Stationary distribution, $u(x)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])

filename = fullfile(dir_fig,'gx_stationary.eps');
print(filename, '-depsc')


%% Distribution evolution over time: 2D plot

figure('pos',[100 100 1800 1000])
set(gca,'FontSize',plotfontsize)

subplot(3,3,1)
plot(exp(x_c_vec{i_p}),gx_c_vec{i_p}(:,1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),gx_n_vec{i_p}{1}(:,1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),gx_n_vec{i_p}{i_kappa_bar}(:,1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time Zero PDF, $g(x,0)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])

subplot(3,3,2)
plot(exp(x_c_vec{i_p}),Gx_c_vec{i_p,1}(:,1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),Gx_n_vec{i_p}{1}(:,1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),Gx_n_vec{i_p}{i_kappa_bar}(:,1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time Zero CDF, $G(x,0)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])
ylim([0 1])

subplot(3,3,3)
plot(exp(x_c_vec{i_p}),dxdt_c_vec{i_p}(:,1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),dxdt_n_vec{i_p}{1}(:,1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),dxdt_n_vec{i_p}{i_kappa_bar}(:,1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time Zero Change','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])

subplot(3,3,4)
plot(exp(x_c_vec{i_p}),gx_c_vec{i_p}(:,1/dt+1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),gx_n_vec{i_p}{1}(:,1/dt+1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),gx_n_vec{i_p}{i_kappa_bar}(:,1/dt+1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time 1 PDF, $g(x,1)$','FontSize',labelfontsize,'interpreter','latex')

subplot(3,3,5)
plot(exp(x_c_vec{i_p}),Gx_c_vec{i_p}(:,1/dt+1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),Gx_n_vec{i_p}{1}(:,1/dt+1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),Gx_n_vec{i_p}{i_kappa_bar}(:,1/dt+1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time 1 CDF, $G(x,1)$','FontSize',labelfontsize,'interpreter','latex')
ylim([0 1])

subplot(3,3,6)
plot(exp(x_c_vec{i_p}),dxdt_c_vec{i_p}(:,1/dt+1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),dxdt_n_vec{i_p}{1}(:,1/dt+1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),dxdt_n_vec{i_p}{i_kappa_bar}(:,1/dt+1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time 1 Change','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])

subplot(3,3,7)
plot(exp(x_c_vec{i_p}),gx_c_vec{i_p}(:,10/dt+1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),gx_n_vec{i_p}{1}(:,10/dt+1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),gx_n_vec{i_p}{i_kappa_bar}(:,10/dt+1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time 10 PDF, $g(x,10)$','FontSize',labelfontsize,'interpreter','latex')

subplot(3,3,8)
plot(exp(x_c_vec{i_p}),Gx_c_vec{i_p}(:,10/dt+1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),Gx_n_vec{i_p}{1}(:,10/dt+1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),Gx_n_vec{i_p}{i_kappa_bar}(:,10/dt+1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time 10 CDF, $G(x,10)$','FontSize',labelfontsize,'interpreter','latex')
ylim([0 1])

subplot(3,3,9)
plot(exp(x_c_vec{i_p}),dxdt_c_vec{i_p}(:,10/dt+1),'b-')
hold on
plot(exp(x_n_vec{i_p}{1}),dxdt_n_vec{i_p}{1}(:,10/dt+1),'r-.')
plot(exp(x_n_vec{i_p}{i_kappa_bar}),dxdt_n_vec{i_p}{i_kappa_bar}(:,10/dt+1),'k-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time 10 Change','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])

filename = fullfile(dir_fig,'gx_evolve.eps');
print(filename, '-depsc')


%% Distribution evolution over time: 3D plot

max_gx_temp = 2;

figure('pos',[100 100 1800 1000])
set(gca,'FontSize',plotfontsize)

subplot(2,2,1)
set(gca,'FontSize',plotfontsize)
mesh(exp(x_c_vec{i_p})*ones(1,length(t)),ones(length(x_c_vec{i_p}),1)*t',min(gx_c_vec{i_p},max_gx_temp))
pbaspect([1 1 1])
title('No Noncompete','FontSize',titlefontsize)
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time, $t$','FontSize',labelfontsize,'interpreter','latex')
zlabel('Density $g(x,t)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])
ylim([0 T])
zlim([0 max_gx_temp])

subplot(2,2,2)
set(gca,'FontSize',plotfontsize)
mesh(exp(x_n_vec{i_p}{1})*ones(1,length(t)),ones(length(x_n_vec{i_p}{1}),1)*t',min(gx_n_vec{i_p}{1},max_gx_temp))
pbaspect([1 1 1])
title('Noncompete','FontSize',titlefontsize)
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time, $t$','FontSize',labelfontsize,'interpreter','latex')
zlabel('Density $g(x,t)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])
ylim([0 T])
zlim([0 max_gx_temp])

subplot(2,2,3)
set(gca,'FontSize',plotfontsize)
mesh(exp(x_c_vec{i_p})*ones(1,length(t)),ones(length(x_c_vec{i_p}),1)*t',Gx_c_vec{i_p})
pbaspect([1 1 1])
title('No Noncompete','FontSize',titlefontsize)
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time, $t$','FontSize',labelfontsize,'interpreter','latex')
zlabel('Density $g(x,t)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])
ylim([0 T])
zlim([0 1])

subplot(2,2,4)
set(gca,'FontSize',plotfontsize)
mesh(exp(x_n_vec{i_p}{1})*ones(1,length(t)),ones(length(x_n_vec{i_p}{1}),1)*t',Gx_n_vec{i_p}{1})
pbaspect([1 1 1])
title('Noncompete','FontSize',titlefontsize)
xlabel('Wage/Prdouct Ratio, $exp(x)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Time, $t$','FontSize',labelfontsize,'interpreter','latex')
zlabel('Density $g(x,t)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min_x_temp max_x_temp])
ylim([0 T])
zlim([0 1])

%% 

figure
set(gca,'FontSize',plotfontsize)

subplot(1,2,1)
plot(t,xmean_c_vec{i_p},'b-','LineWidth',linewidth)
hold on
plot(t,xmean_n_vec{i_p}{1},'r-.','LineWidth',linewidth)
plot(t,xmean_n_vec{i_p}{i_kappa_bar},'k-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Tenure','FontSize',labelfontsize,'interpreter','latex')
ylabel('Mean $x=log(w/z)$','FontSize',labelfontsize,'interpreter','latex')
xlim([0,T])

subplot(1,2,2)
plot(t,wmean_c_vec{i_p},'b-','LineWidth',linewidth)
hold on
plot(t,wmean_n_vec{i_p}{1},'r-.','LineWidth',linewidth)
plot(t,wmean_n_vec{i_p}{i_kappa_bar},'k-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete","Noncompete ($\kappa=0$)","Noncompete (marginal)",'Location','SouthEast','interpreter','latex')
legend('boxoff')
xlabel('Tenure','FontSize',labelfontsize,'interpreter','latex')
ylabel('Mean log(w)','FontSize',labelfontsize,'interpreter','latex')
xlim([0,T])

filename = fullfile(dir_fig,'wage_tenure.eps');
print(filename, '-depsc')
