titlefontsize = 12;
labelfontsize = 12;
plotfontsize  = 12;
linewidth = 2;

%% Distribution kappa

figure('pos',[100 100 700 700])
set(gca,'FontSize',plotfontsize)

subplot(2,2,1)
plot(kappa,fkappa,'b-','LineWidth',linewidth)
pbaspect([1.5 1 1])
xlabel('Enforcement Cost, $\kappa$','FontSize',labelfontsize,'interpreter','latex')
ylabel('pdf, $f(\kappa)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(kappa) max(kappa)])
ylim([0 max(fkappa)+1])

subplot(2,2,2)
plot(log(kappa),fkappa,'b-','LineWidth',linewidth)
pbaspect([1.5 1 1])
xlabel('Enforcement Cost, $log(\kappa)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('pdf, $f(\kappa)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(log(kappa)) max(log(kappa))])
ylim([0 max(fkappa)+1])

subplot(2,2,3)
plot(kappa,Fkappa,'b-','LineWidth',linewidth)
pbaspect([1.5 1 1])
xlabel('Enforcement Cost, $\kappa$','FontSize',labelfontsize,'interpreter','latex')
ylabel('cdf, $F(\kappa)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(kappa) max(kappa)])
ylim([0 1])

subplot(2,2,4)
plot(log(kappa),Fkappa,'b-','LineWidth',linewidth)
pbaspect([1.5 1 1])
xlabel('Enforcement Cost, $log(\kappa)$','FontSize',labelfontsize,'interpreter','latex')
ylabel('cdf, $F(\kappa)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(log(kappa)) max(log(kappa))])
ylim([0 1])

filename = fullfile(dir_fig,'distribution_kappa.eps');
print(filename, '-depsc')


%% Variation by p: Investment v.s. Mobility

figure('pos',[100 100 1000 1000])
set(gca,'FontSize',plotfontsize)

subplot(3,2,1)
plot(p_vec,theta_bar_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,theta_bar_n_vec,'b-','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Southwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Poaching Threshold, $\bar{\theta}$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([0 max(theta_bar_n_vec)+0.01])

subplot(3,2,2)
plot(p_vec,j2j_c_vec*100,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,j2j_n_vec*100,'b-','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Southwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('J2J Transition Rate, \%','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([min(j2j_n_vec)*100-0.1 max(j2j_c_vec)*100+0.1])

subplot(3,2,3)
plot(p_vec,sep_c_vec*100,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,sep_n_vec*100,'b-','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Southwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Separation Rate, \%','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([min(sep_n_vec)*100-0.1 max(sep_c_vec)*100+0.1])

subplot(3,2,4)
plot(p_vec,mu_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,Emu_n_vec,'b-','LineWidth',linewidth)
plot(p_vec,exp(dlogmu_vec).*(mu_c_vec-1/2*sigma^2)+1/2*sigma^2,'k-','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete","Noncompete (approx)",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Investment, $E[\mu]$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,2,5)
plot(p_vec,mu_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,mu_n_vec,'b-')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Investment, $\mu$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,2,6)
plot(p_vec,cmu_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,Ecmu_n_vec,'b-','LineWidth',linewidth)
plot(p_vec,exp(dlogcmu_vec).*cmu_c_vec,'k-','LineWidth',linewidth)
plot(p_vec,cmu_c_data*ones(N_p,1),'-.')
plot(p_vec,Ecmu_n_data*ones(N_p,1),'-.')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete","Noncompete (approx)",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Investment Rate, $c(\mu)$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([cmu_c_data-0.001 Ecmu_n_data+0.001])

filename = fullfile(dir_fig,'mobility_investment.eps');
print(filename, '-depsc')


%% Compare equilibrium with social optimum

figure('pos',[100 100 2400 1600])
set(gca,'FontSize',plotfontsize)

subplot(3,4,1)
plot(p_vec,j_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,j_n_vec,'b-')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Southwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Private Value, $j$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,4,2)
plot(p_vec,s_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,s_n_vec,'b-')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Southwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Social Value (Equilibrium), $s$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,4,3)
plot(p_vec,s_c_vec,'r-.','LineWidth',linewidth)
hold on
plot(p_vec,s_n_star_t0_vec,'b-')
plot(p_vec,s_n_star_ss_vec,'g-')
hold off
pbaspect([1.5 1 1])
legend("No Noncompete", "Noncompete",'Box','off','Location','Southwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Social Value (Optimum), $s$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,4,4)
plot(p_vec,Delta_vec,'b-','LineWidth',linewidth)
hold on
plot(p_vec,Delta_star_t0_vec,'r-')
plot(p_vec,Delta_star_ss_vec,'g-.')
hold off
pbaspect([1.5 1 1])
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Wedge, $\Delta$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,4,5)
plot(p_vec,pie_vec,'b-','LineWidth',linewidth)
hold on
plot(p_vec,pie_star_t0_vec,'r-','LineWidth',linewidth)
plot(p_vec,pie_star_ss_vec,'g-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Noncompete Duration, $\pi$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([0 max(pie_vec)+0.1])

subplot(3,4,6)
plot(p_vec,mu_n_vec,'b-')
hold on
plot(p_vec,mu_n_star_t0_vec,'r-')
plot(p_vec,mu_n_star_ss_vec,'g-.')
plot(p_vec,mu_c_vec,'k-','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Investment, $\mu$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])

subplot(3,4,7)
plot(p_vec,kappa_bar_vec,'b-','LineWidth',linewidth)
hold on
plot(p_vec,kappa_bar_star_t0_vec,'r-','LineWidth',linewidth)
plot(p_vec,kappa_bar_star_t0_vec,'g-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("Private optimum", "Social optimum (t0)", "Social optimum (ss)", 'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Enrofce Cost Threshold, $\bar{\kappa}$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([0 kappau])

subplot(3,4,8)
plot(p_vec,frac_n_vec,'b-','LineWidth',linewidth)
hold on
plot(p_vec,frac_n_star_t0_vec,'r-','LineWidth',linewidth)
plot(p_vec,frac_n_star_ss_vec,'g-','LineWidth',linewidth)
plot(p_vec,frac_n_approx_vec,'b-.o')
plot(p_vec,frac_n_star_t0_approx_vec,'r-.s')
plot(p_vec,frac_n_star_ss_approx_vec,'g-.d')
hold off
pbaspect([1.5 1 1])
legend("Private optimum", "Social optimum (t0)", "Social optimum (ss)", 'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Fraction of Non-Compete','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([0 1])

min_temp = min([dS_t0_vec;dS_reallocate_t0_vec;dS_invest_t0_vec;dS_select_t0_vec;dY_ss_vec;dY_invest_ss_vec;dY_select_ss_vec])*100;
max_temp = max([dS_t0_vec;dS_reallocate_t0_vec;dS_invest_t0_vec;dS_select_t0_vec;dY_ss_vec;dY_invest_ss_vec;dY_select_ss_vec])*100;

subplot(3,4,9)
plot(p_vec,dS_t0_vec*100,'b-','LineWidth',linewidth)
hold on
plot(p_vec,dS_reallocate_t0_vec*100,'r-.','LineWidth',linewidth)
plot(p_vec,dS_invest_t0_vec*100,'k-.','LineWidth',linewidth)
plot(p_vec,dS_select_t0_vec*100,'g-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("Overall", "Reallocate","Investment","Selection",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Optimum (t0), $d\log(Welfare),\%$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([min_temp max_temp])

subplot(3,4,10)
plot(p_vec,Y_vec,'b-','LineWidth',linewidth)
hold on
plot(p_vec,Y_star_t0_vec,'r-.','LineWidth',linewidth)
plot(p_vec,Y_star_ss_vec,'g-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("Private optimum", "Social optimum (t0)", "Social optimum (ss)",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Output','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])


subplot(3,4,11)
plot(p_vec,dY_ss_vec*100,'b-','LineWidth',linewidth)
hold on
plot(p_vec,dY_reallocate_ss_vec*100,'r-.','LineWidth',linewidth)
plot(p_vec,dY_invest_ss_vec*100,'k-.','LineWidth',linewidth)
plot(p_vec,dY_select_ss_vec*100,'g-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend("Overall", "Reallocate","Investment","Selection",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('Optimum (ss), $d\log(Y),\%$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([min_temp max_temp])

subplot(3,4,12)
plot(p_vec,(Z_star_t0_vec./Z_vec-1)*100,'r-','LineWidth',linewidth)
hold on
plot(p_vec,(Z_star_ss_vec./Z_vec-1)*100,'g-.','LineWidth',linewidth)
hold off
pbaspect([1.5 1 1])
legend( "Social optimum (t0)", "Social optimum (ss)",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Enforce Prob, $p$','FontSize',labelfontsize,'interpreter','latex')
ylabel('$dlog(Z),\%$','FontSize',labelfontsize,'interpreter','latex')
xlim([min(p_vec) max(p_vec)])
ylim([min_temp max_temp])

filename = fullfile(dir_fig,'vary_p.eps');
print(filename, '-depsc')



