%% Initialize the setting

clear;
close all;
clc;
format compact
format short

plotfontsize  = 18;
labelfontsize = 18;
linecolor = 1/255*[0 0 153];

%% Folder path 

dir = fileparts(fileparts(cd));
dir_fig = fullfile(dir,'output/figures/baseline');
if ~exist(dir_fig,'dir')
    mkdir(dir_fig)
end

%% Load data

load(fullfile(dir,'output/data','wage_tenure_model.mat'))

data_filename = fullfile(fileparts(dir),'empirical/analysis/output/data/tdc2_tenure.csv');
data_raw = readtable(data_filename,'VariableNamingRule','preserve');
data = table2array(data_raw(:,[6,end-1,end]));
data_c = data(data(:,3)==0,:);

%% Plot: cross state variation

figure('pos',[100 100 450 360])
plot(t+1,wmean_c+data_c(1,1)-wmean_c(1),'Color',[0 0 0],'LineWidth',2)
hold on 
plot(data_c(:,2),data_c(:,1),'LineStyle','none','Marker','o','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
hold off
pbaspect([1.5 1 1])
xlh = xlabel('Tenure, years','FontName','Arial','FontSize',labelfontsize);
ylh = ylabel('Log wage','FontName','Arial','FontSize',labelfontsize);
xlim([1 11])
ylim([-0.1 0.6])
xticks([1 2 3 4 5 6 7 8 9 10 11])
yticks([-0.1 0 0.1 0.2 0.3 0.4 0.5 0.6])
legend({'Model','Data'},'Box','off','Location','northwest','FontSize',labelfontsize);
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')
    
filename = fullfile(dir_fig,'data_moment_wage_tenure.eps');
print(filename, '-depsc')


