
%% Initialize the setting

clear;
close all;
clc;
format compact
format short

options_fsolve  =  optimset('fsolve');
options_fsolve  =  optimset(options_fsolve , 'TolFun'      , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'TolX'        , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'Display'     , 'off');
options_fsolve  =  optimset(options_fsolve , 'MaxFunEvals' , 1000);
options_fsolve  =  optimset(options_fsolve , 'MaxIter' , 1000);

%% Specification

% set to 1 if exogneous entry
%        2 if endogenous entry
i_case = 2;

% whether to impose a simple duration cap
case_duration_cap = 0;
dur_cap = Inf;

%% Folder path 

% base folder
dir = fileparts(fileparts(cd));
% figure folder
dir_fig = fullfile(dir,'output/figures/free_entry');

%% Parameters

run(fullfile(dir,'code/parameters','data_moment.m'));
run(fullfile(dir,'code/parameters','parameters_entry.m'));
run(fullfile(dir,'code/grids','grid.m'));
error = 5e-3;

%% Prepare to store results

%% equilibrium objects

% standard contract
theta_bar_c_vec = zeros(N_p,1);
j_c_vec  = zeros(N_p,1);
mu_c_vec = zeros(N_p,1);
cmu_c_vec = zeros(N_p,1);
j2j_c_vec = zeros(N_p,1);
sep_c_vec = zeros(N_p,1);
Z_c_vec   = zeros(N_p,1);
Y_c_vec   = zeros(N_p,1);
s_c_vec   = zeros(N_p,1);

% noncompete contract
j_n_vec = zeros(N_p,N_kappa);
mu_n_vec = zeros(N_p,N_kappa);
i_n_vec = zeros(N_p,N_kappa);

Emu_n_vec = zeros(N_p,1);
Ecmu_n_vec = zeros(N_p,1);
theta_bar_n_vec = zeros(N_p,1);
j2j_n_vec = zeros(N_p,1);
sep_n_vec = zeros(N_p,1);

Z_n_vec = zeros(N_p,N_kappa);
Y_n_vec = zeros(N_p,N_kappa);

% aggregation
kappa_bar_vec = zeros(N_p,1);
frac_n_vec = zeros(N_p,1);
frac_n_approx_vec = zeros(N_p,1);
pie_vec = zeros(N_p,1);
kappa_mean_vec = zeros(N_p,1);

j2j_vec = zeros(N_p,1);
sep_vec = zeros(N_p,1);
cmu_vec = zeros(N_p,1);

dlogmu_vec = zeros(N_p,1);
dlogcmu_vec = zeros(N_p,1);
gz_prox_c_vec = cell(N_p,1);
gz_prox_n_vec = cell(N_p,1);

Z_vec = zeros(N_p,1); 
Y_vec   = zeros(N_p,1);

% social values
s_n_vec  = zeros(N_p,N_kappa);
S_1_vec  = zeros(N_p,1);
S_ss_vec = zeros(N_p,1);
Delta_vec = zeros(N_p,N_kappa);

% entry
lambda_endo_vec = zeros(N_p,1);
v_vec = zeros(N_p,1);

%% Iterate over enforcement regimes

for i_p =1:N_p
    
    p   = p_vec(i_p);
    disp(['P Iteration = ' num2str(i_p) ...
          ', p = ' num2str(p)])

    %% Solve equilibrium
    
    run(fullfile(dir,'code/solve','solve_equilibrium_entry.m'));

    %% Store results    
    
    theta_bar_c_vec(i_p) = theta_bar_c;
    j_c_vec(i_p)   = j_c;
    mu_c_vec(i_p)  = mu_c;
    cmu_c_vec(i_p) = cmu_c;
    j2j_c_vec(i_p) = j2j_c;
    sep_c_vec(i_p) = sep_c;
    Z_c_vec(i_p)   = Z_c;
    Y_c_vec(i_p)   = Y_c;
    s_c_vec(i_p)   = s_c;    

    j_n_vec(i_p,:) = j_n;
    mu_n_vec(i_p,:) = mu_n;
    i_n_vec(i_p,:) = i_n;

    theta_bar_n_vec(i_p) = theta_bar_n;
    pie_vec(i_p) = pie;
    kappa_bar_vec(i_p) = kappa_bar;    
    frac_n_vec(i_p) = frac_n;
    frac_n_approx_vec(i_p) = frac_n_approx;
           
    j2j_n_vec(i_p) = j2j_n;    
    sep_n_vec(i_p) = sep_n;    
    j2j_vec(i_p) = j2j;
    sep_vec(i_p) = sep;
    Emu_n_vec(i_p) = Emu_n;            
    Ecmu_n_vec(i_p) = Ecmu_n;        
    cmu_vec(i_p) = cmu;

    Z_n_vec(i_p,:) = Z_n;    
    Z_vec(i_p) = Z;        
    Y_n_vec(i_p,:) = Y_n;
    Y_vec(i_p) = Y;
    
    kappa_mean_vec(i_p) = kappa_mean;        
    dlogmu_vec(i_p) = dlogmu;     
    dlogcmu_vec(i_p) = dlogcmu;     
    
    s_n_vec(i_p,:) = s_n;
    S_1_vec(i_p) = S_1;
    S_ss_vec(i_p) = S_ss;
    Delta_vec(i_p,:) = Delta;
        
    gz_prox_c_vec{i_p} = gz_prox_c;
    gz_prox_n_vec{i_p} = gz_prox_n;
       
    lambda_endo_vec(i_p) = lambda_endo;
    v_vec(i_p) = v;
    
    %% Display results

    disp('   Equilibrium:')
    fprintf('       Fraction with noncompete = %.4g\n',frac_n)  
    fprintf('       Cost threshold, kappa_bar = %.4g\n',kappa_bar)  
    fprintf('       Noncompete duration = %.3g\n',pie)
    fprintf('       Output = %.5g\n',Y)
    fprintf('       Buyout = %.5g\n',theta_bar_n-1)
    fprintf('       Rent = %.5g\n',lambda*p*(1-F(theta_bar_n))*(theta_bar_n-1)) 
    M_temp = [theta_bar_c theta_bar_n;...
              j2j_c j2j_n;...
              sep_c sep_n;...
              mu_c Emu_n;...
              cmu_c Ecmu_n;...
              zetap_c zetap_n];
    disp(array2table(M_temp,...
             'VariableNames',{'Standard','Noncompete'},...
             'RowNames',{'Poaching Threshold','J2J rate','Sep rate','Drift', 'Invest rate', 'Pareto tail'}))
    fprintf('       J2J transition rate = %.3g%%\n',j2j*100)
    fprintf('       Separation rate = %.3g%%\n',sep*100) 
    fprintf('       Investment rate = %.3g%%\n',cmu*100) 
    disp(' ')   

end

