
%% Initialize the setting

clear;
close all;
clc;
format compact
format short

options_fsolve  =  optimset('fsolve');
options_fsolve  =  optimset(options_fsolve , 'TolFun'      , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'TolX'        , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'Display'     , 'off');
options_fsolve  =  optimset(options_fsolve , 'MaxFunEvals' , 1000);
options_fsolve  =  optimset(options_fsolve , 'MaxIter' , 1000);

plotfontsize  = 18;
labelfontsize = 18;
linecolor = 1/255*[0 0 153];

%% Folder path 

% base folder
dir = fileparts(fileparts(cd));
% figure folder
dir_fig = fullfile(dir,'output/figures/discount_rate');
if ~exist(dir_fig,'dir')
    mkdir(dir_fig)
end

% data
run(fullfile(dir,'code/parameters','data_moment.m'));

%% Specification

% discount factor cases
rho_vec = [0.05 1e-5];
N_case = length(rho_vec);  
% for full enforcement
p      = 1;               
error  = 5e-3;

% duration cap grid
case_duration_cap = 1;
N_dur = 201;    
dur_cap_vec = linspace(0,dur_data,N_dur)';

%% Prepare to store results

kappa_bar_cap_vec = zeros(N_case,N_dur);
frac_n_cap_vec = zeros(N_case,N_dur);
frac_n_cap_approx_vec = zeros(N_case,N_dur);

s_n_kappa0_cap_vec = zeros(N_case,N_dur);

S_cap_vec = zeros(N_case,N_dur);
dS_cap_vec = zeros(N_case,N_dur);
dS_reallocate_cap_vec = zeros(N_case,N_dur);
dS_invest_cap_vec = zeros(N_case,N_dur);
dS_intensive_cap_vec = zeros(N_case,N_dur); 
dS_select_cap_vec = zeros(N_case,N_dur);

S_ss_cap_vec = zeros(N_case,N_dur);
Y_cap_vec = zeros(N_case,N_dur);
dY_cap_vec = zeros(N_case,N_dur);
dY_reallocate_cap_vec = zeros(N_case,N_dur);
dY_invest_cap_vec = zeros(N_case,N_dur);    
dY_intensive_cap_vec = zeros(N_case,N_dur);    
dY_select_cap_vec = zeros(N_case,N_dur);

dS_intensive_cap_max_vec = zeros(N_case,1);
dur_S_intensive_cap_max_vec = zeros(N_case,1);
dY_intensive_cap_max_vec = zeros(N_case,1);
dur_Y_intensive_cap_max_vec = zeros(N_case,1);
 
%% Welfare analysis

for i_case=1:N_case
    
    disp(' ')
    fprintf('Case: %.0g\n', i_case)

    run(fullfile(dir,'code/parameters','parameters_discount.m'));    
    run(fullfile(dir,'code/grids','grid_finetune_kappa.m'));
    
    Y_vec = zeros(N_dur,1);
    frac_n_vec = zeros(N_dur,1);
    s_n_vec = zeros(N_dur,N_kappa);
    Z_n_vec = zeros(N_dur,N_kappa);
    S_1_vec = zeros(N_dur,1);
    S_ss_vec = zeros(N_dur,1);

    dur_cap = Inf;
    run(fullfile(dir,'code/solve','solve_equilibrium.m'));
    
    for i_dur=1:N_dur
        
        %% solve equilibrium subject to the cap
        
        dur_cap = dur_cap_vec(i_dur);
        run(fullfile(dir,'code/solve','solve_social_optimum_t0.m'));   
        run(fullfile(dir,'code/solve','solve_social_optimum_ss.m'));
        run(fullfile(dir,'code/solve','solve_cap.m'));
        
        %% store results 
        
        s_n_kappa0_cap_vec(i_case,i_dur) = s_n_star_t0(1);
      
        kappa_bar_cap_vec(i_case,i_dur) = kappa_bar_cap;
        frac_n_cap_vec(i_case,i_dur) = frac_n_cap;
        frac_n_cap_approx_vec(i_case,i_dur) = frac_n_cap_approx;

        S_cap_vec(i_case,i_dur) = S_cap;
        dS_cap_vec(i_case,i_dur) = dS_cap;
        dS_reallocate_cap_vec(i_case,i_dur) = dS_reallocate_cap;
        dS_invest_cap_vec(i_case,i_dur) = dS_invest_cap;
        dS_intensive_cap_vec(i_case,i_dur) = dS_reallocate_cap+dS_invest_cap;                
        dS_select_cap_vec(i_case,i_dur) = dS_select_cap;
        
        S_ss_cap_vec(i_case,i_dur) = S_ss_cap;
        Y_cap_vec(i_case,i_dur) = Y_cap;
        dY_cap_vec(i_case,i_dur) = dY_cap;
        dY_reallocate_cap_vec(i_case,i_dur) = dY_reallocate_cap;
        dY_invest_cap_vec(i_case,i_dur) = dY_invest_cap;    
        dY_intensive_cap_vec(i_case,i_dur) = dY_reallocate_cap+dY_invest_cap;    
        dY_select_cap_vec(i_case,i_dur) = dY_select_cap;   
        
    end
 
    %% Display
    
    % time 0 welfare
    disp(' Time-0 welfare:')    
    [dS_cap_max, tempI] = max(dS_cap_vec(i_case,:));
    dur_S_cap_max = dur_cap_vec(tempI);
    fprintf(' Overall\n')
    fprintf('   Gain = %.3g%%\n',dS_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_S_cap_max)    
    fprintf('   Duration cap = %.3g months\n',dur_S_cap_max*12)    
    
    [dS_intensive_cap_max, tempI] = max(dS_intensive_cap_vec(i_case,:));
    dur_S_intensive_cap_max = dur_cap_vec(tempI);
    fprintf(' Intensive margin\n')
    fprintf('   Gain = %.3g%%\n',dS_intensive_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_S_intensive_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_S_intensive_cap_max*12)  
    
    dS_intensive_cap_max_vec(i_case) = dS_intensive_cap_max;
    dur_S_intensive_cap_max_vec(i_case) = dur_S_intensive_cap_max;

    [~, tempI] = max(s_n_kappa0_cap_vec(i_case,:));
    fprintf('   type kappa=0\n')
    fprintf('   Duration cap = %.3g years\n',dur_cap_vec(tempI))
    fprintf('   Duration cap = %.3g months \n',dur_cap_vec(tempI)*12)
    
    % steady state welfare
    disp(' Steady-state welfare:')        
    [dY_cap_max, tempI] = max(dY_cap_vec(i_case,:));
    dur_Y_cap_max = dur_cap_vec(tempI);
    fprintf(' Overall\n')
    fprintf('   Gain = %.3g\n',dur_Y_cap_max)
    fprintf('   Duration cap = %.3g years\n',dY_cap_max)    
    fprintf('   Duration cap = %.3g months\n',dY_cap_max*12)    
    
    [dY_intensive_cap_max, tempI] = max(dY_intensive_cap_vec(i_case,:));
    dur_Y_intensive_cap_max = dur_cap_vec(tempI);
    fprintf(' Intensive margin\n')
    fprintf('   Gain = %.3g\n',dY_intensive_cap_max)
    fprintf('   Duration cap = %.3g years\n',dur_Y_intensive_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_Y_intensive_cap_max*12)
    
    dY_intensive_cap_max_vec(i_case) = dY_intensive_cap_max;
    dur_Y_intensive_cap_max_vec(i_case) = dur_Y_intensive_cap_max;
    
end

%% Plot: duration cap and welfare

figure('pos',[100 100 450 350])
plot(dur_cap_vec*12,dS_intensive_cap_vec(1,:)*100,'-k','LineWidth',3)
hold on
plot(dur_cap_vec*12,dY_intensive_cap_vec(1,:)*100,'-r','LineWidth',1)   
plot(dur_cap_vec*12,dS_intensive_cap_vec(2,:)*100,'--k','LineWidth',3)
plot(dur_cap_vec*12,dY_intensive_cap_vec(2,:)*100,'--r','LineWidth',1)
plot(dur_S_intensive_cap_max_vec(1)*12,dS_intensive_cap_max_vec(1)*100,'Marker','o','MarkerSize',8,'MarkerEdgeColor','k','MarkerFaceColor','k')
plot(dur_Y_intensive_cap_max_vec(1)*12,dY_intensive_cap_max_vec(1)*100,'Marker','*','MarkerSize',12,'MarkerEdgeColor','r','MarkerFaceColor','r')
plot(dur_S_intensive_cap_max_vec(2)*12,dS_intensive_cap_max_vec(2)*100,'Marker','o','MarkerSize',8,'MarkerEdgeColor','k','MarkerFaceColor','k')
plot(dur_Y_intensive_cap_max_vec(2)*12,dY_intensive_cap_max_vec(2)*100,'Marker','*','MarkerSize',12,'MarkerEdgeColor','r','MarkerFaceColor','r')
hold off
pbaspect([1.5 1 1])
legend("$\rho=5\%$ Transition","$\rho=5\%$ Steady State","$\rho\rightarrow0\%$ Transition ","$\rho\rightarrow0\%$ Steady State",...
        'Box','off','Location','East','FontSize',labelfontsize,'interpreter','latex')
xlabel('Noncompete duration, months','FontName','Arial','FontSize',labelfontsize);
ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 dur_data*12])
ylim([0 4])
xticks([0 2 4 6 8 10 12 14 16 18])
xtickangle(0)
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

filename = fullfile(dir_fig,'welfare_cap_discount.eps');
print(filename, '-depsc')

%% Save data

save(fullfile(dir,'output/data','welfare_cap_discount.mat'))
