
%% Initialize the setting

clear;
close all;
clc;
format compact
format short

options_fsolve  =  optimset('fsolve');
options_fsolve  =  optimset(options_fsolve , 'TolFun'      , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'TolX'        , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'Display'     , 'off');
options_fsolve  =  optimset(options_fsolve , 'MaxFunEvals' , 1000);
options_fsolve  =  optimset(options_fsolve , 'MaxIter' , 1000);

plotfontsize  = 18;
labelfontsize = 18;
linecolor = 1/255*[0 0 153];

%% Folder path 

% base folder
dir = fileparts(fileparts(cd));
% figure folder
dir_fig = fullfile(dir,'output/figures/mobility_distortion');
if ~exist(dir_fig,'dir')
    mkdir(dir_fig)
end

% data
run(fullfile(dir,'code/parameters','data_moment.m'));

%% Specification

% distortion cases
dsep_alt_data_vec = 0.018*[1 1.5 2 0.75 0.5074 0.3 0.2 0.1 0.01]';
N_case = length(dsep_alt_data_vec);  
% for full enforcement
p      = 1;        
error  = 5e-3;

alpha_alt_vec = zeros(size(dsep_alt_data_vec));
f_vec  = cell(size(dsep_alt_data_vec));
F_vec  = cell(size(dsep_alt_data_vec));

% duration cap grid
N_dur = 201;    
dur_cap_vec = linspace(0,dur_data,N_dur)';

%% Prepare to store results

kappa_bar_cap_vec = zeros(1,N_dur);
frac_n_cap_vec = zeros(1,N_dur);
frac_n_cap_approx_vec = zeros(1,N_dur);

s_n_kappa0_cap_vec = zeros(1,N_dur);

S_cap_vec = zeros(1,N_dur);
dS_cap_vec = zeros(1,N_dur);
dS_reallocate_cap_vec = zeros(1,N_dur);
dS_invest_cap_vec = zeros(1,N_dur);
dS_intensive_cap_vec = zeros(1,N_dur); 
dS_select_cap_vec = zeros(1,N_dur);

S_ss_cap_vec = zeros(1,N_dur);
Y_cap_vec = zeros(1,N_dur);
dY_cap_vec = zeros(1,N_dur);
dY_reallocate_cap_vec = zeros(1,N_dur);
dY_invest_cap_vec = zeros(1,N_dur);    
dY_select_cap_vec = zeros(1,N_dur);

dur_intensive_cap_max_vec = zeros(N_case,1);
dS_intensive_cap_max_vec = zeros(N_case,1);

Delta_max_vec = zeros(N_case,1);

%% Welfare analysis

for i_case=1:N_case
    
    disp(' ')
    fprintf('Case = %d\n',i_case)

    dsep_alt_data = dsep_alt_data_vec(i_case);    
    run(fullfile(dir,'code/parameters','parameters_distortion.m'));
    % store calibrated shape parameter
    alpha_alt_vec(i_case) = alpha_alt;
    f_vec{i_case} = f;
    F_vec{i_case} = F;    
    run(fullfile(dir,'code/grids','grid_finetune_kappa.m'));

    Y_vec = zeros(1,1);
    frac_n_vec = zeros(N_dur,1);
    s_n_vec = zeros(N_dur,N_kappa);
    Z_n_vec = zeros(N_dur,N_kappa);
    S_1_vec = zeros(N_dur,1);
    S_ss_vec = zeros(N_dur,1);

    dur_cap = Inf;
    run(fullfile(dir,'code/solve','solve_equilibrium.m'));

    fprintf(' Mobility decline = %0.2f%% \n',dsep_alt_data*100)    
    fprintf(' Investment cost increase, average = %0.1f%%\n',(Ecmu_n-c(mu_c))*100)
    fprintf(' Calibrated distribution parameter = %0.1f\n',alpha_alt)
    
    case_duration_cap = 0;   
    run(fullfile(dir,'code/solve','solve_social_optimum_t0.m'));    
    Delta_max_vec(i_case) = Delta_star_t0(1);
    
    for i_dur=1:N_dur
        
        %% solve equilibrium subject to the cap
        
        case_duration_cap = 1;
        dur_cap = dur_cap_vec(i_dur);
        run(fullfile(dir,'code/solve','solve_social_optimum_t0.m'));    
        run(fullfile(dir,'code/solve','solve_cap.m'));
        
        %% store results 
        
        s_n_kappa0_cap_vec(i_case,i_dur) = s_n_star_t0(1);
        
        kappa_bar_cap_vec(i_case,i_dur) = kappa_bar_cap;
        frac_n_cap_vec(i_case,i_dur) = frac_n_cap;
        frac_n_cap_approx_vec(i_case,i_dur) = frac_n_cap_approx;

        S_cap_vec(i_case,i_dur) = S_cap;
        dS_cap_vec(i_case,i_dur) = dS_cap;
        dS_reallocate_cap_vec(i_case,i_dur) = dS_reallocate_cap;
        dS_invest_cap_vec(i_case,i_dur) = dS_invest_cap;
        dS_intensive_cap_vec(i_case,i_dur) = dS_reallocate_cap+dS_invest_cap;                
        dS_select_cap_vec(i_case,i_dur) = dS_select_cap;
        
        S_ss_cap_vec(i_case,i_dur) = S_ss_cap;
        Y_cap_vec(i_case,i_dur) = Y_cap;
        dY_cap_vec(i_case,i_dur) = dY_cap;
        dY_reallocate_cap_vec(i_case,i_dur) = dY_reallocate_cap;
        dY_invest_cap_vec(i_case,i_dur) = dY_invest_cap;    
        dY_select_cap_vec(i_case,i_dur) = dY_select_cap;   
        
        if mod(i_dur,10)==0
            display(['    duration iteration = ' num2str(i_dur)])
        end
    end
 
    %% Display

    [dS_cap_max, tempI] = max(dS_cap_vec(i_case,:));
    dur_cap_max = dur_cap_vec(tempI);
    fprintf(' Time-0 welfare:\n')
    fprintf(' Overall\n')
    fprintf('   Gain = %.3g%%\n',dS_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_cap_max*12)    
    
    [dS_intensive_cap_max, tempI] = max(dS_intensive_cap_vec(i_case,:));
    dur_intensive_cap_max = dur_cap_vec(tempI);
    fprintf(' Intensive margin\n')
    fprintf('   Gain = %.3%%g\n',dS_intensive_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_intensive_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_intensive_cap_max*12)        
    
    dur_intensive_cap_max_vec(i_case) = dur_intensive_cap_max;
    dS_intensive_cap_max_vec(i_case) = dS_intensive_cap_max;

    [~, tempI] = max(s_n_kappa0_cap_vec(i_case,:));
    fprintf('   type kappa=0\n')
    fprintf('   Duration cap = %.3g years\n',dur_cap_vec(tempI))
    fprintf('   Duration cap = %.3g months \n',dur_cap_vec(tempI)*12)

    [dS_select_cap_max, tempI] = max(dS_select_cap_vec(i_case,:));
    dur_select_cap_max = dur_cap_vec(tempI);    
    fprintf(' Selection margin\n')
    fprintf('   Gain = %.3g%%\n',dS_select_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_select_cap_max)    
    fprintf('   Duration cap = %.3g months\n',dur_select_cap_max*12)      

    %% Plot

    figure('pos',[100 100 450 360])
    plot(dur_cap_vec,dS_intensive_cap_vec(i_case,:)*100,'-k','LineWidth',2)
    hold on 
    plot(dur_cap_vec,dS_select_cap_vec(i_case,:)*100,'--','Color',[0.6 0 0],'LineWidth',2)
    plot(dur_cap_vec,dS_cap_vec(i_case,:)*100,':','Color',linecolor,'LineWidth',2)
    plot(dur_intensive_cap_max,dS_intensive_cap_max*100,'Marker','o','MarkerSize',9,'MarkerEdgeColor','k','MarkerFaceColor','k')
    plot(dur_cap_max,dS_cap_max*100,'Marker','d','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
    plot(dur_cap_vec(end),dS_cap_vec(i_case,end)*100,'Marker','s','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
    text(dur_cap_vec(1),dS_cap_vec(i_case,1)*100,'Ban','HorizontalAlignment','left','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize)
    text(dur_cap_vec(end),dS_cap_vec(i_case,end)*100,'Private Optimum','HorizontalAlignment','right','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize)
    hold off
    pbaspect([1.5 1 1])
    legend("Intensive Margin","Selection Margin",'Total','Box','off','Location','Northeast','FontSize',labelfontsize)
    xlabel('Noncompete duration, years','FontName','Arial','FontSize',labelfontsize);
    ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
    xlim([0 dur_data])
    ylim([0 ceil(max(dS_cap_vec(:))*100*2)/2])
    xticks([0 .2 .4 .6 .8 1 1.2 1.4 1.6])
    set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

    filename = fullfile(dir_fig,strcat('welfare_cap_alpha',num2str(i_case),'.eps'));
    print(filename, '-depsc')    

end

%% Plot: duration cap and welfare

figure('pos',[100 100 450 360])
plot(dur_intensive_cap_max_vec(1:3)*12,dS_intensive_cap_max_vec(1:3)*100,'-.b','Marker','o','LineWidth',1,'MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','b')
hold on
for i_case=1:N_case
    if i_case==1
        linewidth = 2;
    else 
        linewidth = 1;
    end
    if i_case<=3
        grey_shade = [1 1 1]*0.15*i_case;
        plot(dur_cap_vec*12,dS_intensive_cap_vec(i_case,:)*100,'Color',grey_shade,'LineWidth',linewidth)        
    elseif i_case>3
        grey_shade = [1 1 1]*0.15*(i_case-3);
        plot(dur_cap_vec*12,dS_intensive_cap_vec(i_case,:)*100,'--','Color',grey_shade,'LineWidth',linewidth)            
    end    
end
plot(dur_cap_vec*12,dS_intensive_cap_vec(1,:)*100,'Color',[1 1 1]*0.15*1,'LineWidth',2)
plot([dur_intensive_cap_max_vec(1);dur_intensive_cap_max_vec(4:end)]*12,[dS_intensive_cap_max_vec(1);dS_intensive_cap_max_vec(4:end)]*100,'-.','Color','b','LineWidth',1,'Marker','o','MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','none')
plot(dur_intensive_cap_max_vec(1:3)*12,dS_intensive_cap_max_vec(1:3)*100,'LineStyle','none','Marker','o','LineWidth',1,'MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','b')
hold off
pbaspect([1.5 1 1])
legend("Optimal Cap",  "$\hat{\alpha}=6.3$ (Baseline)",...
                       "$\hat{\alpha}=10.1$",...
                       "$\hat{\alpha}=12.7$",...
                       "$\hat{\alpha}=3.4$",...
                       "$\hat{\alpha}=-1$",...
                       "$\hat{\alpha}=-4$",...
                       "$\hat{\alpha}=-14$",...
                       "$\hat{\alpha}=-32$",...      
                       "$\hat{\alpha}=-320$",...                                         
        'Box','off','NumColumns',2,'Location','Northeast','FontSize',labelfontsize,'interpreter','latex')
xlabel('Noncompete duration, months','FontName','Arial','FontSize',labelfontsize);
ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 dur_data*12])
ylim([-0.2 4])
xticks([0 2 4 6 8 10 12 14 16 18])
xtickangle(0)
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

filename = fullfile(dir_fig,'welfare_cap_alpha.eps');
print(filename, '-depsc')


%% Plot: model implied mobility decline

pie_star_approx = epsilon.*Delta_max_vec./(epsilon.*Delta_max_vec+1)*pie;
deta_vec = dsep_alt_data_vec./(dsep_alt_data_vec+sep_n_data-delta);

figure('pos',[100 100 450 360])
plot(dur_intensive_cap_max_vec(1:3)*12,deta_vec(1:3),'-.b','Marker','o','LineWidth',1,'MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','b')
hold on
plot(pie_star_approx(1:3)*12,deta_vec(1:3),'-.r','Marker','S','LineWidth',1,'MarkerSize',10,'MarkerEdgeColor','r','MarkerFaceColor','r')
plot([pie_star_approx(1);pie_star_approx(4:end)]*12,[deta_vec(1);deta_vec(4:end)],'-.','Color','r','Marker','S','LineWidth',1,'MarkerSize',10,'MarkerEdgeColor','r','MarkerFaceColor','none')
plot([dur_intensive_cap_max_vec(1);dur_intensive_cap_max_vec(4:end)]*12,[deta_vec(1);deta_vec(4:end)],'-.','Color','b','Marker','o','LineWidth',1,'MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','none')
plot(dur_intensive_cap_max_vec(1:3)*12,deta_vec(1:3),'-.b','Marker','o','LineWidth',1,'MarkerSize',8,'MarkerEdgeColor','b','MarkerFaceColor','b')
text(dur_intensive_cap_max_vec(1)*12+0.3,2/3,'$\leftarrow$Baseline','HorizontalAlignment','left','FontSize',18,'FontWeight','bold','interpreter','latex');
hold off
legend("Precise cap","Approximation",...
        'Box','off','NumColumns',1,'Location','Northeast','FontSize',labelfontsize,'interpreter','latex')
xlabel('Optimal duration cap, months','FontName','Arial','FontSize',labelfontsize);
ylabel('$\frac{\eta^c-\eta^n}{\eta^c}$','FontName','Arial','FontSize',labelfontsize,'interpreter','latex');
pbaspect([1.5 1 1])
xlim([0 dur_data*12])
yticks([-1 -0.8 -0.6 -0.4 -0.2 0 0.2 0.4 0.6 0.8 1])
% yt = get(gca, 'YTick');
% ytl = compose('%.0f%%',yt*100);
% set(gca, 'YTick',yt, 'YTickLabel',ytl)
xticks([0 2 4 6 8 10 12 14 16 18])
xtickangle(0)
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

filename = fullfile(dir_fig,'deta_cap.eps');
print(filename, '-depsc')


%% Plot: theta distribution 

theta_plot = linspace(1,3,1000);

% pdf

figure('pos',[100 100 450 360])
hold on
for i_case=1:N_case
    f_plot = f_vec{i_case};
    F_plot = F_vec{i_case};
    if i_case==1
        linewidth = 2;
    else 
        linewidth = 1;
    end
    if i_case<=3
        grey_shade = [1 1 1]*0.15*i_case;
        plot(theta_plot,f_plot(theta_plot)/(1-F_plot(1)),'Color',grey_shade,'LineWidth',linewidth)        
    elseif i_case>3
        grey_shade = [1 1 1]*0.15*(i_case-3);
        plot(theta_plot,f_plot(theta_plot)/(1-F_plot(1)),'--','Color',grey_shade,'LineWidth',linewidth)            
    end
    if i_case ==3
        y_max = max(f_plot(theta_plot)/(1-F_plot(1)));
        plot([alpha/(alpha-1) alpha/(alpha-1)],[0 y_max],':','Color','b','LineWidth',2)        
    end
end
f_plot = f_vec{1};
F_plot = F_vec{1};
grey_shade = [1 1 1]*0.15*1;
plot(theta_plot,f_plot(theta_plot)/(1-F_plot(1)),'Color',grey_shade,'LineWidth',linewidth)    
text(alpha/(alpha-1),-0.9,'$\bar{\theta}^n$','HorizontalAlignment','center','Color','b','FontSize',18,'FontWeight','bold','interpreter','latex');
hold off
pbaspect([1.5 1 1])
legend("$\hat{\alpha}=6.3$ (Baseline)",...
       "$\hat{\alpha}=10.1$",...
       "$\hat{\alpha}=12.7$",...
       "$\hat{\alpha}=3.4$",...
       "$\hat{\alpha}=-1$",...
       "$\hat{\alpha}=-4$",...
       "$\hat{\alpha}=-14$",...
       "$\hat{\alpha}=-32$",...      
       "$\hat{\alpha}=-320$",...                                          
        'Box','off','NumColumns',1,'Location','East','FontSize',labelfontsize,'interpreter','latex')
xlim([1 3])
ylim([0 y_max])
yticks([0 2 4 6 8 10])
xlabel('Entrant match quality, \theta','FontName','Arial','FontSize',labelfontsize);
ylabel('$\frac{f(\theta)}{1-F(1)}$','FontName','Arial','FontSize',labelfontsize,'interpreter','latex');
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')
box on

filename = fullfile(dir_fig,'pdf_theta.eps');
print(filename, '-depsc')

% cdf

figure('pos',[100 100 450 360])
hold on
for i_case=1:N_case
    F_plot = F_vec{i_case};
    if i_case==1
        linewidth = 2;
    else 
        linewidth = 1;
    end
    if i_case<=3
        grey_shade = [1 1 1]*0.15*i_case;
        plot(theta_plot,(F_plot(theta_plot)-F_plot(1))/(1-F(1)),'Color',grey_shade,'LineWidth',linewidth)        
    elseif i_case>3
        grey_shade = [1 1 1]*0.15*(i_case-3);
        plot(theta_plot,(F_plot(theta_plot)-F_plot(1))/(1-F(1)),'--','Color',grey_shade,'LineWidth',linewidth)            
    end    
end
plot([alpha/(alpha-1) alpha/(alpha-1)],[0 1],':','Color','b','LineWidth',2)
F_plot = F_vec{1};
grey_shade = [1 1 1]*0.15*1;
plot(theta_plot,(F_plot(theta_plot)-F_plot(1))/(1-F(1)),'Color',grey_shade,'LineWidth',linewidth)        
text(alpha/(alpha-1),-0.08,'$\bar{\theta}^n$','HorizontalAlignment','center','Color','b','FontSize',18,'FontWeight','bold','interpreter','latex');
hold off
pbaspect([1.5 1 1])
legend("$\hat{\alpha}=6.3$ (Baseline)",...
       "$\hat{\alpha}=10.1$",...
       "$\hat{\alpha}=12.7$",...
       "$\hat{\alpha}=3.4$",...
       "$\hat{\alpha}=-1$",...
       "$\hat{\alpha}=-4$",...
       "$\hat{\alpha}=-14$",...
       "$\hat{\alpha}=-32$",...      
       "$\hat{\alpha}=-320$",...                                         
        'Box','off','NumColumns',1,'Location','East','FontSize',labelfontsize,'interpreter','latex')
xlim([1 3])
xlabel('Entrant match quality, \theta','FontName','Arial','FontSize',labelfontsize);
ylabel('$\frac{F(\theta)-F(1)}{1-F(1)}$','FontName','Arial','FontSize',labelfontsize,'interpreter','latex');
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')
box on

filename = fullfile(dir_fig,'cdf_theta.eps');
print(filename, '-depsc')

% hazard rate

figure('pos',[100 100 450 360])
hold on
for i_case=1:N_case
    f_plot = f_vec{i_case};  
    F_plot = F_vec{i_case};
    if i_case==1
        linewidth = 2;
    else 
        linewidth = 1;
    end
    if i_case<=3
        grey_shade = [1 1 1]*0.15*i_case;
        plot(theta_plot,f_plot(theta_plot)./(1-F_plot(theta_plot)),'Color',grey_shade,'LineWidth',linewidth)        
    elseif i_case>3
        grey_shade = [1 1 1]*0.15*(i_case-3);
        plot(theta_plot,f_plot(theta_plot)./(1-F_plot(theta_plot)),'--','Color',grey_shade,'LineWidth',linewidth)            
    end    
end
plot([alpha/(alpha-1) alpha/(alpha-1)],[0 12],':','Color','b','LineWidth',2)
f_plot = f_vec{1};  
F_plot = F_vec{1};
grey_shade = [1 1 1]*0.15*1;
plot(theta_plot,f_plot(theta_plot)./(1-F_plot(theta_plot)),'Color',grey_shade,'LineWidth',linewidth)        
text(alpha/(alpha-1),-0.95,'$\bar{\theta}^n$','HorizontalAlignment','center','Color','b','FontSize',18,'FontWeight','bold','interpreter','latex');
hold off
pbaspect([1.5 1 1])
legend("$\hat{\alpha}=6.3$ (Baseline)",...
       "$\hat{\alpha}=10.1$",...
       "$\hat{\alpha}=12.7$",...
       "$\hat{\alpha}=3.4$",...
       "$\hat{\alpha}=-1$",...
       "$\hat{\alpha}=-4$",...
       "$\hat{\alpha}=-14$",...
       "$\hat{\alpha}=-32$",...      
       "$\hat{\alpha}=-320$",...                                         
        'Box','off','NumColumns',1,'Location','East','FontSize',labelfontsize,'interpreter','latex')
xlim([1 3])
ylim([0 12])
xlabel('Entrant match quality, \theta','FontName','Arial','FontSize',labelfontsize);
ylabel('$\frac{f(\theta)}{1-F(\theta)}$','FontName','Arial','FontSize',labelfontsize,'interpreter','latex');
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')
box on

filename = fullfile(dir_fig,'hazard_rate_theta.eps');
print(filename, '-depsc')

%% Save data 

save(fullfile(dir,'output/data','welfare_cap_mobility_distortion.mat'))

