
%% Initialize the setting

clear;
close all;
clc;
format compact
format short

options_fsolve  =  optimset('fsolve');
options_fsolve  =  optimset(options_fsolve , 'TolFun'      , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'TolX'        , 1e-10);
options_fsolve  =  optimset(options_fsolve , 'Display'     , 'off');
options_fsolve  =  optimset(options_fsolve , 'MaxFunEvals' , 1000);
options_fsolve  =  optimset(options_fsolve , 'MaxIter' , 1000);

plotfontsize  = 18;
labelfontsize = 18;
linecolor = 1/255*[0 0 153];

%% Folder path 

% base folder
dir = fileparts(fileparts(cd));
% figure folder
dir_fig = fullfile(dir,'output/figures/free_entry');
if ~exist(dir_fig,'dir')
    mkdir(dir_fig)
end

% data
run(fullfile(dir,'code/parameters','data_moment.m'));

%% Specification

% entry cases 
N_case = 2;   
% for full enforcement
p = 1;       
error = 5e-3;

% duration cap grid
case_duration_cap = 1;
N_dur = 201;    
dur_cap_vec = linspace(0,dur_data,N_dur)';

%% Prepare to store results

kappa_bar_cap_vec = zeros(N_case,N_dur);
frac_n_cap_vec = zeros(N_case,N_dur);
frac_n_cap_approx_vec = zeros(N_case,N_dur);
lambda_endo_cap_vec = zeros(N_case,N_dur);
v_cap_vec = zeros(N_case,N_dur);

kappa_bar_pseudo_vec = zeros(N_case,N_dur);
frac_n_pseudo_vec = zeros(N_case,N_dur);

u_c_cap_vec = zeros(N_case,N_dur);
u_n_cap_vec = zeros(N_case,N_dur);

S_cap_vec = zeros(N_case,N_dur);
dS_cap_vec = zeros(N_case,N_dur);
dS_reallocate_cap_vec = zeros(N_case,N_dur);
dS_invest_cap_vec = zeros(N_case,N_dur);
dS_select_cap_vec = zeros(N_case,N_dur);
dS_entry_cap_vec = zeros(N_case,N_dur);
dS_intensive_cap_vec = zeros(N_case,N_dur);

S_cap_ss_vec = zeros(N_case,N_dur);
Y_cap_vec = zeros(N_case,N_dur);
dY_cap_vec = zeros(N_case,N_dur);

dur_intensive_cap_max_vec = zeros(N_case,1);
dS_intensive_cap_max_vec = zeros(N_case,1);

%% Welfare analysis

for i_case= 1:2
    
    disp(' ')
    fprintf('Case: %.0g\n', i_case)
    
    run(fullfile(dir,'code/parameters','parameters_entry.m'));
    run(fullfile(dir,'code/grids','grid_finetune_kappa.m'));    
    
    Y_vec = zeros(N_dur,1);
    frac_n_vec = zeros(N_dur,1);
    s_n_vec = zeros(N_dur,N_kappa);
    Z_n_vec = zeros(N_dur,N_kappa);
    S_1_vec = zeros(N_dur,1);
    S_ss_vec = zeros(N_dur,1);
    
    dur_cap = Inf;
    run(fullfile(dir,'code/solve','solve_equilibrium_entry.m'));        
    
    for i_dur=1:N_dur
        
        display(['   Duration cap loop= ' num2str(i_dur)])

        %% solve equilibrium subject to the cap

        dur_cap = dur_cap_vec(i_dur);
        run(fullfile(dir,'code/solve','solve_cap_entry.m'));        

        %% store results 
                
        kappa_bar_cap_vec(i_case,i_dur) = kappa_bar_cap;
        frac_n_cap_vec(i_case,i_dur) = frac_n_cap;
        frac_n_cap_approx_vec(i_case,i_dur) = frac_n_cap_approx;
        lambda_endo_cap_vec(i_case,i_dur) = lambda_endo_cap;
        v_cap_vec(i_case,i_dur) = v_cap;
        
        kappa_bar_pseudo_vec(i_case,i_dur) = kappa_bar_pseudo;
        frac_n_pseudo_vec(i_case,i_dur) = frac_n_pseudo;
        
        u_c_cap_vec(i_case,i_dur)  = beta*j_c_cap;
        u_n_cap_vec(i_case,i_dur)  = beta*trapz(kappa_cap,interp1(kappa,j_n_cap,kappa_cap).*i_n_cap.*fkappa_cap);

        S_cap_vec(i_case,i_dur) = S_cap;
        dS_cap_vec(i_case,i_dur) = dS_cap;
        dS_reallocate_cap_vec(i_case,i_dur) = dS_reallocate_cap;
        dS_invest_cap_vec(i_case,i_dur) = dS_invest_cap;
        dS_select_cap_vec(i_case,i_dur) = dS_select_cap;
        dS_entry_cap_vec(i_case,i_dur) = dS_entry_cap;        
        dS_intensive_cap_vec(i_case,i_dur) = dS_reallocate_cap+dS_invest_cap;
        
        S_cap_ss_vec(i_case,i_dur) = S_cap_ss;
        Y_cap_vec(i_case,i_dur) = Y_cap;
        dY_cap_vec(i_case,i_dur) = dY_cap;
                
    end
    

    [dS_cap_max, tempI] = max(dS_cap_vec(i_case,:));
    dur_cap_max = dur_cap_vec(tempI);
    fprintf(' Time-0 welfare:\n')    
    fprintf(' Overall\n')
    fprintf('   Gain = %.3g%%\n',dS_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_cap_max*12)
    
    [dS_intensive_cap_max, tempI] = max(dS_intensive_cap_vec(i_case,:));
    dur_intensive_cap_max = dur_cap_vec(tempI);
    fprintf(' Intensive margin\n')
    fprintf('   Gain = %.3g%%\n',dS_intensive_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_intensive_cap_max)
    fprintf('   Duration cap = %.3g months\n',dur_intensive_cap_max*12)
    
    dur_intensive_cap_max_vec(i_case) = dur_intensive_cap_max;
    dS_intensive_cap_max_vec(i_case) = dS_intensive_cap_max;    

    [dS_select_cap_max, tempI] = max(dS_select_cap_vec(i_case,:));
    dur_select_cap_max = dur_cap_vec(tempI);    
    fprintf(' Selection margin\n')
    fprintf('   Gain = %.3g%%\n',dS_select_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_select_cap_max)    
    fprintf('   Duration cap = %.3g months\n',dur_select_cap_max*12)        
    
    [dS_entry_cap_max, tempI] = max(dS_entry_cap_vec(i_case,:));
    dur_entry_cap_max = dur_cap_vec(tempI);    
    fprintf(' Entry margin\n')
    fprintf('   Gain = %.3g%%\n',dS_entry_cap_max*100)
    fprintf('   Duration cap = %.3g years\n',dur_entry_cap_max)    
    fprintf('   Duration cap = %.3g months\n',dur_entry_cap_max*12) 
    
    %% Plot

    figure('pos',[100 100 450 360])
    plot(dur_cap_vec,dS_intensive_cap_vec(i_case,:)*100,'-k','LineWidth',2)
    hold on 
    plot(dur_cap_vec,dS_select_cap_vec(i_case,:)*100,'--','Color',[0.6 0 0],'LineWidth',2)
    plot(dur_cap_vec,dS_entry_cap_vec(i_case,:)*100,'-.','Color',[0, 0.5, 0],'LineWidth',2)    
    plot(dur_cap_vec,dS_cap_vec(i_case,:)*100,':','Color',linecolor,'LineWidth',2)
    plot(dur_intensive_cap_max,dS_intensive_cap_max*100,'Marker','o','MarkerSize',9,'MarkerEdgeColor','k','MarkerFaceColor','k')
    plot(dur_cap_max,dS_cap_max*100,'Marker','d','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
    plot(dur_cap_vec(end),dS_cap_vec(i_case,end)*100,'Marker','s','MarkerSize',9,'MarkerEdgeColor',linecolor,'MarkerFaceColor',linecolor)
    text(dur_cap_vec(1),dS_cap_vec(i_case,1)*100,'Ban','HorizontalAlignment','left','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize)
    text(dur_cap_vec(end),dS_cap_vec(i_case,end)*100,'Private Optimum','HorizontalAlignment','right','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize)
    hold off
    pbaspect([1.5 1 1])
    legend("Intensive Margin","Selection Margin","Entry Margin",'Total','Box','off','Location','Northeast','FontSize',labelfontsize)
    xlabel('Noncompete duration, years','FontName','Arial','FontSize',labelfontsize);
    ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
    xlim([0 dur_data])
    ylim([0 ceil(max(dS_cap_vec(i_case,:))*100*2)/2])
    xticks([0 .2 .4 .6 .8 1 1.2 1.4 1.6])
    set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

    filename = fullfile(dir_fig,strcat('welfare_cap_entry',num2str(i_case),'.eps'));
    print(filename, '-depsc')        

end
    
%% Plot: duraion cap and welfare

figure('pos',[100 100 450 360])
plot(dur_cap_vec*12,dS_intensive_cap_vec(1,:)*100,'-k','LineWidth',2)
hold on 
plot(dur_cap_vec*12,dS_select_cap_vec(1,:)*100,'--','Color',[0.6 0 0],'LineWidth',2)
plot(dur_cap_vec*12,dS_entry_cap_vec(1,:)*100,'-.','Color',[0, 0.5, 0],'LineWidth',2)    
plot(dur_cap_vec*12,dS_cap_vec(1,:)*100,':','Color',linecolor,'LineWidth',2)
p1 = plot(dur_cap_vec*12,dS_intensive_cap_vec(2,:)*100,'-k','LineWidth',5);
p2 = plot(dur_cap_vec*12,dS_select_cap_vec(2,:)*100,'--','Color',[0.6 0 0],'LineWidth',5);
p3 = plot(dur_cap_vec*12,dS_entry_cap_vec(2,:)*100,'-.','Color',[0, 0.5, 0],'LineWidth',5);    
p4 = plot(dur_cap_vec*12,dS_cap_vec(2,:)*100,':','Color',linecolor,'LineWidth',5);
text(0.39*12,4.05,'\underline{Fixed Entry}','HorizontalAlignment','left','VerticalAlignment','top','FontName','Arial','FontSize',labelfontsize,'interpreter','latex')
text(0.97*12,4.05,'\underline{Free Entry}','HorizontalAlignment','left','VerticalAlignment','top','FontName','Arial','FontSize',labelfontsize,'interpreter','latex')
plot(dur_cap_vec*12,dS_intensive_cap_vec(1,:)*100,'-k','LineWidth',2)
plot(dur_intensive_cap_max_vec(1)*12,dS_intensive_cap_max_vec(1)*100,'Marker','o','MarkerSize',9,'MarkerEdgeColor','b','MarkerFaceColor','b')
hold off
p1.Color(4) = 0.3;
p2.Color(4) = 0.3;
p3.Color(4) = 0.3;
p4.Color(4) = 0.3;
pbaspect([1.5 1 1])
l = legend("Intensive","Selection\hspace{0.3cm}","Entry","Total",...
       "Intensive","Selection","Entry","Total",...
       'Box','off','NumColumns',2,'Location','NorthEast','FontSize',labelfontsize,'interpreter','latex');
set(l, 'Position', [0.45, 0.55, .25, .25])
xlabel('Noncompete duration, months','FontName','Arial','FontSize',labelfontsize);
ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 dur_data*12])
ylim([0 4])
xticks([0 2 4 6 8 10 12 14 16 18])
xtickangle(0)
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

filename = fullfile(dir_fig,strcat('welfare_cap_entry.eps'));
print(filename, '-depsc')

%% Plot: duration cap and entry rate

figure('pos',[100 100 450 360])
plot(dur_cap_vec*12,(lambda_endo_cap_vec(1,:)./lambda_endo_cap_vec(1,end)-1)*100,'-k','LineWidth',4)
hold on 
plot(dur_cap_vec*12,(lambda_endo_cap_vec(2,:)./lambda_endo_cap_vec(2,end)-1)*100,'--k','LineWidth',4)
hold off
pbaspect([1.5 1 1])
legend("Fixed Entry","Free Entry",'Box','off','Location','Northeast','FontSize',labelfontsize)
xlabel('Noncompete duration, months','FontName','Arial','FontSize',labelfontsize);
ylabel('Change in arrival rate \lambda, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 dur_data*12])
xticks([0 2 4 6 8 10 12 14 16 18])
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

filename = fullfile(dir_fig,strcat('arrival_rate_cap_entry.eps'));
print(filename, '-depsc')

%% Plot: duration cap and worker welfare

figure('pos',[100 100 450 360])
plot(dur_cap_vec(2:end)*12,(u_n_cap_vec(1,2:end)./u_n_cap_vec(1,end)-1)*100,'-k','LineWidth',4)
hold on 
plot(dur_cap_vec(2:end)*12,(u_n_cap_vec(2,2:end)./u_n_cap_vec(2,end)-1)*100,'--k','LineWidth',4)
plot(dur_cap_vec(1:end)*12,dur_cap_vec(1:end)*0,':r','LineWidth',1)
hold off
pbaspect([1.5 1 1])
legend("Fixed Entry","Free Entry",'Box','off','Location','Northwest','FontSize',labelfontsize)
xlabel('Noncompete duration, months','FontName','Arial','FontSize',labelfontsize);
ylabel('Change in worker value, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 dur_data*12])
ylim([-1.5,0.5])
xticks([0 2 4 6 8 10 12 14 16 18])
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

filename = fullfile(dir_fig,strcat('worker_welfare_cap_entry.eps'));
print(filename, '-depsc')

%% Save data

save(fullfile(dir,'output/data','welfare_cap_free_entry.mat'))


