iter     = 0;
if i_case==1
    iter_max = 1;
elseif i_case==2
    iter_max = 50;
end
iter_tol = 1e-8;
distance = inf;
weight = 0.5;

% initial guess (more efficient updating)
if iter==0
    lambda_ub  = (delta-mu_c)/ES(theta_bar_c)-0.02;
    v_ub       = pv_inv(lambda_ub);   
    v_lb       = 0;
    v_cap = (v_lb+v_ub)/2;
end

while iter<iter_max && abs(distance)>iter_tol    

    if i_case==1
        lambda_endo_cap = lambda;
    elseif i_case==2
        lambda_endo_cap = pv(v_cap);
    end
    q_cap       = qv(v_cap);

    % Bilateral Joint Maximization  
    theta_bar_c = 1;
    eq_mu_c = @(mu) cp(mu)*(r-mu-lambda_endo_cap*ER(1))-(1-c(mu));
    mu_c_cap = fzero(eq_mu_c, [1/2*sigma^2 r-lambda_endo_cap*ER(1)], options_fsolve);
    j_c_cap  = (1-c(mu_c_cap))/(r-mu_c_cap-lambda_endo_cap*ER(1));
    cmu_c_cap    = c(mu_c);
        
    %% Noncompete contract, subject to cap

    theta_bar_n_cap = min(exp(dur_cap*r),theta_bar_n);
    % investment for cost type kappa
    mu_n_cap    = zeros(1,N_kappa);
    for i_kappa = 1:N_kappa
        eq_mu_n = @(mu) cp(mu)*(r-mu-lambda_endo_cap*(p*ER(theta_bar_n_cap)+(1-p)*ER(theta_bar_c)))-(1-c(mu)-kappa(i_kappa));         
        mu_n_temp = fzero(eq_mu_n, [1/2*sigma^2 r-lambda_endo_cap*(p*ER(theta_bar_n_cap)+(1-p)*ER(theta_bar_c))], options_fsolve);
        mu_n_cap(i_kappa) = mu_n_temp;
    end
    j_n_cap = (1-c(mu_n_cap)-kappa)./(r-mu_n_cap-lambda_endo_cap*(p*ER(theta_bar_n_cap)+(1-p)*ER(theta_bar_c)));

    %% Standard contract
    % note that the standard contract is unaffected by the matching rate (lambda)
    
    %% kappa_bar, according to private agents
    
    % marginal type
    kappa_bar_cap = min(max(interp1(j_n_cap,kappa,j_c,'linear','extrap'),0),kappau);
    frac_n_cap = cdf(pd,kappa_bar_cap);

    % endogenous grid
    kappa_cap  = sort([kappa(kappa<max(kappa_bar,kappa_bar_cap)) max(kappa_bar,kappa_bar_cap) kappa_bar_cap]);            
    i_n_cap    = (kappa_cap<=kappa_bar_cap);  
    frac_n_cap_approx = trapz(kappa_cap,i_n_cap.*pdf(pd,kappa_cap));
    if frac_n_cap_approx>0
        fkappa_cap = pdf(pd,kappa_cap)/frac_n_cap_approx;
    else
        fkappa_cap = zeros(size(kappa_cap));
    end
    if frac_n_approx>0
       fkappa_cap_eqm = pdf(pd,kappa_cap)/max(frac_n_approx,frac_n_cap_approx);
    else
       fkappa_cap_eqm = zeros(size(kappa_cap));
    end
    
    %% 
    D_c_cap     = delta-mu_c-lambda_endo_cap*ES(theta_bar_c);
    Z_c_cap     = delta/D_c_cap;
    
    D_n_cap = delta-mu_n_cap-lambda_endo_cap*(p*ES(theta_bar_n_cap)+(1-p)*ES(theta_bar_c));
    Z_n_cap = delta./D_n_cap;
    Z_cap = trapz(kappa_cap,interp1(kappa,Z_n_cap,kappa_cap).*i_n_cap.*fkappa_cap)*frac_n_cap+Z_c_cap*(1-frac_n_cap);
    
    surplus_n_cap = trapz(kappa_cap,interp1(kappa,j_n_cap.*Z_n_cap,kappa_cap).*i_n_cap.*fkappa_cap)*(p*EE(theta_bar_n_cap)+(1-p)*EE(theta_bar_c));
    surplus_c_cap = j_c*Z_c_cap*EE(theta_bar_c); 
    surplus_cap = (surplus_n_cap*frac_n_cap+surplus_c_cap*(1-frac_n_cap));
    distance = surplus_cap*q_cap/Z_cap-K*v_cap^b;  % free entry condition

    if distance>iter_tol     
        v_lb    = (v_cap+v_lb)/2;                                         
    elseif distance<-iter_tol 
        v_ub    = (v_cap+v_ub)/2;                                             
    end  
    v_cap = (v_lb+v_ub)/2;

    iter = iter+1;

    if (mod(iter,10)==0 || iter==iter_max || abs(distance)<=iter_tol)
        display(['   Iteration = ' num2str(iter) ' Distance = ' num2str(distance)])
    end        
    
end

%% J2J and Separation Rates, Investments

j2j_n_cap = lambda_endo_cap*(p*(1-F(theta_bar_n_cap))+(1-p)*(1-F(theta_bar_c)));
sep_n_cap = j2j_n_cap+delta;

j2j_cap = j2j_n_cap*frac_n_cap+j2j_c*(1-frac_n_cap);
sep_cap = j2j_cap+delta;
cmu_cap = trapz(kappa_cap,interp1(kappa,c(mu_n_cap),kappa_cap).*i_n_cap.*fkappa_cap)*frac_n_cap+cmu_c*(1-frac_n_cap);

%% Welfare

s_n_cap = (1-c(mu_n_cap)-kappa-K/(b+1)*v_cap^(b+1))./(r-mu_n_cap-lambda_endo_cap*(p*ES(theta_bar_n_cap)+(1-p)*ES(theta_bar_c)));
s_c_cap = (1-c(mu_c_cap)-K/(b+1)*v_cap^(b+1))/(r-mu_c_cap-lambda_endo_cap*ES(theta_bar_c));
% new born 
S_1_cap   = (rho+delta)/rho*(trapz(kappa_cap,interp1(kappa,s_n_cap,kappa_cap).*i_n_cap.*fkappa_cap)*frac_n_cap+s_c_cap*(1-frac_n_cap));
% time 0
s_cap  = s_c.*(1-i_n_cap)+interp1(kappa,s_n_cap,kappa_cap).*i_n_cap;
if frac_n>=frac_n_cap
    S_cap  = trapz(kappa_cap,s_cap.*interp1(kappa,Z_n,kappa_cap).*fkappa_cap_eqm)*frac_n+s_c_cap*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_cap;    
else
    S_cap  = trapz(kappa_cap,s_cap.*(interp1(kappa,Z_n,kappa_cap).*(kappa_cap<=kappa_bar)+Z_c.*(kappa_cap>kappa_bar)).*fkappa_cap_eqm)*frac_n_cap+s_c_cap*Z_c*(1-frac_n_cap)+delta/(rho+delta)*S_1_cap;     
end

% steady state
S_cap_ss  = trapz(kappa_cap,interp1(kappa,s_n_cap.*Z_n_cap,kappa_cap).*i_n_cap.*fkappa_cap)*frac_n_cap+s_c_cap*Z_c_cap*(1-frac_n_cap)+delta/(rho+delta)*S_1_cap;

%% Prepare for Welfare T0 Decomposition: 
% solve a case impose the equilibrium lambda
% this step is irrelevant if exogenous entry
% it's possible that kappa_bar_cap>kappa_bar, 
% but it's always true that kappa_bar_pseudo<kappa_bar

mu_n_pseudo    = zeros(1,N_kappa);
for i_kappa = 1:N_kappa
    eq_mu_n = @(mu) cp(mu)*(r-mu-lambda_endo*(p*ER(theta_bar_n_cap)+(1-p)*ER(theta_bar_c)))-(1-c(mu)-kappa(i_kappa));         
    mu_n_temp = fzero(eq_mu_n, [1/2*sigma^2 r-lambda_endo*(p*ER(theta_bar_n_cap)+(1-p)*ER(theta_bar_c))], options_fsolve);
    mu_n_pseudo(i_kappa) = mu_n_temp;
end
j_n_pseudo = (1-c(mu_n_pseudo)-kappa)./(r-mu_n_pseudo-lambda_endo*(p*ER(theta_bar_n_cap)+(1-p)*ER(theta_bar_c)));
% marginal type
kappa_bar_pseudo = min(max(interp1(j_n_pseudo,kappa,j_c,'linear','extrap'),0),kappau);
frac_n_pseudo = cdf(pd,kappa_bar_pseudo);
% endogenous grid
kappa_pseudo  = sort([kappa(kappa<kappa_bar) kappa_bar kappa_bar_pseudo]);    
i_n_pseudo    = (kappa_pseudo<=kappa_bar_pseudo);  
frac_n_pseudo_approx = trapz(kappa_pseudo,i_n_pseudo.*pdf(pd,kappa_pseudo));
if frac_n_pseudo_approx>0
    fkappa_pseudo = pdf(pd,kappa_pseudo)/frac_n_pseudo_approx;
else
    fkappa_pseudo = zeros(size(kappa_pseudo));
end
if frac_n_approx>0
   fkappa_pseudo_eqm = pdf(pd,kappa_pseudo)/frac_n_approx;
else
   fkappa_pseudo_eqm = zeros(size(kappa_pseudo));
end

%% Welfare T0 Decomposition

% reallocate
D_n_reallocate_cap = delta-mu_n-lambda_endo*(p*ES(theta_bar_n_cap)+(1-p)*ES(theta_bar_c));
s_n_reallocate_cap = (1-c(mu_n)-kappa-K/(b+1)*v^(b+1))./(rho+D_n_reallocate_cap);

S_1_reallocate_cap = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n_reallocate_cap,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));
S_reallocate_cap = trapz(kappa_eqm,interp1(kappa,s_n_reallocate_cap.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_reallocate_cap;  

% invest
D_n_invest_cap = delta-mu_n_pseudo-lambda_endo*(p*ES(theta_bar_n_cap)+(1-p)*ES(theta_bar_c));
s_n_invest_cap = (1-c(mu_n_pseudo)-kappa-K/(b+1)*v^(b+1))./(rho+D_n_invest_cap);

S_1_invest_cap = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n_invest_cap,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));    
S_invest_cap = trapz(kappa_eqm,interp1(kappa,s_n_invest_cap.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_invest_cap; 

% selection
S_1_select_cap = (rho+delta)/rho*(trapz(kappa_pseudo,interp1(kappa,s_n_invest_cap,kappa_pseudo).*i_n_pseudo.*fkappa_pseudo)*frac_n_pseudo+s_c*(1-frac_n_pseudo));   
s_select = s_c.*(1-i_n_pseudo)+interp1(kappa,s_n_invest_cap,kappa_pseudo).*i_n_pseudo;
S_select_cap = trapz(kappa_pseudo,s_select.*interp1(kappa,Z_n,kappa_pseudo).*fkappa_pseudo_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_select_cap; 

% decompose
dS_cap = S_cap/S_ss-1;
dS_reallocate_cap = (S_reallocate_cap-S_ss)/S_ss;
dS_invest_cap = (S_invest_cap-S_reallocate_cap)/S_ss;
dS_select_cap = (S_select_cap-S_invest_cap)/S_ss;
dS_entry_cap = (S_cap-S_select_cap)/S_ss;

%% Steady State Output    

Y_n_cap = delta*(1-c(mu_n_cap)-kappa)./D_n_cap;
Y_cap = trapz(kappa_cap,interp1(kappa,Y_n_cap,kappa_cap).*i_n_cap.*fkappa_cap)*frac_n_cap+Y_c*(1-frac_n_cap)-K/(b+1)*v_cap^(b+1)*Z_cap;
    
%% Decomposition

dY_cap = Y_cap/Y-1;


