%% Standard contract

% Bilateral Joint Maximization  
theta_bar_c = 1;
eq_mu_c = @(mu) cp(mu)*(r-mu)-(1-c(mu));
mu_c    = fzero(eq_mu_c, [1/2*sigma^2 r], options_fsolve);
j_c     = (1-c(mu_c))/(r-mu_c);
cmu_c   = c(mu_c);
j2j_c   = lambda*(1-F(theta_bar_c));
sep_c   = j2j_c+delta;
% Productivity (output)
D_c     = delta-mu_c-lambda*ES(theta_bar_c);
Z_c     = delta/D_c;
% Consumption
Y_c     = delta*(1-c(mu_c))/D_c;
% Welfare
s_c    = (1-c(mu_c))/(r-mu_c-lambda*ES(1));

%% Noncompete contract: bilateral joint maximization

% private-optimal noncompete, poaching threshold 
theta_bar_guess = theta_bar_n;
theta_bar_n_temp = fsolve(@(theta_bar) 1+((1-F(theta_bar))/f(theta_bar))-theta_bar, theta_bar_guess, options_fsolve);
% whether noncompete duration is binding:
theta_bar_n = min(exp(dur_cap*r),theta_bar_n_temp);
pie     = 1/r*log(theta_bar_n);
% investment for cost type kappa
mu_n    = zeros(1,N_kappa);
for i_kappa = 1:N_kappa
    eq_mu_n = @(mu) cp(mu)*(r-mu-lambda*p*(theta_bar_n-1)*(1-F(theta_bar_n)))-(1-c(mu)-kappa(i_kappa));         
    mu_n_temp = fsolve(eq_mu_n, mu_c, options_fsolve);
    mu_n(i_kappa) = mu_n_temp;
end
j_n = (1-c(mu_n)-kappa)./(r-mu_n-lambda*p*(theta_bar_n-1)*(1-F(theta_bar_n)));

% marginal type 
kappa_bar = min(j_c*lambda*p*(theta_bar_n-1)*(1-F(theta_bar_n)),kappau);
if kappa_bar==0
    i_kappa_bar = 1;
    kappa_mean = 0;
else 
    i_kappa_bar = find(kappa<=kappa_bar,1,'last');
    pd_truncate = truncate(pd,0,kappa_bar);
    kappa_mean = mean(pd_truncate); 
end
% noncompete or not
i_n      = (kappa<=kappa_bar); 
frac_n   = cdf(pd,kappa_bar);

% endogeous grid
kappa_eqm  = [kappa(kappa<=kappa_bar) kappa_bar];
frac_n_approx = trapz(kappa_eqm,pdf(pd,kappa_eqm));
if frac_n_approx>0
    fkappa_eqm = pdf(pd,kappa_eqm)/frac_n_approx;
else
    fkappa_eqm = zeros(size(kappa_eqm));
end

%% J2J and Separation Rates

j2j_n   = lambda*(p*(1-F(theta_bar_n))+(1-p)*(1-F(theta_bar_c)));
sep_n   = j2j_n+delta;

j2j     = j2j_n*frac_n+j2j_c*(1-frac_n);
sep     = j2j+delta;

%% Investment rate

if frac_n_approx>0
    Emu_n   = trapz(kappa_eqm,interp1(kappa,mu_n,kappa_eqm).*fkappa_eqm);
    Ecmu_n  = trapz(kappa_eqm,interp1(kappa,c(mu_n),kappa_eqm).*fkappa_eqm);
else
    Emu_n   = mu_n(1);
    Ecmu_n  = c(mu_n(1));
end
cmu     = trapz(kappa_eqm,interp1(kappa,c(mu_n),kappa_eqm).*fkappa_eqm)*frac_n+cmu_c*(1-frac_n);

dlogmu  = epsilon*(lambda*p*(theta_bar_n-1).*(1-F(theta_bar_n))-kappa_mean./j_c)./(r-mu_c);
dlogcmu = (epsilon+1)*(lambda*p*(theta_bar_n-1).*(1-F(theta_bar_n))-kappa_mean./j_c)./(r-mu_c);

%% Productivity distribution

% using standard contract
fzeta_c   = @(zeta) alpha/(alpha-zeta)*theta_bar_c^zeta;
eq_zeta_c = @(zeta) .5*sigma^2*zeta^2+(mu_c-1/2*sigma^2)*zeta-delta+lambda*(1-F(theta_bar_c))*(fzeta_c(zeta)-1);
zetap_c   = fsolve(eq_zeta_c, 1.5, options_fsolve);
zetan_c   = fsolve(eq_zeta_c, -2, options_fsolve);
% pareto distribution proxy
gz_prox_c = @(z) zetap_c*zetan_c/(zetap_c+zetan_c)*(z.^(-zetap_c).*(z>1)+z.^(-zetan_c).*(z<1));

% using noncompete contract
fzeta_n   = @(zeta) alpha/(alpha-zeta)*theta_bar_n^zeta;
eq_zeta_n = @(zeta) .5*sigma^2*zeta^2+(mu_n(1)-1/2*sigma^2)*zeta-delta+lambda*p*(1-F(theta_bar_n))*(fzeta_n(zeta)-1)+lambda*(1-p)*(1-F(theta_bar_c))*(fzeta_c(zeta)-1);
zetap_n   = fsolve(eq_zeta_n, 1.5, options_fsolve);
zetan_n   = fsolve(eq_zeta_n, -2, options_fsolve);
% pareto distribution proxy
gz_prox_n = @(z) zetap_n*zetan_n/(zetap_n+zetan_n)*(z.^(-zetap_n).*(z>1)+z.^(-zetan_n).*(z<1));

%% Steady-state output    

D_n      = delta-mu_n-lambda*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c));
% Productivity (overall output): interpretation of contracting cost as disutility
Z_n     = delta./D_n;
Z       = trapz(kappa_eqm,interp1(kappa,Z_n,kappa_eqm).*fkappa_eqm)*frac_n+Z_c*(1-frac_n);
% Consumption (net output)
Y_n     = delta*(1-c(mu_n)-kappa)./D_n;
Y       = trapz(kappa_eqm,interp1(kappa,Y_n,kappa_eqm).*fkappa_eqm)*frac_n+Y_c*(1-frac_n);

%% Social welfare

s_n    = (1-c(mu_n)-kappa)./(r-mu_n-lambda*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c)));
% social value at the private optimal contract: kappa_bar and duration
s_n_bar = (1-c(mu_c)-kappa_bar)./(r-mu_c-lambda*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c)));
% new born 
S_1    = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));
% steady state
S_ss   = trapz(kappa_eqm,interp1(kappa,s_n.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1;

% wedge
Delta1 = (lambda*(p*EE(theta_bar_n)+(1-p)*EE(theta_bar_c)))./(r-mu_n-lambda*p*ER(theta_bar_n-1));
Delta2 = (mu_n-1/2*sigma^2)./(r-mu_n-lambda*p*ER(theta_bar_n-1));
Delta  = Delta1.*Delta2;
