
%% Solve for endogenous entry

iter     = 0;
if i_case==1
    iter_max = 1;
elseif i_case==2
    iter_max = 50;
end
iter_tol = 1e-4;
distance = inf;
weight = 0.5;

% initial guess
if iter==0
    lambda_ub  = (delta-mu_c)/ES(theta_bar_c)-0.01;
    v_ub       = pv_inv(lambda_ub);   
    v_lb       = 0;
    v = (v_lb+v_ub)/2; 
end

while iter<iter_max && abs(distance)>iter_tol
    
    if i_case==1
        lambda_endo = lambda;
    elseif i_case==2
        lambda_endo = pv(v); 
    end
    q       = qv(v);
    
    %% Standard contract: bilateral joint maximization  

    theta_bar_c = 1;
    eq_mu_c = @(mu) cp(mu)*(r-mu-lambda_endo*ER(1))-(1-c(mu));
    mu_c    = fzero(eq_mu_c, [1/2*sigma^2 r], options_fsolve);
    j_c     = (1-c(mu_c))/(r-mu_c-lambda_endo*ER(1));
    cmu_c   = c(mu_c);
    
    %% Noncompete contract: bilateral joint maximization

    % private-optimal noncompete, poaching threshold 
    theta_bar_guess = 1;
    theta_bar_n_temp = fsolve(@(theta_bar) 1+(1-F(theta_bar))/f(theta_bar)-theta_bar, theta_bar_guess, options_fsolve);
    % whether noncompete duration is binding:
    theta_bar_n = min(exp(dur_cap*r),theta_bar_n_temp);
    pie     = 1/r*log(theta_bar_n);
    % investment for cost type kappa
    mu_n    = zeros(1,N_kappa);
    for i_kappa = 1:N_kappa
        eq_mu_n = @(mu) cp(mu)*(r-mu-lambda_endo*(p*ER(theta_bar_n)+(1-p)*ER(theta_bar_c)))-(1-c(mu)-kappa(i_kappa));         
        mu_n_temp = fzero(eq_mu_n, [1/2*sigma^2 r-lambda_endo*(p*ER(theta_bar_n)+(1-p)*ER(theta_bar_c))], options_fsolve);
        mu_n(i_kappa) = mu_n_temp;
    end
    j_n = (1-c(mu_n)-kappa)./(r-mu_n-lambda_endo*(p*ER(theta_bar_n)+(1-p)*ER(theta_bar_c)));

    % marginal type 
    kappa_bar = min(j_c*lambda_endo*p*(theta_bar_n-1)*(1-F(theta_bar_n)),kappau);
    if kappa_bar==0
        i_kappa_bar = 1;
        kappa_mean = 0;
    else 
        i_kappa_bar = find(kappa<kappa_bar,1,'last');
        pd_truncate = truncate(pd,0,kappa_bar);
        kappa_mean = mean(pd_truncate); 
    end
    % noncompete or not
    i_n      = (kappa<=kappa_bar); 
    frac_n   = cdf(pd,kappa_bar);

    % endogeous grid
    kappa_eqm  = [kappa(kappa<kappa_bar) kappa_bar];
    frac_n_approx = trapz(kappa_eqm,pdf(pd,kappa_eqm));
    if frac_n_approx>0
        fkappa_eqm = pdf(pd,kappa_eqm)/frac_n_approx;
    else
        fkappa_eqm = zeros(size(kappa_eqm));
    end

    %% Update entry

    % Productivity 
    D_c     = delta-mu_c-lambda_endo*ES(theta_bar_c);
    Z_c     = delta/D_c;
    D_n     = delta-mu_n-lambda_endo*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c));
    Z_n     = delta./D_n;
    Z       = trapz(kappa_eqm,interp1(kappa,Z_n,kappa_eqm).*fkappa_eqm)*frac_n+Z_c*(1-frac_n);

    surplus_n = trapz(kappa_eqm,interp1(kappa,j_n.*Z_n,kappa_eqm).*fkappa_eqm)*(p*EE(theta_bar_n)+(1-p)*EE(theta_bar_c));
    surplus_c = j_c*Z_c*EE(theta_bar_c);  
    surplus = (frac_n*surplus_n+(1-frac_n)*surplus_c);
    distance = surplus*q/Z-K*v^b;   % free entry condition

    if distance>iter_tol     
        v_lb    = (v+v_lb)/2;                                         
    elseif distance<-iter_tol 
        v_ub    = (v+v_ub)/2;                                             
    end      
    v = (v_lb+v_ub)/2;

    iter = iter+1;

    if mod(iter,10)==0 || iter==iter_max || abs(distance)<=iter_tol
        display(['   Iteration = ' num2str(iter) ' Distance = ' num2str(distance)])
    end 
    
end


%% J2J rates, separation rates

j2j_c   = lambda_endo*(1-F(theta_bar_c));
sep_c   = j2j_c+delta;

j2j_n   = lambda_endo*(p*(1-F(theta_bar_n))+(1-p)*(1-F(theta_bar_c)));
sep_n   = j2j_n+delta;

j2j     = j2j_n*frac_n+j2j_c*(1-frac_n);
sep     = j2j+delta;

%% Investment rate

if frac_n_approx>0
    Emu_n   = trapz(kappa_eqm,interp1(kappa,mu_n,kappa_eqm).*fkappa_eqm);
    Ecmu_n  = trapz(kappa_eqm,interp1(kappa,c(mu_n),kappa_eqm).*fkappa_eqm);
else
    Emu_n   = mu_n(1);
    Ecmu_n  = c(mu_n(1));
end
cmu     = trapz(kappa_eqm,interp1(kappa,c(mu_n),kappa_eqm).*fkappa_eqm)*frac_n+cmu_c*(1-frac_n);

dlogmu  = epsilon*(lambda_endo*p*(theta_bar_n-1).*(1-F(theta_bar_n))-kappa_mean./j_c)./(r-mu_c);
dlogcmu = (epsilon+1)*(lambda_endo*p*(theta_bar_n-1).*(1-F(theta_bar_n))-kappa_mean./j_c)./(r-mu_c);

%% Productivity distribution

% using standard contract
fzeta_c   = @(zeta) alpha/(alpha-zeta)*theta_bar_c^zeta;
eq_zeta_c = @(zeta) .5*sigma^2*zeta^2+(mu_c-1/2*sigma^2)*zeta-delta+lambda_endo*(1-F(theta_bar_c))*(fzeta_c(zeta)-1);
zetap_c   = fsolve(eq_zeta_c, 1.5, options_fsolve);
zetan_c   = fsolve(eq_zeta_c, -2, options_fsolve);
% pareto distribution proxy
gz_prox_c = @(z) zetap_c*zetan_c/(zetap_c+zetan_c)*(z.^(-zetap_c).*(z>1)+z.^(-zetan_c).*(z<1));

% using noncompete contract
fzeta_n   = @(zeta) alpha/(alpha-zeta)*theta_bar_n^zeta;
eq_zeta_n = @(zeta) .5*sigma^2*zeta^2+(mu_n(1)-1/2*sigma^2)*zeta-delta+lambda_endo*p*(1-F(theta_bar_n))*(fzeta_n(zeta)-1)+lambda_endo*(1-p)*(1-F(theta_bar_c))*(fzeta_c(zeta)-1);
zetap_n   = fsolve(eq_zeta_n, 1.5, options_fsolve);
zetan_n   = fsolve(eq_zeta_n, -2, options_fsolve);
% pareto distribution proxy
gz_prox_n = @(z) zetap_n*zetan_n/(zetap_nc+zetan_n)*(z.^(-zetap_n).*(z>1)+z.^(-zetan_n).*(z<1));

    
%% Social welfare
% the two computations are equivalent!

% s_c    = (1-c(mu_c))/(r-mu_c-lambda_endo*ES(theta_bar_c));
% s_n    = (1-c(mu_n)-kappa)./(r-mu_n-lambda_endo*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c)));
% % social value at the private optimal contract: kappa_bar and duration
% s_n_bar = (1-c(mu_c)-kappa_bar)./(r-mu_c-lambda_endo*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c)));
% % new born 
% S_1    = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));
% % steady state
% S_ss   = trapz(kappa_eqm,interp1(kappa,s_n.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1-K/(b+1)*v^(b+1)*Z/rho;

s_c    = (1-c(mu_c)-K/(b+1)*v^(b+1))/(r-mu_c-lambda_endo*ES(theta_bar_c));
s_n    = (1-c(mu_n)-kappa-K/(b+1)*v^(b+1))./(r-mu_n-lambda_endo*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c)));
% social value at the private optimal contract: kappa_bar and duration
s_n_bar = (1-c(mu_c)-kappa_bar)./(r-mu_c-lambda_endo*(p*ES(theta_bar_n)+(1-p)*ES(theta_bar_c)));
% new born 
S_1    = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));
% steady state
S_ss   = trapz(kappa_eqm,interp1(kappa,s_n.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1;

%% Consumption (net output)
% the two computations are equivalent!

% Y_n     = delta*(1-c(mu_n)-kappa)./D_n;
% Y_c     = delta*(1-c(mu_c))/D_c;
% Y       = trapz(kappa_eqm,interp1(kappa,Y_n,kappa_eqm).*fkappa_eqm)*frac_n+Y_c*(1-frac_n)-K/(b+1)*v^(b+1)*Z;

Y_n     = delta*(1-c(mu_n)-kappa-K/(b+1)*v^(b+1))./D_n;
Y_c     = delta*(1-c(mu_c)-K/(b+1)*v^(b+1))/D_c;
Y       = trapz(kappa_eqm,interp1(kappa,Y_n,kappa_eqm).*fkappa_eqm)*frac_n+Y_c*(1-frac_n);
    
%% Wedge

Delta1 = (lambda_endo*(p*EE(theta_bar_n)+(1-p)*EE(theta_bar_c)))./(r-mu_n-lambda_endo*p*ER(theta_bar_n-1));
Delta2 = (mu_n-1/2*sigma^2)./(r-mu_n-lambda_endo*p*ER(theta_bar_n-1));
Delta  = Delta1.*Delta2;
