dS_alt_vec = zeros(N_p,1);

%% Move to a weaker enforcement regime

if i_p == N_p
   
for i_p_alt = 1:N_p    

    p_alt = p_vec(i_p_alt);
    
    % marginal type
    kappa_bar_alt = kappa_bar_vec(i_p_alt);    
    frac_n_alt = frac_n_vec(i_p_alt);
    
    % endogeous grid
    kappa_alt = sort([kappa_eqm kappa_bar_alt]);    
    i_n_alt    = (kappa_alt<=kappa_bar_alt);    
    frac_n_alt_approx = trapz(kappa_alt,i_n_alt.*pdf(pd,kappa_alt));
    if frac_n_alt_approx>0
        fkappa_alt = pdf(pd,kappa_alt)/frac_n_alt_approx;
    else
        fkappa_alt = zeros(size(kappa_alt));
    end    
    if frac_n_approx>0
       fkappa_alt_eqm = pdf(pd,kappa_alt)/frac_n_approx;
    else
       fkappa_alt_eqm = zeros(size(kappa_alt));
    end

    %% J2J rates, separation rates, and investment rates

    j2j_n_alt = j2j_n_vec(i_p_alt);
    j2j_alt   = j2j_vec(i_p_alt);
    sep_alt   = sep_vec(i_p_alt);
    cmu_alt   = cmu_vec(i_p_alt);

    %% Welfare
    
    s_n_alt  = s_n_vec(i_p_alt,:);
    
    % new born
    S_1_alt  = S_1_vec(i_p_alt);
    % time 0
    s_alt    = s_c.*(1-i_n_alt)+interp1(kappa,s_n_alt,kappa_alt).*i_n_alt;
    S_alt    = trapz(kappa_alt,s_alt.*interp1(kappa,Z_n,kappa_alt).*fkappa_alt_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_alt;    
    % steady state 
    S_ss_alt = S_ss_vec(i_p_alt);

    %% Welfare-t0 decomposition
    
    dS_alt = S_alt/S_ss-1;

    D_n_reallocate_alt = delta-mu_n-lambda*(p_alt*ES(theta_bar_n)+(1-p_alt)*ES(theta_bar_c));
    s_n_reallocate_alt = (1-c(mu_n)-kappa)./(rho+D_n_reallocate_alt);
    S_1_reallocate_alt = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n_reallocate_alt,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));
    S_reallocate_alt = trapz(kappa_eqm,interp1(kappa,s_n_reallocate_alt.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_reallocate_alt;  

    dS_reallocate_alt = (S_reallocate_alt-S_ss)/S_ss;
    S_1_invest_alt = (rho+delta)/rho*(trapz(kappa_eqm,interp1(kappa,s_n_alt,kappa_eqm).*fkappa_eqm)*frac_n+s_c*(1-frac_n));    
    S_invest_alt = trapz(kappa_eqm,interp1(kappa,s_n_alt.*Z_n,kappa_eqm).*fkappa_eqm)*frac_n+s_c*Z_c*(1-frac_n)+delta/(rho+delta)*S_1_invest_alt; 

    dS_invest_alt = (S_invest_alt-S_reallocate_alt)/S_ss;

    dS_select_alt = (S_alt-S_invest_alt)/S_ss;

    %% Output

    Y_alt = Y_vec(i_p_alt);
    dY_alt = Y_alt/Y-1;

    %% Save

    dS_alt_vec(i_p_alt) = dS_alt;

    fprintf('   Move to a enforcement Regime = %.1g\n', p_alt)
    fprintf('       Fraction with noncompete = %.4g\n',frac_n_alt)      
    fprintf('       Cost threshold, kappa_bar = %.4g\n',kappa_bar_alt)   
    fprintf('       J2J transition rate = %.3g%%\n',j2j_alt*100)
    fprintf('                    change = %.3g%%\n',(j2j_alt-j2j)*100)
    fprintf('       Separation rate = %.3g%%\n',sep_alt*100) 
    fprintf('                change = %.3g%%\n',(sep_alt-sep)*100)
    fprintf('       Investment rate = %.3g%%\n',cmu_alt*100) 
    fprintf('                change = %.3g%%\n',(cmu_alt-cmu)*100)
    fprintf('       Welfare gain = %.3g%%\n',dS_alt*100)
    fprintf('       Decomposition\n')
    fprintf('         Reallocation = %.3g%%\n',dS_reallocate_alt*100)
    fprintf('         Investment = %.3g%%\n',dS_invest_alt*100)
    fprintf('         Selection = %.3g%%\n',dS_select_alt*100)
    fprintf('       Steady-State Welfare = %.5g\n',S_ss_alt)
    fprintf('       Steady-State Output = %.5g\n',Y_alt)
    fprintf('       Steady-State Output Gain  = %.3g%%\n',dY_alt*100)    
    disp(' ')   

end

%% Plot: weaken enforcement and welfare

plotfontsize  = 18;
labelfontsize = 18;
linecolor = 1/255*[0 0 153];

N_temp =30;
y_max_temp = 2.5; 

% find peak point
[~, temp] = max(dS_alt_vec);
fprintf('Weaken enforcement: Max s\n')
fprintf('   p = %.3g\n',p_vec(temp))
    
figure('pos',[100 100 450 360])
plot(p_vec,dS_alt_vec*100,'Color','k','LineWidth',2)
hold on 
plot(1*ones(N_temp,1),linspace(0,y_max_temp,N_temp),'.','Color',linecolor,'LineWidth',1)
plot(0.4*ones(N_temp,1),linspace(0,y_max_temp,N_temp),'.','Color',[.6 0 0],'LineWidth',1)
plot(0,dS_alt_vec(1)*100,'Marker','d','MarkerSize',9,'MarkerEdgeColor','k','MarkerFaceColor','k')
text(0,dS_alt_vec(1)*100,'Ban','HorizontalAlignment','left','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize,'Interpreter','latex')
text(0.8,0,'FL level','HorizontalAlignment','left','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize,'Color',linecolor,'Interpreter','latex')
text(0.3,0,'CA level','HorizontalAlignment','left','VerticalAlignment','bottom','FontName','Arial','FontSize',labelfontsize,'Color',[.6 0 0],'Interpreter','latex')
hold off
pbaspect([1.5 1 1])
xlabel('Weakened enforceability, p','FontName','Arial','FontSize',labelfontsize);
ylabel('Welfare gain, %','FontName','Arial','FontSize',labelfontsize);
xlim([0 1])
ylim([0 y_max_temp])
xticks([0 .2 .4 .6 .8 1])
set(gca,'FontName','Arial','FontSize',plotfontsize,'LineWidth',0.5,'FontSmoothing','on','XColor','k','YColor','k')

if kappa_case==1
    filename = fullfile(dir_fig,'welfare_enforcement_baseline.eps');
elseif kappa_case==2
    filename = fullfile(dir_fig,'welfare_enforcement_kappa_binary.eps');
elseif kappa_case==3
    filename = fullfile(dir_fig,'welfare_enforcement_kappa_nocost.eps');
end
print(filename, '-depsc')

end 