
% initiate
iter_x_max = 100;
iter_x_tol = 1e-5;
iter_x  = 0;
distance_x = inf;

weight  = 0.5;
Delta   = 100;
epsilon = 1e-3;

% initial guess
if i==1 || (i==2 && i_kappa==1)
    u      = linspace(betal*j_i,betau*j_i,Nx)';
end
ul     = betal*j_i*ones(Nx,1);
uu     = betau*j_i*ones(Nx,1);

% integration function
I       = @(theta_l) theta_min^alpha*(theta_bar_i^(1-alpha)-theta_l.^(1-alpha))/(1-alpha);
Iu      = @(theta_l) theta_min^alpha*(theta_bar_c^(1-alpha)-theta_l.^(1-alpha))/(1-alpha);

% construct matrix
Xx     = 1/2*sigma^2./dx2;
Yx     = ((mu_i+1/2*sigma^2)./dx-sigma^2./dx2);
Zx     = (-(mu_i+1/2*sigma^2)./dx+1/2*sigma^2./dx2);

lowdiag = Xx(2:Nx);
centdiag = Yx;
centdiag(1) = centdiag(1)+Xx(1);
centdiag(Nx) = centdiag(Nx)+Zx(Nx);
updiag = [0;Zx(1:Nx-1)];

A      = spdiags(centdiag,0,Nx,Nx)+spdiags(lowdiag,-1,Nx,Nx)+spdiags(updiag,1,Nx,Nx);
B      = (1/Delta+r-mu_i)*speye(Nx)-A;

while iter_x<iter_x_max && distance_x>iter_x_tol

% solve for theta_star
if i==1 
    theta_l = max(u/j_i,theta_min);
    Istar   = I(theta_l);
elseif i==2 
    theta_l = max(u/(exp(-r*pie_i)*j_i),theta_min);
    theta_l_temp = max(u/j_i,theta_min);
    Istar   = p*exp(-r*pie_i)*I(theta_l)+(1-p)*Iu(theta_l_temp);    
end

a      = exp(x)+lambda*Istar*j_i;
d      = -a-1/Delta*u;

% Yuval Tassa's Newton-based LCP solver
u_new  = LCP(B,d,ul,uu,u,0);   % turn display to 1 to check
check_LCP = (u_new-ul).*(u_new-uu).*(B*u_new+d);
uchange = u_new-u;
u      = u_new*weight+u*(1-weight);

distance_x = max(max(abs(uchange)));

if iter_x==0 && i==1
    disp('   Standard Contract: Wage')           
elseif iter_x==0 && i==2 
    if i_kappa==1
        disp('   Noncompete Contract: Wage,')
    end
    disp(['   	kappa grid = ' num2str(i_kappa)])    
end

if mod(iter_x,10)==0
    disp(['         Iteration = ' num2str(iter_x) ', Distance = ' num2str(distance_x)])
end

iter_x   = iter_x+1;

end

du      = zeros(Nx,1);
ddu     = zeros(Nx,1);    
du(1:Nx-1) = (u(2:end)-u(1:end-1))./dx(1:end-1);
du(Nx)  = du(Nx-1);
ddu(2:Nx) = (du(2:end)-du(1:end-1))./dx(1:end-1);
ddu(1)  = ddu(2);
check_HJB = (r-mu_i)*u-exp(x)-lambda*Istar*j_i+(mu_i+1/2*sigma^2)*du-1/2*sigma^2*ddu;


xl      = x(find(u-betal*j_i>=epsilon, 1, 'first'));   % lower bound of x
xu      = x(find(u-betau*j_i>=-epsilon, 1, 'first'));  % upper bound of x
select  = (x>=xl & x<=xu);
x0      = x(find(u-beta*j_i>=epsilon, 1, 'first'));    % initial Nash bargained level of x (x0=xl, when betal=beta)

